Method: Aws::S3::Client#put_object_acl

Defined in:
lib/aws-sdk-s3/client.rb

#put_object_acl(params = {}) ⇒ Types::PutObjectAclOutput

End of support notice: As of October 1, 2025, Amazon S3 has discontinued support for Email Grantee Access Control Lists (ACLs). If you attempt to use an Email Grantee ACL in a request after October 1, 2025, the request will receive an ‘HTTP 405` (Method Not Allowed) error.

This change affects the following Amazon Web Services Regions: US

East (N. Virginia), US West (N. California), US West (Oregon), Asia Pacific (Singapore), Asia Pacific (Sydney), Asia Pacific (Tokyo), Europe (Ireland), and South America (São Paulo).

<note markdown=“1”> This operation is not supported for directory buckets.

</note>

Uses the acl subresource to set the access control list (ACL) permissions for a new or existing object in an S3 bucket. You must have the WRITE_ACP permission to set the ACL of an object. For more information, see [What permissions can I grant?] in the *Amazon S3 User Guide*.

This functionality is not supported for Amazon S3 on Outposts.

Depending on your application needs, you can choose to set the ACL on an object using either the request body or the headers. For example, if you have an existing application that updates a bucket ACL using the request body, you can continue to use that approach. For more information, see [Access Control List (ACL) Overview] in the *Amazon S3 User Guide*.

If your bucket uses the bucket owner enforced setting for S3 Object Ownership, ACLs are disabled and no longer affect permissions. You must use policies to grant access to your bucket and the objects in it. Requests to set ACLs or update ACLs fail and return the AccessControlListNotSupported error code. Requests to read ACLs are still supported. For more information, see [Controlling object ownership] in the *Amazon S3 User Guide*.

Permissions

: You can set access permissions using one of the following methods:

* Specify a canned ACL with the `x-amz-acl` request header. Amazon
  S3 supports a set of predefined ACLs, known as canned ACLs. Each
  canned ACL has a predefined set of grantees and permissions.
  Specify the canned ACL name as the value of `x-amz-ac`l. If you
  use this header, you cannot use other access control-specific
  headers in your request. For more information, see [Canned
  ACL][4].

* Specify access permissions explicitly with the `x-amz-grant-read`,
  `x-amz-grant-read-acp`, `x-amz-grant-write-acp`, and
  `x-amz-grant-full-control` headers. When using these headers, you
  specify explicit access permissions and grantees (Amazon Web
  Services accounts or Amazon S3 groups) who will receive the
  permission. If you use these ACL-specific headers, you cannot use
  `x-amz-acl` header to set a canned ACL. These parameters map to
  the set of permissions that Amazon S3 supports in an ACL. For more
  information, see [Access Control List (ACL) Overview][2].

  You specify each grantee as a type=value pair, where the type is
  one of the following:

  * `id` 

Grantee Values

: You can specify the person (grantee) to whom you’re assigning

access rights (using request elements) in the following ways. For
examples of how to specify these grantee values in JSON format, see
the Amazon Web Services CLI example in [ Enabling Amazon S3 server
access logging][6] in the *Amazon S3 User Guide*.

* By the person's ID:

  `<Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xsi:type="CanonicalUser"><ID><>ID<></ID><DisplayName><>GranteesEmail<></DisplayName>
  </Grantee>`

  DisplayName is optional and ignored in the request.

* By URI:

  `<Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xsi:type="Group"><URI><>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<></URI></Grantee>`

* By Email address:

  `<Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xsi:type="AmazonCustomerByEmail"><EmailAddress><>[email protected]<></EmailAddress>lt;/Grantee>`

  The grantee is resolved to the CanonicalUser and, in a response to
  a GET Object acl request, appears as the CanonicalUser.

  <note markdown="1"> Using email addresses to specify a grantee is only supported in
  the following Amazon Web Services Regions:

   * US East (N. Virginia)

  * US West (N. California)

  * US West (Oregon)

  * Asia Pacific (Singapore)

  * Asia Pacific (Sydney)

  * Asia Pacific (Tokyo)

  * Europe (Ireland)

  * South America (São Paulo)

   For a list of all the Amazon S3 supported Regions and endpoints,
  see [Regions and Endpoints][5] in the Amazon Web Services General
  Reference.

   </note>

Versioning

: The ACL of an object is set at the object version level. By default,

PUT sets the ACL of the current version of an object. To set the ACL
of a different version, use the `versionId` subresource.

The following operations are related to PutObjectAcl:

  • CopyObject][7
  • GetObject][8

You must URL encode any signed header values that contain spaces. For example, if your header value is ‘my file.txt`, containing two spaces after my, you must URL encode this value to `my%20%20file.txt`.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions [2]: docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html [3]: docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html [4]: docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#CannedACL [5]: docs.aws.amazon.com/general/latest/gr/rande.html#s3_region [6]: docs.aws.amazon.com/AmazonS3/latest/userguide/enable-server-access-logging.html [7]: docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html [8]: docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

Examples:

Example: To grant permissions using object ACL


# The following example adds grants to an object ACL. The first permission grants user1 and user2 FULL_CONTROL and the
# AllUsers group READ permission.

resp = client.put_object_acl({
  access_control_policy: {
  }, 
  bucket: "examplebucket", 
  grant_full_control: "[email protected],[email protected]", 
  grant_read: "uri=http://acs.amazonaws.com/groups/global/AllUsers", 
  key: "HappyFace.jpg", 
})

resp.to_h outputs the following:
{
}

Request syntax with placeholder values


resp = client.put_object_acl({
  acl: "private", # accepts private, public-read, public-read-write, authenticated-read, aws-exec-read, bucket-owner-read, bucket-owner-full-control
  access_control_policy: {
    grants: [
      {
        grantee: {
          display_name: "DisplayName",
          email_address: "EmailAddress",
          id: "ID",
          type: "CanonicalUser", # required, accepts CanonicalUser, AmazonCustomerByEmail, Group
          uri: "URI",
        },
        permission: "FULL_CONTROL", # accepts FULL_CONTROL, WRITE, WRITE_ACP, READ, READ_ACP
      },
    ],
    owner: {
      display_name: "DisplayName",
      id: "ID",
    },
  },
  bucket: "BucketName", # required
  content_md5: "ContentMD5",
  checksum_algorithm: "CRC32", # accepts CRC32, CRC32C, SHA1, SHA256, CRC64NVME
  grant_full_control: "GrantFullControl",
  grant_read: "GrantRead",
  grant_read_acp: "GrantReadACP",
  grant_write: "GrantWrite",
  grant_write_acp: "GrantWriteACP",
  key: "ObjectKey", # required
  request_payer: "requester", # accepts requester
  version_id: "ObjectVersionId",
  expected_bucket_owner: "AccountId",
})

Response structure


resp.request_charged #=> String, one of "requester"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :acl (String)

    The canned ACL to apply to the object. For more information, see [Canned ACL].

    [1]: docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#CannedACL

  • :access_control_policy (Types::AccessControlPolicy)

    Contains the elements that set the ACL permissions for an object per grantee.

  • :bucket (required, String)

    The bucket name that contains the object to which you want to attach the ACL.

    **Access points** - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see [Using access points] in the *Amazon S3 User Guide*.

    **S3 on Outposts** - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form ‘ AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com`. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see [What is S3 on Outposts?] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/using-access-points.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html

  • :content_md5 (String)

    The Base64 encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to [RFC 1864.&gt;]

    For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

    [1]: www.ietf.org/rfc/rfc1864.txt

  • :checksum_algorithm (String)

    Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ‘400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :grant_full_control (String)

    Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

    This functionality is not supported for Amazon S3 on Outposts.

  • :grant_read (String)

    Allows grantee to list the objects in the bucket.

    This functionality is not supported for Amazon S3 on Outposts.

  • :grant_read_acp (String)

    Allows grantee to read the bucket ACL.

    This functionality is not supported for Amazon S3 on Outposts.

  • :grant_write (String)

    Allows grantee to create new objects in the bucket.

    For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

  • :grant_write_acp (String)

    Allows grantee to write the ACL for the applicable bucket.

    This functionality is not supported for Amazon S3 on Outposts.

  • :key (required, String)

    Key for which the PUT action was initiated.

  • :request_payer (String)

    Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

  • :version_id (String)

    Version ID used to reference a specific version of the object.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :expected_bucket_owner (String)

    The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

See Also:



18913
18914
18915
18916
# File 'lib/aws-sdk-s3/client.rb', line 18913

def put_object_acl(params = {}, options = {})
  req = build_request(:put_object_acl, params)
  req.send_request(options)
end