Class: Aws::S3::BucketLifecycleConfiguration
- Inherits:
-
Object
- Object
- Aws::S3::BucketLifecycleConfiguration
- Extended by:
- Deprecations
- Defined in:
- sig/bucket_lifecycle_configuration.rbs,
lib/aws-sdk-s3/bucket_lifecycle_configuration.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #bucket_name ⇒ String
- #rules ⇒ ::Array[Types::LifecycleRule]
- #transition_default_minimum_object_size ⇒ "varies_by_storage_class", "all_storage_classes_128K"
Actions collapse
Associations collapse
- #bucket ⇒ Bucket
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
- #data ⇒ Types::GetBucketLifecycleConfigurationOutput
- #data_loaded? ⇒ Boolean
- #initialize(*args) ⇒ BucketLifecycleConfiguration constructor
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::S3::Client] #wait_until instead
Constructor Details
#initialize(bucket_name, options) ⇒ void #initialize(bucket_name:, client:) ⇒ void #initialize(args) ⇒ void
22 23 24 25 26 27 28 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 22 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @bucket_name = extract_bucket_name(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#bucket ⇒ Bucket
352 353 354 355 356 357 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 352 def bucket Bucket.new( name: @bucket_name, client: @client ) end |
#bucket_name ⇒ String
33 34 35 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 33 def bucket_name @bucket_name end |
#client ⇒ Client
71 72 73 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 71 def client @client end |
#data ⇒ Types::GetBucketLifecycleConfigurationOutput
93 94 95 96 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 93 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
101 102 103 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 101 def data_loaded? !!@data end |
#delete(options = {}) ⇒ Object
222 223 224 225 226 227 228 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 222 def delete( = {}) = .merge(bucket: @bucket_name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.delete_bucket_lifecycle() end resp.data end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
361 362 363 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 361 def identifiers { bucket_name: @bucket_name } end |
#load ⇒ self Also known as: reload
81 82 83 84 85 86 87 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 81 def load resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.get_bucket_lifecycle_configuration(bucket: @bucket_name) end @data = resp.data self end |
#put(options = {}) ⇒ Object
341 342 343 344 345 346 347 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 341 def put( = {}) = .merge(bucket: @bucket_name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.put_bucket_lifecycle_configuration() end resp.data end |
#rules ⇒ ::Array[Types::LifecycleRule]
39 40 41 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 39 def rules data[:rules] end |
#transition_default_minimum_object_size ⇒ "varies_by_storage_class", "all_storage_classes_128K"
64 65 66 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 64 def transition_default_minimum_object_size data[:transition_default_minimum_object_size] end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::S3::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/aws-sdk-s3/bucket_lifecycle_configuration.rb', line 185 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |