Class: Aws::S3::BucketNotification

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/bucket_notification.rbs,
lib/aws-sdk-s3/bucket_notification.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(bucket_name, options) ⇒ void #initialize(bucket_name:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(bucket_name, options) ⇒ void

    Parameters:

    • bucket_name (String)
    • options (Hash[Symbol, untyped])
  • #initialize(bucket_name:, client:) ⇒ void

    Parameters:

    • bucket_name: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


22
23
24
25
26
27
28
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 22

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @bucket_name = extract_bucket_name(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#bucketBucket

Returns:



287
288
289
290
291
292
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 287

def bucket
  Bucket.new(
    name: @bucket_name,
    client: @client
  )
end

#bucket_nameString

Returns:

  • (String)


33
34
35
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 33

def bucket_name
  @bucket_name
end

#clientClient

Returns:



67
68
69
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 67

def client
  @client
end

#dataTypes::NotificationConfiguration



89
90
91
92
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 89

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


97
98
99
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 97

def data_loaded?
  !!@data
end

#event_bridge_configurationTypes::EventBridgeConfiguration



60
61
62
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 60

def event_bridge_configuration
  data[:event_bridge_configuration]
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


296
297
298
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 296

def identifiers
  { bucket_name: @bucket_name }
end

#lambda_function_configurations::Array[Types::LambdaFunctionConfiguration]



54
55
56
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 54

def lambda_function_configurations
  data[:lambda_function_configurations]
end

#loadself Also known as: reload

Returns:

  • (self)


77
78
79
80
81
82
83
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 77

def load
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.get_bucket_notification_configuration(bucket: @bucket_name)
  end
  @data = resp.data
  self
end

#put(options = {}) ⇒ Object



276
277
278
279
280
281
282
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 276

def put(options = {})
  options = options.merge(bucket: @bucket_name)
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.put_bucket_notification_configuration(options)
  end
  resp.data
end

#queue_configurations::Array[Types::QueueConfiguration]

Returns:



47
48
49
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 47

def queue_configurations
  data[:queue_configurations]
end

#topic_configurations::Array[Types::TopicConfiguration]

Returns:



40
41
42
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 40

def topic_configurations
  data[:topic_configurations]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::S3::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-s3/bucket_notification.rb', line 181

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end