Method: Aws::S3::Encryption::DecryptHandler#call
- Defined in:
- lib/aws-sdk-s3/encryption/decrypt_handler.rb
#call(context) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/aws-sdk-s3/encryption/decrypt_handler.rb', line 46 def call(context) attach_http_event_listeners(context) apply_cse_user_agent(context) if context[:response_target].is_a?(Proc) && !@@warned_response_target_proc @@warned_response_target_proc = true warn(':response_target is a Proc, or a block was provided. ' \ 'Read the entire object to the ' \ 'end before you start using the decrypted data. This is to ' \ 'verify that the object has not been modified since it ' \ 'was encrypted.') end @handler.call(context) end |