Class: Aws::S3::EncryptionV3::DecryptHandler Private

Inherits:
Seahorse::Client::Handler
  • Object
show all
Defined in:
lib/aws-sdk-s3/encryptionV3/decrypt_handler.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

API:

  • private

Constant Summary collapse

@@warned_response_target_proc =

This classvariable is part of a private API. You should avoid using this classvariable if possible, as it may be removed or be changed in the future.

API:

  • private

false

Instance Method Summary collapse

Instance Method Details

#call(context) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'lib/aws-sdk-s3/encryptionV3/decrypt_handler.rb', line 14

def call(context)
  attach_http_event_listeners(context)
  apply_cse_user_agent(context)

  if context[:response_target].is_a?(Proc) && !@@warned_response_target_proc
    @@warned_response_target_proc = true
    warn(':response_target is a Proc, or a block was provided. ' \
      'Read the entire object to the ' \
      'end before you start using the decrypted data. This is to ' \
      'verify that the object has not been modified since it ' \
      'was encrypted.')

  end

  @handler.call(context)
end