Class: Aws::S3::MultipartUpload

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/multipart_upload.rbs,
lib/aws-sdk-s3/multipart_upload.rb,
lib/aws-sdk-s3/customizations/multipart_upload.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(bucket_name, object_key, id, options) ⇒ void #initialize(bucket_name:, object_key:, id:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(bucket_name, object_key, id, options) ⇒ void

    Parameters:

    • bucket_name (String)
    • object_key (String)
    • id (String)
    • options (Hash[Symbol, untyped])
  • #initialize(bucket_name:, object_key:, id:, client:) ⇒ void

    Parameters:

    • bucket_name: (String)
    • object_key: (String)
    • id: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


26
27
28
29
30
31
32
33
34
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 26

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @bucket_name = extract_bucket_name(args, options)
  @object_key = extract_object_key(args, options)
  @id = extract_id(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#abort(options = {}) ⇒ Object



291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 291

def abort(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    upload_id: @id
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.abort_multipart_upload(options)
  end
  resp.data
end

#basic_completeObject

Examples:

Request syntax with placeholder values

object = multipart_upload.complete({
  multipart_upload: {
    parts: [
      {
        etag: "ETag",
        checksum_crc32: "ChecksumCRC32",
        checksum_crc32c: "ChecksumCRC32C",
        checksum_crc64nvme: "ChecksumCRC64NVME",
        checksum_sha1: "ChecksumSHA1",
        checksum_sha256: "ChecksumSHA256",
        checksum_sha512: "ChecksumSHA512",
        checksum_md5: "ChecksumMD5",
        checksum_xxhash64: "ChecksumXXHASH64",
        checksum_xxhash3: "ChecksumXXHASH3",
        checksum_xxhash128: "ChecksumXXHASH128",
        part_number: 1,
      },
    ],
  },
  checksum_crc32: "ChecksumCRC32",
  checksum_crc32c: "ChecksumCRC32C",
  checksum_crc64nvme: "ChecksumCRC64NVME",
  checksum_sha1: "ChecksumSHA1",
  checksum_sha256: "ChecksumSHA256",
  checksum_sha512: "ChecksumSHA512",
  checksum_md5: "ChecksumMD5",
  checksum_xxhash64: "ChecksumXXHASH64",
  checksum_xxhash3: "ChecksumXXHASH3",
  checksum_xxhash128: "ChecksumXXHASH128",
  checksum_type: "COMPOSITE", # accepts COMPOSITE, FULL_OBJECT
  mpu_object_size: 1,
  request_payer: "requester", # accepts requester
  expected_bucket_owner: "AccountId",
  if_match: "IfMatch",
  if_none_match: "IfNoneMatch",
  sse_customer_algorithm: "SSECustomerAlgorithm",
  sse_customer_key: "SSECustomerKey",
  sse_customer_key_md5: "SSECustomerKeyMD5",
})

Parameters:

  • options (Hash)

    ({})

Returns:



7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
# File 'lib/aws-sdk-s3/customizations/multipart_upload.rb', line 7

def complete(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    upload_id: @id
  )
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.complete_multipart_upload(options)
  end
  Object.new(
    bucket_name: @bucket_name,
    key: @object_key,
    client: @client
  )
end

#bucket_nameString

Returns:

  • (String)


39
40
41
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 39

def bucket_name
  @bucket_name
end

#checksum_algorithm"CRC32", ...

Returns:

  • ("CRC32", "CRC32C", "SHA1", "SHA256", "CRC64NVME", "SHA512", "MD5", "XXHASH64", "XXHASH3", "XXHASH128")


104
105
106
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 104

def checksum_algorithm
  data[:checksum_algorithm]
end

#checksum_type"COMPOSITE", "FULL_OBJECT"

Returns:

  • ("COMPOSITE", "FULL_OBJECT")


116
117
118
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 116

def checksum_type
  data[:checksum_type]
end

#clientClient

Returns:



123
124
125
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 123

def client
  @client
end

#complete(options = {}) ⇒ Object



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 563

def complete(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    upload_id: @id
  )
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.complete_multipart_upload(options)
  end
  Object.new(
    bucket_name: @bucket_name,
    key: @object_key,
    client: @client
  )
end

#dataTypes::MultipartUpload



138
139
140
141
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 138

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


146
147
148
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 146

def data_loaded?
  !!@data
end

#idString

Returns:

  • (String)


49
50
51
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 49

def id
  @id
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


702
703
704
705
706
707
708
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 702

def identifiers
  {
    bucket_name: @bucket_name,
    object_key: @object_key,
    id: @id
  }
end

#initiated::Time

Returns:

  • (::Time)


67
68
69
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 67

def initiated
  data[:initiated]
end

#initiatorTypes::Initiator

Returns:



98
99
100
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 98

def initiator
  data[:initiator]
end

#key::String

Returns:

  • (::String)


61
62
63
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 61

def key
  data[:key]
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


129
130
131
132
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 129

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#objectObject

Returns:



582
583
584
585
586
587
588
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 582

def object
  Object.new(
    bucket_name: @bucket_name,
    key: @object_key,
    client: @client
  )
end

#object_keyString

Returns:

  • (String)


44
45
46
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 44

def object_key
  @object_key
end

#ownerTypes::Owner

Returns:



92
93
94
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 92

def owner
  data[:owner]
end

#part(part_number) ⇒ MultipartUploadPart

Parameters:

  • part_number (String)

Returns:



592
593
594
595
596
597
598
599
600
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 592

def part(part_number)
  MultipartUploadPart.new(
    bucket_name: @bucket_name,
    object_key: @object_key,
    multipart_upload_id: @id,
    part_number: part_number,
    client: @client
  )
end

#parts(options = {}) ⇒ Object



672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 672

def parts(options = {})
  batches = Enumerator.new do |y|
    options = options.merge(
      bucket: @bucket_name,
      key: @object_key,
      upload_id: @id
    )
    resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      @client.list_parts(options)
    end
    resp.each_page do |page|
      batch = []
      page.data.parts.each do |p|
        batch << MultipartUploadPart.new(
          bucket_name: options[:bucket],
          object_key: options[:key],
          multipart_upload_id: options[:upload_id],
          part_number: p.part_number,
          data: p,
          client: @client
        )
      end
      y.yield(batch)
    end
  end
  MultipartUploadPart::Collection.new(batches)
end

#storage_class"STANDARD", ...

Returns:

  • ("STANDARD", "REDUCED_REDUNDANCY", "STANDARD_IA", "ONEZONE_IA", "INTELLIGENT_TIERING", "GLACIER", "DEEP_ARCHIVE", "OUTPOSTS", "GLACIER_IR", "SNOW", "EXPRESS_ONEZONE", "FSX_OPENZFS", "FSX_ONTAP")


80
81
82
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 80

def storage_class
  data[:storage_class]
end

#upload_id::String

Returns:

  • (::String)


55
56
57
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 55

def upload_id
  data[:upload_id]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::S3::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 230

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end