Class: Aws::S3::ObjectAcl

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/object_acl.rbs,
lib/aws-sdk-s3/object_acl.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(bucket_name, object_key, options) ⇒ void #initialize(bucket_name:, object_key:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(bucket_name, object_key, options) ⇒ void

    Parameters:

    • bucket_name (String)
    • object_key (String)
    • options (Hash[Symbol, untyped])
  • #initialize(bucket_name:, object_key:, client:) ⇒ void

    Parameters:

    • bucket_name: (String)
    • object_key: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


24
25
26
27
28
29
30
31
# File 'lib/aws-sdk-s3/object_acl.rb', line 24

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @bucket_name = extract_bucket_name(args, options)
  @object_key = extract_object_key(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#bucket_nameString

Returns:

  • (String)


36
37
38
# File 'lib/aws-sdk-s3/object_acl.rb', line 36

def bucket_name
  @bucket_name
end

#clientClient

Returns:



77
78
79
# File 'lib/aws-sdk-s3/object_acl.rb', line 77

def client
  @client
end

#dataTypes::GetObjectAclOutput



102
103
104
105
# File 'lib/aws-sdk-s3/object_acl.rb', line 102

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


110
111
112
# File 'lib/aws-sdk-s3/object_acl.rb', line 110

def data_loaded?
  !!@data
end

#grants::Array[Types::Grant]

Returns:



53
54
55
# File 'lib/aws-sdk-s3/object_acl.rb', line 53

def grants
  data[:grants]
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


360
361
362
363
364
365
# File 'lib/aws-sdk-s3/object_acl.rb', line 360

def identifiers
  {
    bucket_name: @bucket_name,
    object_key: @object_key
  }
end

#loadself Also known as: reload

Returns:

  • (self)


87
88
89
90
91
92
93
94
95
96
# File 'lib/aws-sdk-s3/object_acl.rb', line 87

def load
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.get_object_acl(
    bucket: @bucket_name,
    key: @object_key
  )
  end
  @data = resp.data
  self
end

#objectObject

Returns:



350
351
352
353
354
355
356
# File 'lib/aws-sdk-s3/object_acl.rb', line 350

def object
  Object.new(
    bucket_name: @bucket_name,
    key: @object_key,
    client: @client
  )
end

#object_keyString

Returns:

  • (String)


41
42
43
# File 'lib/aws-sdk-s3/object_acl.rb', line 41

def object_key
  @object_key
end

#ownerTypes::Owner

Returns:



47
48
49
# File 'lib/aws-sdk-s3/object_acl.rb', line 47

def owner
  data[:owner]
end

#put(options = {}) ⇒ Object



336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-s3/object_acl.rb', line 336

def put(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.put_object_acl(options)
  end
  resp.data
end

#request_charged"requester"

Returns:

  • ("requester")


70
71
72
# File 'lib/aws-sdk-s3/object_acl.rb', line 70

def request_charged
  data[:request_charged]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::S3::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/aws-sdk-s3/object_acl.rb', line 194

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end