Class: Aws::S3::ObjectVersion

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/object_version.rbs,
lib/aws-sdk-s3/object_version.rb,
lib/aws-sdk-s3/customizations/object_version.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(bucket_name, object_key, id, options) ⇒ void #initialize(bucket_name:, object_key:, id:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(bucket_name, object_key, id, options) ⇒ void

    Parameters:

    • bucket_name (String)
    • object_key (String)
    • id (String)
    • options (Hash[Symbol, untyped])
  • #initialize(bucket_name:, object_key:, id:, client:) ⇒ void

    Parameters:

    • bucket_name: (String)
    • object_key: (String)
    • id: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


26
27
28
29
30
31
32
33
34
# File 'lib/aws-sdk-s3/object_version.rb', line 26

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @bucket_name = extract_bucket_name(args, options)
  @object_key = extract_object_key(args, options)
  @id = extract_id(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#bucket_nameString

Returns:

  • (String)


39
40
41
# File 'lib/aws-sdk-s3/object_version.rb', line 39

def bucket_name
  @bucket_name
end

#checksum_algorithm::Array[("CRC32" | "CRC32C" | "SHA1" | "SHA256" | "CRC64NVME" | "SHA512" | "MD5" | "XXHASH64" | "XXHASH3" | "XXHASH128")]

Returns:

  • (::Array[("CRC32" | "CRC32C" | "SHA1" | "SHA256" | "CRC64NVME" | "SHA512" | "MD5" | "XXHASH64" | "XXHASH3" | "XXHASH128")])


61
62
63
# File 'lib/aws-sdk-s3/object_version.rb', line 61

def checksum_algorithm
  data[:checksum_algorithm]
end

#checksum_type"COMPOSITE", "FULL_OBJECT"

Returns:

  • ("COMPOSITE", "FULL_OBJECT")


73
74
75
# File 'lib/aws-sdk-s3/object_version.rb', line 73

def checksum_type
  data[:checksum_type]
end

#clientClient

Returns:



137
138
139
# File 'lib/aws-sdk-s3/object_version.rb', line 137

def client
  @client
end

#dataTypes::ObjectVersion



152
153
154
155
# File 'lib/aws-sdk-s3/object_version.rb', line 152

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


160
161
162
# File 'lib/aws-sdk-s3/object_version.rb', line 160

def data_loaded?
  !!@data
end

#delete(options = {}) ⇒ Object



353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-s3/object_version.rb', line 353

def delete(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    version_id: @id
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.delete_object(options)
  end
  resp.data
end

#etag::String

Returns:

  • (::String)


55
56
57
# File 'lib/aws-sdk-s3/object_version.rb', line 55

def etag
  data[:etag]
end

#get(options = {}, &block) ⇒ Object



580
581
582
583
584
585
586
587
588
589
590
# File 'lib/aws-sdk-s3/object_version.rb', line 580

def get(options = {}, &block)
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    version_id: @id
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.get_object(options, &block)
  end
  resp.data
end

#head(options = {}) ⇒ Object



772
773
774
775
776
777
778
779
780
781
782
# File 'lib/aws-sdk-s3/object_version.rb', line 772

def head(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    version_id: @id
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.head_object(options)
  end
  resp.data
end

#idString

Returns:

  • (String)


49
50
51
# File 'lib/aws-sdk-s3/object_version.rb', line 49

def id
  @id
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


797
798
799
800
801
802
803
# File 'lib/aws-sdk-s3/object_version.rb', line 797

def identifiers
  {
    bucket_name: @bucket_name,
    object_key: @object_key,
    id: @id
  }
end

#is_latestBoolean

Returns:

  • (Boolean)


104
105
106
# File 'lib/aws-sdk-s3/object_version.rb', line 104

def is_latest
  data[:is_latest]
end

#key::String

Returns:

  • (::String)


91
92
93
# File 'lib/aws-sdk-s3/object_version.rb', line 91

def key
  data[:key]
end

#last_modified::Time

Returns:

  • (::Time)


110
111
112
# File 'lib/aws-sdk-s3/object_version.rb', line 110

def last_modified
  data[:last_modified]
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


143
144
145
146
# File 'lib/aws-sdk-s3/object_version.rb', line 143

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#objectObject

Returns:



787
788
789
790
791
792
793
# File 'lib/aws-sdk-s3/object_version.rb', line 787

def object
  Object.new(
    bucket_name: @bucket_name,
    key: @object_key,
    client: @client
  )
end

#object_keyString

Returns:

  • (String)


44
45
46
# File 'lib/aws-sdk-s3/object_version.rb', line 44

def object_key
  @object_key
end

#ownerTypes::Owner

Returns:



116
117
118
# File 'lib/aws-sdk-s3/object_version.rb', line 116

def owner
  data[:owner]
end

#restore_statusTypes::RestoreStatus



130
131
132
# File 'lib/aws-sdk-s3/object_version.rb', line 130

def restore_status
  data[:restore_status]
end

#size::Integer

Returns:

  • (::Integer)


79
80
81
# File 'lib/aws-sdk-s3/object_version.rb', line 79

def size
  data[:size]
end

#storage_class"STANDARD"

Returns:

  • ("STANDARD")


85
86
87
# File 'lib/aws-sdk-s3/object_version.rb', line 85

def storage_class
  data[:storage_class]
end

#version_id::String

Returns:

  • (::String)


97
98
99
# File 'lib/aws-sdk-s3/object_version.rb', line 97

def version_id
  data[:version_id]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::S3::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-s3/object_version.rb', line 244

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end