Class: Aws::S3::Resource

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-s3/resource.rb

Overview

This class provides a resource oriented interface for S3. To create a resource object:

resource = Aws::S3::Resource.new(region: 'us-west-2')

You can supply a client object with custom configuration that will be used for all resource operations. If you do not pass :client, a default client will be constructed.

client = Aws::S3::Client.new(region: 'us-west-2')
resource = Aws::S3::Resource.new(client: client)

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ Resource

Returns a new instance of Resource.

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):



27
28
29
# File 'lib/aws-sdk-s3/resource.rb', line 27

def initialize(options = {})
  @client = options[:client] || Client.new(options)
end

Instance Method Details

#bucket(name) ⇒ Bucket

Parameters:

  • name (String)

Returns:



217
218
219
220
221
222
# File 'lib/aws-sdk-s3/resource.rb', line 217

def bucket(name)
  Bucket.new(
    name: name,
    client: @client
  )
end

#buckets(options = {}) ⇒ Bucket::Collection

Examples:

Request syntax with placeholder values


buckets = s3.buckets({
  prefix: "Prefix",
  bucket_region: "BucketRegion",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :prefix (String)

    Limits the response to bucket names that begin with the specified bucket name prefix.

  • :bucket_region (String)

    Limits the response to buckets that are located in the specified Amazon Web Services Region. The Amazon Web Services Region must be expressed according to the Amazon Web Services Region code, such as us-west-2 for the US West (Oregon) Region. For a list of the valid values for all of the Amazon Web Services Regions, see [Regions and Endpoints].

    <note markdown=“1”> Requests made to a Regional endpoint that is different from the bucket-region parameter are not supported. For example, if you want to limit the response to your buckets in Region us-west-2, the request must be made to an endpoint in Region us-west-2.

    </note>
    

    [1]: docs.aws.amazon.com/general/latest/gr/rande.html#s3_region

Returns:



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/aws-sdk-s3/resource.rb', line 253

def buckets(options = {})
  batches = Enumerator.new do |y|
    resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      @client.list_buckets(options)
    end
    resp.each_page do |page|
      batch = []
      page.data.buckets.each do |b|
        batch << Bucket.new(
          name: b.name,
          data: b,
          client: @client
        )
      end
      y.yield(batch)
    end
  end
  Bucket::Collection.new(batches)
end

#clientClient

Returns:



32
33
34
# File 'lib/aws-sdk-s3/resource.rb', line 32

def client
  @client
end

#create_bucket(options = {}) ⇒ Bucket

Examples:

Request syntax with placeholder values


bucket = s3.create_bucket({
  acl: "private", # accepts private, public-read, public-read-write, authenticated-read
  bucket: "BucketName", # required
  create_bucket_configuration: {
    location_constraint: "af-south-1", # accepts af-south-1, ap-east-1, ap-northeast-1, ap-northeast-2, ap-northeast-3, ap-south-1, ap-south-2, ap-southeast-1, ap-southeast-2, ap-southeast-3, ap-southeast-4, ap-southeast-5, ca-central-1, cn-north-1, cn-northwest-1, EU, eu-central-1, eu-central-2, eu-north-1, eu-south-1, eu-south-2, eu-west-1, eu-west-2, eu-west-3, il-central-1, me-central-1, me-south-1, sa-east-1, us-east-2, us-gov-east-1, us-gov-west-1, us-west-1, us-west-2
    location: {
      type: "AvailabilityZone", # accepts AvailabilityZone, LocalZone
      name: "LocationNameAsString",
    },
    bucket: {
      data_redundancy: "SingleAvailabilityZone", # accepts SingleAvailabilityZone, SingleLocalZone
      type: "Directory", # accepts Directory
    },
    tags: [
      {
        key: "ObjectKey", # required
        value: "Value", # required
      },
    ],
  },
  grant_full_control: "GrantFullControl",
  grant_read: "GrantRead",
  grant_read_acp: "GrantReadACP",
  grant_write: "GrantWrite",
  grant_write_acp: "GrantWriteACP",
  object_lock_enabled_for_bucket: false,
  object_ownership: "BucketOwnerPreferred", # accepts BucketOwnerPreferred, ObjectWriter, BucketOwnerEnforced
  bucket_namespace: "account-regional", # accepts account-regional, global
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :acl (String)

    The canned ACL to apply to the bucket.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :bucket (required, String)

    The name of the bucket to create.

    **General purpose buckets** - For information about bucket naming restrictions, see [Bucket naming rules] in the *Amazon S3 User Guide*.

    Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ‘s3express-control.region-code.amazonaws.com/bucket-name `. Virtual-hosted-style requests aren’t supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format ‘ bucket-base-name–zone-id–x-s3` (for example, ` DOC-EXAMPLE-BUCKET–usw2-az1–x-s3`). For information about bucket naming restrictions, see [Directory bucket naming rules] in the *Amazon S3 User Guide*

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-bucket-naming-rules.html

  • :create_bucket_configuration (Types::CreateBucketConfiguration)

    The configuration information for the bucket.

  • :grant_full_control (String)

    Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :grant_read (String)

    Allows grantee to list the objects in the bucket.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :grant_read_acp (String)

    Allows grantee to read the bucket ACL.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :grant_write (String)

    Allows grantee to create new objects in the bucket.

    For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :grant_write_acp (String)

    Allows grantee to write the ACL for the applicable bucket.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :object_lock_enabled_for_bucket (Boolean)

    Specifies whether you want S3 Object Lock to be enabled for the new bucket.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :object_ownership (String)

    The container element for object ownership for a bucket’s ownership controls.

    BucketOwnerPreferred - Objects uploaded to the bucket change ownership to the bucket owner if the objects are uploaded with the bucket-owner-full-control canned ACL.

    ObjectWriter - The uploading account will own the object if the object is uploaded with the bucket-owner-full-control canned ACL.

    BucketOwnerEnforced - Access control lists (ACLs) are disabled and no longer affect permissions. The bucket owner automatically owns and has full control over every object in the bucket. The bucket only accepts PUT requests that don’t specify an ACL or specify bucket owner full control ACLs (such as the predefined bucket-owner-full-control canned ACL or a custom ACL in XML format that grants the same permissions).

    By default, ObjectOwnership is set to BucketOwnerEnforced and ACLs are disabled. We recommend keeping ACLs disabled, except in uncommon use cases where you must control access for each object individually. For more information about S3 Object Ownership, see [Controlling ownership of objects and disabling ACLs for your bucket] in the *Amazon S3 User Guide*.

    <note markdown=“1”> This functionality is not supported for directory buckets. Directory buckets use the bucket owner enforced setting for S3 Object Ownership.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html

  • :bucket_namespace (String)

    Specifies the namespace where you want to create your general purpose bucket. When you create a general purpose bucket, you can choose to create a bucket in the shared global namespace or you can choose to create a bucket in your account regional namespace. Your account regional namespace is a subdivision of the global namespace that only your account can create buckets in. For more information on bucket namespaces, see [Namespaces for general purpose buckets].

    General purpose buckets in your account regional namespace must follow a specific naming convention. These buckets consist of a bucket name prefix that you create, and a suffix that contains your 12-digit Amazon Web Services Account ID, the Amazon Web Services Region code, and ends with -an. Bucket names must follow the format bucket-name-prefix-accountId-region-an (for example, amzn-s3-demo-bucket-111122223333-us-west-2-an). For information about bucket naming restrictions, see [Account regional namespace naming rules] in the *Amazon S3 User Guide*.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/gpbucketnamespaces.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html#account-regional-naming-rules

Returns:



203
204
205
206
207
208
209
210
211
# File 'lib/aws-sdk-s3/resource.rb', line 203

def create_bucket(options = {})
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.create_bucket(options)
  end
  Bucket.new(
    name: options[:bucket],
    client: @client
  )
end