Class: Aws::S3::Types::AnnotationEntry

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Describes a single annotation attached to an object, including its name, last modified time, size, ETag, checksum algorithm, and replication status. Returned in the response from ‘ListObjectAnnotations`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_nameString

The name of the annotation.

Returns:

  • (String)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmArray<String>

The checksum algorithm used for the annotation.

Returns:

  • (Array<String>)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The entity tag of the annotation.

Returns:

  • (String)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time the annotation was last modified.

Returns:

  • (Time)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#replication_statusString

The replication status of the annotation.

Returns:

  • (String)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The size of the annotation payload, in bytes.

Returns:

  • (Integer)


419
420
421
422
423
424
425
426
427
428
# File 'lib/aws-sdk-s3/types.rb', line 419

class AnnotationEntry < Struct.new(
  :annotation_name,
  :last_modified,
  :etag,
  :checksum_algorithm,
  :size,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end