Class: Aws::S3::Types::AnnotationTableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies the configuration for the annotation table associated with a bucket’s Amazon S3 Metadata configuration. The annotation table is an Iceberg table that records annotation events for objects in the bucket.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_stateString

The state of the annotation table. Valid values are ‘ENABLED` and `DISABLED`.

Returns:

  • (String)


464
465
466
467
468
469
470
# File 'lib/aws-sdk-s3/types.rb', line 464

class AnnotationTableConfiguration < Struct.new(
  :configuration_state,
  :encryption_configuration,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::MetadataTableEncryptionConfiguration

The encryption settings for an S3 Metadata journal table or inventory table configuration.



464
465
466
467
468
469
470
# File 'lib/aws-sdk-s3/types.rb', line 464

class AnnotationTableConfiguration < Struct.new(
  :configuration_state,
  :encryption_configuration,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The ARN of the IAM role used to manage the annotation table.

Returns:

  • (String)


464
465
466
467
468
469
470
# File 'lib/aws-sdk-s3/types.rb', line 464

class AnnotationTableConfiguration < Struct.new(
  :configuration_state,
  :encryption_configuration,
  :role)
  SENSITIVE = []
  include Aws::Structure
end