Class: Aws::S3::Types::AnnotationTableConfigurationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Contains the current state of the annotation table associated with a bucket’s Amazon S3 Metadata configuration, including its provisioning status and identifiers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_stateString

The current configuration state of the annotation table.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::ErrorDetails

If an S3 Metadata V1 ‘CreateBucketMetadataTableConfiguration` or V2 `CreateBucketMetadataConfiguration` request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.

<note markdown=“1”> If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using [CreateBucketMetadataConfiguration] so that you can expire journal table records and create a live inventory table.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucketMetadataConfiguration.html

Returns:



517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The ARN of the IAM role associated with the annotation table.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#table_arnString

The ARN of the annotation table.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the annotation table.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#table_statusString

The provisioning status of the annotation table. Possible values: ‘CREATING`, `BACKFILLING`, `ACTIVE`, `FAILED`.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
# File 'lib/aws-sdk-s3/types.rb', line 517

class AnnotationTableConfigurationResult < Struct.new(
  :configuration_state,
  :table_status,
  :error,
  :table_name,
  :table_arn,
  :role)
  SENSITIVE = []
  include Aws::Structure
end