Class: Aws::S3::Types::BucketInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies the information about the bucket that will be created. For more information about directory buckets, see Directory buckets in the Amazon S3 User Guide.

This functionality is only supported by directory buckets.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_redundancyString

The number of Zone (Availability Zone or Local Zone) that's used for redundancy for the bucket.

Returns:

  • (String)


697
698
699
700
701
702
# File 'lib/aws-sdk-s3/types.rb', line 697

class BucketInfo < Struct.new(
  :data_redundancy,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of bucket.

Returns:

  • (String)


697
698
699
700
701
702
# File 'lib/aws-sdk-s3/types.rb', line 697

class BucketInfo < Struct.new(
  :data_redundancy,
  :type)
  SENSITIVE = []
  include Aws::Structure
end