Class: Aws::S3::Types::CompleteMultipartUploadRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:sse_customer_key]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

Name of the bucket to which the multipart upload was initiated.

Directory buckets - When you use this operation with a directory bucket, you must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style requests are not supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket naming restrictions, see Directory bucket naming rules in the Amazon S3 User Guide.

Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.

Object Lambda access points are not supported by directory buckets.

S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see What is S3 on Outposts? in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_crc32String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32 checksum of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_crc32cString

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit CRC32C checksum of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_crc64nvmeString

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit CRC64NVME checksum of the object. The CRC64NVME checksum is always a full object checksum. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_md5String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit MD5 digest of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_sha1String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit SHA1 digest of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_sha256String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit SHA256 digest of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_sha512String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 512-bit SHA512 digest of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_typeString

This header specifies the checksum type of the object, which determines how part-level checksums are combined to create an object-level checksum for multipart objects. You can use this header as a data integrity check to verify that the checksum type that is received is the same checksum that was specified. If the checksum type doesn’t match the checksum type that was specified for the object during the CreateMultipartUpload request, it’ll result in a BadDigest error. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_xxhash128String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit XXHASH128 checksum of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_xxhash3String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit XXHASH3 checksum of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#checksum_xxhash64String

This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit XXHASH64 checksum of the object. For more information, see Checking object integrity in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#if_matchString

Uploads the object only if the ETag (entity tag) value provided during the WRITE operation matches the ETag of the object in S3. If the ETag values do not match, the operation returns a 412 Precondition Failed error.

If a conflicting operation occurs during the upload S3 returns a 409 ConditionalRequestConflict response. On a 409 failure you should fetch the object's ETag, re-initiate the multipart upload with CreateMultipartUpload, and re-upload each part.

Expects the ETag value as a string.

For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#if_none_matchString

Uploads the object only if the object key name does not already exist in the bucket specified. Otherwise, Amazon S3 returns a 412 Precondition Failed error.

If a conflicting operation occurs during the upload S3 returns a 409 ConditionalRequestConflict response. On a 409 failure you should re-initiate the multipart upload with CreateMultipartUpload and re-upload each part.

Expects the '*' (asterisk) character.

For more information about conditional requests, see RFC 7232, or Conditional requests in the Amazon S3 User Guide.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#keyString

Object key for which the multipart upload was initiated.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#mpu_object_sizeInteger

The expected total object size of the multipart upload request. If there’s a mismatch between the specified object size value and the actual object size value, it results in an HTTP 400 InvalidRequest error.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#multipart_uploadTypes::CompletedMultipartUpload

The container for the multipart upload request information.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#sse_customer_algorithmString

The server-side encryption (SSE) algorithm used to encrypt the object. This parameter is required only when the object was created using a checksum algorithm or if your bucket policy requires the use of SSE-C. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#sse_customer_keyString

The server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#sse_customer_key_md5String

The MD5 server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end

#upload_idString

ID for the initiated multipart upload.

Returns:



1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-s3/types.rb', line 1717

class CompleteMultipartUploadRequest < Struct.new(
  :bucket,
  :key,
  :multipart_upload,
  :upload_id,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :mpu_object_size,
  :request_payer,
  :expected_bucket_owner,
  :if_match,
  :if_none_match,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end