Class: Aws::S3::Types::CopyObjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::CopyObjectOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:ssekms_key_id, :ssekms_encryption_context]
Instance Attribute Summary collapse
-
#bucket_key_enabled ⇒ Boolean
Indicates whether the copied object uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
-
#copy_object_result ⇒ Types::CopyObjectResult
Container for all response elements.
-
#copy_source_version_id ⇒ String
Version ID of the source object that was copied.
-
#expiration ⇒ String
If the object expiration is configured, the response includes this header.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
-
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that’s used.
-
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
-
#ssekms_encryption_context ⇒ String
If present, indicates the Amazon Web Services KMS Encryption Context to use for object encryption.
-
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
-
#version_id ⇒ String
Version ID of the newly created copy.
Instance Attribute Details
#bucket_key_enabled ⇒ Boolean
Indicates whether the copied object uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#copy_object_result ⇒ Types::CopyObjectResult
Container for all response elements.
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#copy_source_version_id ⇒ String
Version ID of the source object that was copied.
<note markdown=“1”> This functionality is not supported when the source object is in a directory bucket.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#expiration ⇒ String
If the object expiration is configured, the response includes this header.
<note markdown=“1”> Object expiration information is not returned in directory buckets and this header returns the value “‘NotImplemented`” in all responses for directory buckets.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
<note markdown=“1”> When accessing data stored in Amazon FSx file systems using S3 access points, the only valid server side encryption option is ‘aws:fsx`.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that’s used.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#ssekms_encryption_context ⇒ String
If present, indicates the Amazon Web Services KMS Encryption Context to use for object encryption. The value of this header is a Base64 encoded UTF-8 string holding JSON with the encryption context key-value pairs.
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |
#version_id ⇒ String
Version ID of the newly created copy.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'lib/aws-sdk-s3/types.rb', line 2066 class CopyObjectOutput < Struct.new( :copy_object_result, :expiration, :copy_source_version_id, :version_id, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :ssekms_encryption_context, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id, :ssekms_encryption_context] include Aws::Structure end |