Class: Aws::S3::Types::CreateBucketMetadataConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::CreateBucketMetadataConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The general purpose bucket that you want to create the metadata configuration for.
-
#checksum_algorithm ⇒ String
The checksum algorithm to use with your metadata configuration.
-
#content_md5 ⇒ String
The ‘Content-MD5` header for the metadata configuration.
-
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to your metadata configuration.
-
#metadata_configuration ⇒ Types::MetadataConfiguration
The contents of your metadata configuration.
Instance Attribute Details
#bucket ⇒ String
The general purpose bucket that you want to create the metadata configuration for.
3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-s3/types.rb', line 3233 class CreateBucketMetadataConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :metadata_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
The checksum algorithm to use with your metadata configuration.
3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-s3/types.rb', line 3233 class CreateBucketMetadataConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :metadata_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The ‘Content-MD5` header for the metadata configuration.
3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-s3/types.rb', line 3233 class CreateBucketMetadataConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :metadata_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to your metadata configuration.
3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-s3/types.rb', line 3233 class CreateBucketMetadataConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :metadata_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#metadata_configuration ⇒ Types::MetadataConfiguration
The contents of your metadata configuration.
3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-s3/types.rb', line 3233 class CreateBucketMetadataConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :metadata_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |