Class: Aws::S3::Types::CreateBucketOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_arnString

The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.

This parameter is only supported for S3 directory buckets. For more information, see Using tags with directory buckets.

Returns:

  • (String)


3511
3512
3513
3514
3515
3516
# File 'lib/aws-sdk-s3/types.rb', line 3511

class CreateBucketOutput < Struct.new(
  :location,
  :bucket_arn)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

A forward slash followed by the name of the bucket for all account regional namespace buckets and all global general purpose buckets created in us-east-1. For example, /amzn-s3-demo-bucket. For global general purpose buckets created in other Amazon Web Services Regions, the Location field is the global endpoint URL. For example, http://amzn-s3-demo-bucket.s3.amazonaws.com/.

Returns:

  • (String)


3511
3512
3513
3514
3515
3516
# File 'lib/aws-sdk-s3/types.rb', line 3511

class CreateBucketOutput < Struct.new(
  :location,
  :bucket_arn)
  SENSITIVE = []
  include Aws::Structure
end