Class: Aws::S3::Types::CreateBucketRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aclString

The canned ACL to apply to the bucket.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket to create.

**General purpose buckets** - For information about bucket naming restrictions, see [Bucket naming rules][1] in the *Amazon S3 User Guide*.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ‘s3express-control.region-code.amazonaws.com/bucket-name `. Virtual-hosted-style requests aren’t supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format ‘ bucket-base-name–zone-id–x-s3` (for example, ` DOC-EXAMPLE-BUCKET–usw2-az1–x-s3`). For information about bucket naming restrictions, see [Directory bucket naming rules][2] in the *Amazon S3 User Guide*

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-bucket-naming-rules.html

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_namespaceString

Specifies the namespace where you want to create your general purpose bucket. When you create a general purpose bucket, you can choose to create a bucket in the shared global namespace or you can choose to create a bucket in your account regional namespace. Your account regional namespace is a subdivision of the global namespace that only your account can create buckets in. For more information on bucket namespaces, see [Namespaces for general purpose buckets][1].

General purpose buckets in your account regional namespace must follow a specific naming convention. These buckets consist of a bucket name prefix that you create, and a suffix that contains your 12-digit Amazon Web Services Account ID, the Amazon Web Services Region code, and ends with -an. Bucket names must follow the format bucket-name-prefix-accountId-region-an (for example, amzn-s3-demo-bucket-111122223333-us-west-2-an). For information about bucket naming restrictions, see [Account regional namespace naming rules][2] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/gpbucketnamespaces.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html#account-regional-naming-rules

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#create_bucket_configurationTypes::CreateBucketConfiguration

The configuration information for the bucket.



3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#grant_full_controlString

Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#grant_readString

Allows grantee to list the objects in the bucket.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#grant_read_acpString

Allows grantee to read the bucket ACL.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#grant_writeString

Allows grantee to create new objects in the bucket.

For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#grant_write_acpString

Allows grantee to write the ACL for the applicable bucket.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#object_lock_enabled_for_bucketBoolean

Specifies whether you want S3 Object Lock to be enabled for the new bucket.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

Returns:

  • (Boolean)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#object_ownershipString

The container element for object ownership for a bucket’s ownership controls.

BucketOwnerPreferred - Objects uploaded to the bucket change ownership to the bucket owner if the objects are uploaded with the bucket-owner-full-control canned ACL.

ObjectWriter - The uploading account will own the object if the object is uploaded with the bucket-owner-full-control canned ACL.

BucketOwnerEnforced - Access control lists (ACLs) are disabled and no longer affect permissions. The bucket owner automatically owns and has full control over every object in the bucket. The bucket only accepts PUT requests that don’t specify an ACL or specify bucket owner full control ACLs (such as the predefined bucket-owner-full-control canned ACL or a custom ACL in XML format that grants the same permissions).

By default, ObjectOwnership is set to BucketOwnerEnforced and ACLs are disabled. We recommend keeping ACLs disabled, except in uncommon use cases where you must control access for each object individually. For more information about S3 Object Ownership, see [Controlling ownership of objects and disabling ACLs for your bucket][1] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported for directory buckets. Directory buckets use the bucket owner enforced setting for S3 Object Ownership.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/aws-sdk-s3/types.rb', line 3110

class CreateBucketRequest < Struct.new(
  :acl,
  :bucket,
  :create_bucket_configuration,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :object_lock_enabled_for_bucket,
  :object_ownership,
  :bucket_namespace)
  SENSITIVE = []
  include Aws::Structure
end