Class: Aws::S3::Types::DefaultRetention

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The container element for optionally specifying the default Object Lock retention settings for new objects placed in the specified bucket.

* The DefaultRetention settings require both a mode and a period.

  • The DefaultRetention period can be either Days or Years but you must select one. You cannot specify Days and Years at the same time.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#daysInteger

The number of days that you want to specify for the default retention period. Must be used with Mode.

Returns:

  • (Integer)


4797
4798
4799
4800
4801
4802
4803
4804
# File 'lib/aws-sdk-s3/types.rb', line 4797

class DefaultRetention < Struct.new(
  :mode,
  :days,
  :years,
  :default_event_hold)
  SENSITIVE = []
  include Aws::Structure
end

#default_event_holdTypes::EventHoldDuration

The default event hold duration to be applied to new objects placed in the specified bucket. When configured, new objects will automatically have an event hold enabled with this duration.



4797
4798
4799
4800
4801
4802
4803
4804
# File 'lib/aws-sdk-s3/types.rb', line 4797

class DefaultRetention < Struct.new(
  :mode,
  :days,
  :years,
  :default_event_hold)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Must be used with either Days or Years.

Returns:

  • (String)


4797
4798
4799
4800
4801
4802
4803
4804
# File 'lib/aws-sdk-s3/types.rb', line 4797

class DefaultRetention < Struct.new(
  :mode,
  :days,
  :years,
  :default_event_hold)
  SENSITIVE = []
  include Aws::Structure
end

#yearsInteger

The number of years that you want to specify for the default retention period. Must be used with Mode.

Returns:

  • (Integer)


4797
4798
4799
4800
4801
4802
4803
4804
# File 'lib/aws-sdk-s3/types.rb', line 4797

class DefaultRetention < Struct.new(
  :mode,
  :days,
  :years,
  :default_event_hold)
  SENSITIVE = []
  include Aws::Structure
end