Class: Aws::S3::Types::DeleteBucketMetricsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket containing the metrics configuration to delete.

Returns:



4424
4425
4426
4427
4428
4429
4430
# File 'lib/aws-sdk-s3/types.rb', line 4424

class DeleteBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



4424
4425
4426
4427
4428
4429
4430
# File 'lib/aws-sdk-s3/types.rb', line 4424

class DeleteBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.

Returns:



4424
4425
4426
4427
4428
4429
4430
# File 'lib/aws-sdk-s3/types.rb', line 4424

class DeleteBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end