Class: Aws::S3::Types::DeleteBucketOwnershipControlsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The Amazon S3 bucket whose OwnershipControls you want to delete.

Returns:

  • (String)


4445
4446
4447
4448
4449
4450
# File 'lib/aws-sdk-s3/types.rb', line 4445

class DeleteBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


4445
4446
4447
4448
4449
4450
# File 'lib/aws-sdk-s3/types.rb', line 4445

class DeleteBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end