Class: Aws::S3::Types::DeleteBucketReplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name.

Returns:

  • (String)


5181
5182
5183
5184
5185
5186
# File 'lib/aws-sdk-s3/types.rb', line 5181

class DeleteBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


5181
5182
5183
5184
5185
5186
# File 'lib/aws-sdk-s3/types.rb', line 5181

class DeleteBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end