Class: Aws::S3::Types::DeleteBucketTaggingRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket that has the tag set to be removed.

Returns:



4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-s3/types.rb', line 4524

class DeleteBucketTaggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-s3/types.rb', line 4524

class DeleteBucketTaggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end