Class: Aws::S3::Types::DeleteBucketWebsiteRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name for which you want to remove the website configuration.

Returns:



4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-s3/types.rb', line 4588

class DeleteBucketWebsiteRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-s3/types.rb', line 4588

class DeleteBucketWebsiteRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end