Class: Aws::S3::Types::DeleteObjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteObjectOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_marker ⇒ Boolean
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#version_id ⇒ String
Returns the version ID of the delete marker created as a result of the DELETE operation.
Instance Attribute Details
#delete_marker ⇒ Boolean
Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
5409 5410 5411 5412 5413 5414 5415 |
# File 'lib/aws-sdk-s3/types.rb', line 5409 class DeleteObjectOutput < Struct.new( :delete_marker, :version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
5409 5410 5411 5412 5413 5414 5415 |
# File 'lib/aws-sdk-s3/types.rb', line 5409 class DeleteObjectOutput < Struct.new( :delete_marker, :version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Returns the version ID of the delete marker created as a result of the DELETE operation.
5409 5410 5411 5412 5413 5414 5415 |
# File 'lib/aws-sdk-s3/types.rb', line 5409 class DeleteObjectOutput < Struct.new( :delete_marker, :version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |