Method: Aws::S3::Types::DeleteObjectOutput#request_charged
- Defined in:
- lib/aws-sdk-s3/types.rb
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html
4676 4677 4678 4679 4680 4681 4682 |
# File 'lib/aws-sdk-s3/types.rb', line 4676 class DeleteObjectOutput < Struct.new( :delete_marker, :version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |