Class: Aws::S3::Types::DeletePublicAccessBlockRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The Amazon S3 bucket whose PublicAccessBlock configuration you want to delete.



5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-s3/types.rb', line 5945

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).



5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-s3/types.rb', line 5945

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end