Class: Aws::S3::Types::DeletedObject

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Information about the deleted object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delete_markerBoolean

Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.

This functionality is not supported for directory buckets.



5996
5997
5998
5999
6000
6001
6002
6003
# File 'lib/aws-sdk-s3/types.rb', line 5996

class DeletedObject < Struct.new(
  :key,
  :version_id,
  :delete_marker,
  :delete_marker_version_id)
  SENSITIVE = []
  include Aws::Structure
end

#delete_marker_version_idString

The version ID of the delete marker created as a result of the DELETE operation. If you delete a specific object version, the value returned by this header is the version ID of the object version deleted.

This functionality is not supported for directory buckets.



5996
5997
5998
5999
6000
6001
6002
6003
# File 'lib/aws-sdk-s3/types.rb', line 5996

class DeletedObject < Struct.new(
  :key,
  :version_id,
  :delete_marker,
  :delete_marker_version_id)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The name of the deleted object.



5996
5997
5998
5999
6000
6001
6002
6003
# File 'lib/aws-sdk-s3/types.rb', line 5996

class DeletedObject < Struct.new(
  :key,
  :version_id,
  :delete_marker,
  :delete_marker_version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the deleted object.

This functionality is not supported for directory buckets.



5996
5997
5998
5999
6000
6001
6002
6003
# File 'lib/aws-sdk-s3/types.rb', line 5996

class DeletedObject < Struct.new(
  :key,
  :version_id,
  :delete_marker,
  :delete_marker_version_id)
  SENSITIVE = []
  include Aws::Structure
end