Class: Aws::S3::Types::Encryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::Encryption
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Contains the type of server-side encryption used.
Constant Summary collapse
- SENSITIVE =
[:kms_key_id]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256,
aws:kms). -
#kms_context ⇒ String
If the encryption type is
aws:kms, this optional value can be used to specify the encryption context for the restore results. -
#kms_key_id ⇒ String
If the encryption type is
aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results.
Instance Attribute Details
#encryption_type ⇒ String
The server-side encryption algorithm used when storing job results in Amazon S3 (for example, AES256, aws:kms).
5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-s3/types.rb', line 5368 class Encryption < Struct.new( :encryption_type, :kms_key_id, :kms_context) SENSITIVE = [:kms_key_id] include Aws::Structure end |
#kms_context ⇒ String
If the encryption type is aws:kms, this optional value can be used to specify the encryption context for the restore results.
5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-s3/types.rb', line 5368 class Encryption < Struct.new( :encryption_type, :kms_key_id, :kms_context) SENSITIVE = [:kms_key_id] include Aws::Structure end |
#kms_key_id ⇒ String
If the encryption type is aws:kms, this optional value specifies the ID of the symmetric encryption customer managed key to use for encryption of job results. Amazon S3 only supports symmetric encryption KMS keys. For more information, see [Asymmetric keys in KMS] in the *Amazon Web Services Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html
5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-s3/types.rb', line 5368 class Encryption < Struct.new( :encryption_type, :kms_key_id, :kms_context) SENSITIVE = [:kms_key_id] include Aws::Structure end |