Class: Aws::S3::Types::EndEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::EndEvent
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A message that indicates the request is complete and no more messages will be sent. You should not assume that the request is complete until the client receives an EndEvent.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
5423 5424 5425 |
# File 'lib/aws-sdk-s3/types.rb', line 5423 def event_type @event_type end |