Class: Aws::S3::Types::GetBucketAnalyticsConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketAnalyticsConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket from which an analytics configuration is retrieved.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID that identifies the analytics configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket from which an analytics configuration is retrieved.
7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-s3/types.rb', line 7476 class GetBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-s3/types.rb', line 7476 class GetBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID that identifies the analytics configuration.
7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-s3/types.rb', line 7476 class GetBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |