Class: Aws::S3::Types::GetBucketCorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketCorsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name for which to get the cors configuration.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The bucket name for which to get the cors configuration.
When you use this API operation with an access point, provide the alias of the access point in place of the bucket name.
When you use this API operation with an Object Lambda access point, provide the alias of the Object Lambda access point in place of the bucket name. If the Object Lambda access point alias in a request is not valid, the error code ‘InvalidAccessPointAliasError` is returned. For more information about `InvalidAccessPointAliasError`, see [List of Error Codes].
[1]: docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList
6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-s3/types.rb', line 6676 class GetBucketCorsRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-s3/types.rb', line 6676 class GetBucketCorsRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |