Class: Aws::S3::Types::GetBucketIntelligentTieringConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.

Returns:

  • (String)


7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-s3/types.rb', line 7615

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-s3/types.rb', line 7615

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the S3 Intelligent-Tiering configuration.

Returns:

  • (String)


7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-s3/types.rb', line 7615

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end