Class: Aws::S3::Types::GetBucketLifecycleConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rulesArray<Types::LifecycleRule>

Container for a lifecycle rule.

Returns:



7622
7623
7624
7625
7626
7627
# File 'lib/aws-sdk-s3/types.rb', line 7622

class GetBucketLifecycleConfigurationOutput < Struct.new(
  :rules,
  :transition_default_minimum_object_size)
  SENSITIVE = []
  include Aws::Structure
end

#transition_default_minimum_object_sizeString

Indicates which default minimum object size behavior is applied to the lifecycle configuration.

This parameter applies to general purpose buckets only. It isn't supported for directory bucket lifecycle configurations.

  • all_storage_classes_128K - Objects smaller than 128 KB will not transition to any storage class by default.

  • varies_by_storage_class - Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.

To customize the minimum object size for any transition you can add a filter that specifies a custom ObjectSizeGreaterThan or ObjectSizeLessThan in the body of your transition rule. Custom filters always take precedence over the default transition behavior.

Returns:

  • (String)


7622
7623
7624
7625
7626
7627
# File 'lib/aws-sdk-s3/types.rb', line 7622

class GetBucketLifecycleConfigurationOutput < Struct.new(
  :rules,
  :transition_default_minimum_object_size)
  SENSITIVE = []
  include Aws::Structure
end