Class: Aws::S3::Types::GetBucketLifecycleConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketLifecycleConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket for which to get the lifecycle information.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket for which to get the lifecycle information.
6910 6911 6912 6913 6914 6915 |
# File 'lib/aws-sdk-s3/types.rb', line 6910 class GetBucketLifecycleConfigurationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
<note markdown=“1”> This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
</note>
6910 6911 6912 6913 6914 6915 |
# File 'lib/aws-sdk-s3/types.rb', line 6910 class GetBucketLifecycleConfigurationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |