Class: Aws::S3::Types::GetBucketLoggingOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketLoggingOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logging_enabled ⇒ Types::LoggingEnabled
Describes where logs are stored and the prefix that Amazon S3 assigns to all log object keys for a bucket.
Instance Attribute Details
#logging_enabled ⇒ Types::LoggingEnabled
Describes where logs are stored and the prefix that Amazon S3 assigns to all log object keys for a bucket. For more information, see PUT Bucket logging in the Amazon S3 API Reference.
7842 7843 7844 7845 7846 |
# File 'lib/aws-sdk-s3/types.rb', line 7842 class GetBucketLoggingOutput < Struct.new( :logging_enabled) SENSITIVE = [] include Aws::Structure end |