Class: Aws::S3::Types::GetBucketLoggingRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name for which to get the logging information.

Returns:

  • (String)


7772
7773
7774
7775
7776
7777
# File 'lib/aws-sdk-s3/types.rb', line 7772

class GetBucketLoggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


7772
7773
7774
7775
7776
7777
# File 'lib/aws-sdk-s3/types.rb', line 7772

class GetBucketLoggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end