Class: Aws::S3::Types::GetBucketMetadataTableConfigurationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The V1 S3 Metadata configuration for a general purpose bucket.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::ErrorDetails

If the CreateBucketMetadataTableConfiguration request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.



7983
7984
7985
7986
7987
7988
7989
# File 'lib/aws-sdk-s3/types.rb', line 7983

class GetBucketMetadataTableConfigurationResult < Struct.new(
  :metadata_table_configuration_result,
  :status,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_table_configuration_resultTypes::MetadataTableConfigurationResult

The V1 S3 Metadata configuration for a general purpose bucket.



7983
7984
7985
7986
7987
7988
7989
# File 'lib/aws-sdk-s3/types.rb', line 7983

class GetBucketMetadataTableConfigurationResult < Struct.new(
  :metadata_table_configuration_result,
  :status,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the metadata table. The status values are:

  • CREATING - The metadata table is in the process of being created in the specified table bucket.

  • ACTIVE - The metadata table has been created successfully, and records are being delivered to the table.

  • FAILED - Amazon S3 is unable to create the metadata table, or Amazon S3 is unable to deliver records. See ErrorDetails for details.



7983
7984
7985
7986
7987
7988
7989
# File 'lib/aws-sdk-s3/types.rb', line 7983

class GetBucketMetadataTableConfigurationResult < Struct.new(
  :metadata_table_configuration_result,
  :status,
  :error)
  SENSITIVE = []
  include Aws::Structure
end