Class: Aws::S3::Types::GetBucketMetricsConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketMetricsConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket containing the metrics configuration to retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the metrics configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket containing the metrics configuration to retrieve.
Directory buckets - When you use this operation with a
directory bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name .
Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local
Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide
7955 7956 7957 7958 7959 7960 7961 |
# File 'lib/aws-sdk-s3/types.rb', line 7955 class GetBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
501 Not Implemented.
7955 7956 7957 7958 7959 7960 7961 |
# File 'lib/aws-sdk-s3/types.rb', line 7955 class GetBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
7955 7956 7957 7958 7959 7960 7961 |
# File 'lib/aws-sdk-s3/types.rb', line 7955 class GetBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |