Class: Aws::S3::Types::GetBucketOwnershipControlsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose ‘OwnershipControls` you want to retrieve.

Returns:

  • (String)


7715
7716
7717
7718
7719
7720
# File 'lib/aws-sdk-s3/types.rb', line 7715

class GetBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


7715
7716
7717
7718
7719
7720
# File 'lib/aws-sdk-s3/types.rb', line 7715

class GetBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end