Class: Aws::S3::Types::GetBucketPolicyStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose policy status you want to retrieve.



8216
8217
8218
8219
8220
8221
# File 'lib/aws-sdk-s3/types.rb', line 8216

class GetBucketPolicyStatusRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).



8216
8217
8218
8219
8220
8221
# File 'lib/aws-sdk-s3/types.rb', line 8216

class GetBucketPolicyStatusRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end