Class: Aws::S3::Types::GetBucketReplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name for which to get the replication information.

Returns:



8249
8250
8251
8252
8253
8254
# File 'lib/aws-sdk-s3/types.rb', line 8249

class GetBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:



8249
8250
8251
8252
8253
8254
# File 'lib/aws-sdk-s3/types.rb', line 8249

class GetBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end