Class: Aws::S3::Types::GetBucketTaggingRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the tagging information.

Returns:

  • (String)


7423
7424
7425
7426
7427
7428
# File 'lib/aws-sdk-s3/types.rb', line 7423

class GetBucketTaggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


7423
7424
7425
7426
7427
7428
# File 'lib/aws-sdk-s3/types.rb', line 7423

class GetBucketTaggingRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end