Class: Aws::S3::Types::GetBucketVersioningOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mfa_deleteString

Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is only returned if the bucket has been configured with MFA delete. If the bucket has never been so configured, this element is not returned.

Returns:

  • (String)


7487
7488
7489
7490
7491
7492
# File 'lib/aws-sdk-s3/types.rb', line 7487

class GetBucketVersioningOutput < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The versioning state of the bucket.

Returns:

  • (String)


7487
7488
7489
7490
7491
7492
# File 'lib/aws-sdk-s3/types.rb', line 7487

class GetBucketVersioningOutput < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end