Class: Aws::S3::Types::GetBucketVersioningRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the versioning information.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
# File 'lib/aws-sdk-s3/types.rb', line 8265

class GetBucketVersioningRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
# File 'lib/aws-sdk-s3/types.rb', line 8265

class GetBucketVersioningRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end