Class: Aws::S3::Types::GetObjectAclOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grantsArray<Types::Grant>

A list of grants.



8437
8438
8439
8440
8441
8442
8443
# File 'lib/aws-sdk-s3/types.rb', line 8437

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#ownerTypes::Owner

Container for the bucket owner's ID.



8437
8438
8439
8440
8441
8442
8443
# File 'lib/aws-sdk-s3/types.rb', line 8437

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.



8437
8438
8439
8440
8441
8442
8443
# File 'lib/aws-sdk-s3/types.rb', line 8437

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end