Class: Aws::S3::Types::GetObjectAttributesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectAttributesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum ⇒ Types::Checksum
The checksum or digest of the object.
-
#delete_marker ⇒ Boolean
Specifies whether the object retrieved was (
true) or was not (false) a delete marker. -
#etag ⇒ String
An ETag is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
-
#last_modified ⇒ Time
Date and time when the object was last modified.
-
#object_parts ⇒ Types::GetObjectAttributesParts
A collection of parts associated with a multipart upload.
-
#object_size ⇒ Integer
The size of the object in bytes.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#storage_class ⇒ String
Provides the storage class information of the object.
-
#version_id ⇒ String
The version ID of the object.
Instance Attribute Details
#checksum ⇒ Types::Checksum
The checksum or digest of the object.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#delete_marker ⇒ Boolean
Specifies whether the object retrieved was (true) or was not
(false) a delete marker. If false, this response header does not
appear in the response. To learn more about delete markers, see
Working with delete markers.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
An ETag is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
Date and time when the object was last modified.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#object_parts ⇒ Types::GetObjectAttributesParts
A collection of parts associated with a multipart upload.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#object_size ⇒ Integer
The size of the object in bytes.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
Provides the storage class information of the object. Amazon S3 returns this header for all objects except for S3 Standard storage class objects.
For more information, see Storage Classes.
EXPRESS_ONEZONE (the S3 Express One Zone storage class) in
Availability Zones and ONEZONE_IA (the S3 One Zone-Infrequent
Access storage class) in Dedicated Local Zones.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the object.
8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 |
# File 'lib/aws-sdk-s3/types.rb', line 8773 class GetObjectAttributesOutput < Struct.new( :delete_marker, :last_modified, :version_id, :request_charged, :etag, :checksum, :object_parts, :storage_class, :object_size) SENSITIVE = [] include Aws::Structure end |