Class: Aws::S3::Types::GetObjectAttributesParts
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectAttributesParts
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A collection of parts associated with a multipart upload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
Indicates whether the returned list of parts is truncated.
-
#max_parts ⇒ Integer
The maximum number of parts allowed in the response.
-
#next_part_number_marker ⇒ Integer
When a list is truncated, this element specifies the last part in the list, as well as the value to use for the
PartNumberMarkerrequest parameter in a subsequent request. -
#part_number_marker ⇒ Integer
The marker for the current part.
-
#parts ⇒ Array<Types::ObjectPart>
A container for elements related to a particular part.
-
#total_parts_count ⇒ Integer
The total number of parts.
Instance Attribute Details
#is_truncated ⇒ Boolean
Indicates whether the returned list of parts is truncated. A value
of true indicates that the list was truncated. A list can be
truncated if the number of parts exceeds the limit returned in the
MaxParts element.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |
#max_parts ⇒ Integer
The maximum number of parts allowed in the response.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |
#next_part_number_marker ⇒ Integer
When a list is truncated, this element specifies the last part in
the list, as well as the value to use for the PartNumberMarker
request parameter in a subsequent request.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |
#part_number_marker ⇒ Integer
The marker for the current part.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |
#parts ⇒ Array<Types::ObjectPart>
A container for elements related to a particular part. A response
can contain zero or more Parts elements.
GetObjectAttributes, if an
additional checksum (including x-amz-checksum-crc32,
x-amz-checksum-crc32c, x-amz-checksum-sha1, or
x-amz-checksum-sha256) isn't applied to the object specified in
the request, the response doesn't return the Part element.
- Directory buckets - For
GetObjectAttributes, regardless of whether an additional checksum is applied to the object specified in the request, the response returns thePartelement.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |
#total_parts_count ⇒ Integer
The total number of parts.
8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-s3/types.rb', line 8744 class GetObjectAttributesParts < Struct.new( :total_parts_count, :part_number_marker, :next_part_number_marker, :max_parts, :is_truncated, :parts) SENSITIVE = [] include Aws::Structure end |