Method: Aws::S3::Types::GetObjectOutput#request_charged

Defined in:
lib/aws-sdk-s3/types.rb

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html

Returns:

  • (String)


8415
8416
8417
8418
8419
8420
8421
8422
8423
8424
8425
8426
8427
8428
8429
8430
8431
8432
8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
# File 'lib/aws-sdk-s3/types.rb', line 8415

class GetObjectOutput < Struct.new(
  :body,
  :delete_marker,
  :accept_ranges,
  :expiration,
  :restore,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_type,
  :missing_meta,
  :version_id,
  :cache_control,
  :content_disposition,
  :content_encoding,
  :content_language,
  :content_range,
  :content_type,
  :expires,
  :expires_string,
  :website_redirect_location,
  :server_side_encryption,
  :metadata,
  :sse_customer_algorithm,
  :sse_customer_key_md5,
  :ssekms_key_id,
  :bucket_key_enabled,
  :storage_class,
  :request_charged,
  :replication_status,
  :parts_count,
  :tag_count,
  :object_lock_mode,
  :object_lock_retain_until_date,
  :object_lock_legal_hold_status)
  SENSITIVE = [:ssekms_key_id]
  include Aws::Structure
end