Method: Aws::S3::Types::GetObjectRequest#if_none_match

Defined in:
lib/aws-sdk-s3/types.rb

#if_none_matchString

Return the object only if its entity tag (ETag) is different from the one specified in this header; otherwise, return a ‘304 Not Modified` error.

If both of the If-None-Match and If-Modified-Since headers are present in the request as follows:‘ If-None-Match` condition evaluates to false, and; If-Modified-Since condition evaluates to true; then, S3 returns `304 Not Modified` HTTP status code.

For more information about conditional requests, see [RFC 7232].

[1]: tools.ietf.org/html/rfc7232

Returns:

  • (String)


8781
8782
8783
8784
8785
8786
8787
8788
8789
8790
8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
8803
8804
8805
# File 'lib/aws-sdk-s3/types.rb', line 8781

class GetObjectRequest < Struct.new(
  :bucket,
  :if_match,
  :if_modified_since,
  :if_none_match,
  :if_unmodified_since,
  :key,
  :range,
  :response_cache_control,
  :response_content_disposition,
  :response_content_encoding,
  :response_content_language,
  :response_content_type,
  :response_expires,
  :version_id,
  :sse_customer_algorithm,
  :sse_customer_key,
  :sse_customer_key_md5,
  :request_payer,
  :part_number,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = [:sse_customer_key]
  include Aws::Structure
end