Method: Aws::S3::Types::GetObjectRequest#if_unmodified_since
- Defined in:
- lib/aws-sdk-s3/types.rb
#if_unmodified_since ⇒ Time
Return the object only if it has not been modified since the specified time; otherwise, return a ‘412 Precondition Failed` error.
If both of the If-Match and If-Unmodified-Since headers are present in the request as follows: If-Match condition evaluates to true, and; If-Unmodified-Since condition evaluates to false; then, S3 returns ‘200 OK` and the data requested.
For more information about conditional requests, see [RFC 7232].
8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 |
# File 'lib/aws-sdk-s3/types.rb', line 8781 class GetObjectRequest < Struct.new( :bucket, :if_match, :if_modified_since, :if_none_match, :if_unmodified_since, :key, :range, :response_cache_control, :response_content_disposition, :response_content_encoding, :response_content_language, :response_content_type, :response_expires, :version_id, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5, :request_payer, :part_number, :expected_bucket_owner, :checksum_mode) SENSITIVE = [:sse_customer_key] include Aws::Structure end |