Class: Aws::S3::Types::GetObjectTorrentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket containing the object for which to get the torrent files.

Returns:

  • (String)


10075
10076
10077
10078
10079
10080
10081
10082
# File 'lib/aws-sdk-s3/types.rb', line 10075

class GetObjectTorrentRequest < Struct.new(
  :bucket,
  :key,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


10075
10076
10077
10078
10079
10080
10081
10082
# File 'lib/aws-sdk-s3/types.rb', line 10075

class GetObjectTorrentRequest < Struct.new(
  :bucket,
  :key,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key for which to get the information.

Returns:

  • (String)


10075
10076
10077
10078
10079
10080
10081
10082
# File 'lib/aws-sdk-s3/types.rb', line 10075

class GetObjectTorrentRequest < Struct.new(
  :bucket,
  :key,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


10075
10076
10077
10078
10079
10080
10081
10082
# File 'lib/aws-sdk-s3/types.rb', line 10075

class GetObjectTorrentRequest < Struct.new(
  :bucket,
  :key,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end