Class: Aws::S3::Types::GetPublicAccessBlockRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetPublicAccessBlockRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose
PublicAccessBlockconfiguration you want to retrieve. -
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to retrieve.
9122 9123 9124 9125 9126 9127 |
# File 'lib/aws-sdk-s3/types.rb', line 9122 class GetPublicAccessBlockRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
9122 9123 9124 9125 9126 9127 |
# File 'lib/aws-sdk-s3/types.rb', line 9122 class GetPublicAccessBlockRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |