Class: Aws::S3::Types::IndexDocument

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Container for the Suffix element.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#suffixString

A suffix that is appended to a request that is for a directory on the website endpoint. (For example, if the suffix is index.html and you make a request to samplebucket/images/, the data that is returned will be for the object with the key name images/index.html.) The suffix must not be empty and must not include a slash character.

Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.



11312
11313
11314
11315
11316
# File 'lib/aws-sdk-s3/types.rb', line 11312

class IndexDocument < Struct.new(
  :suffix)
  SENSITIVE = []
  include Aws::Structure
end