Class: Aws::S3::Types::Initiator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::Initiator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Container element that identifies who initiated the multipart upload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
This functionality is not supported for directory buckets. -
#id ⇒ String
If the principal is an Amazon Web Services account, it provides the Canonical User ID.
Instance Attribute Details
#display_name ⇒ String
11191 11192 11193 11194 11195 11196 |
# File 'lib/aws-sdk-s3/types.rb', line 11191 class Initiator < Struct.new( :id, :display_name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
If the principal is an Amazon Web Services account, it provides the Canonical User ID. If the principal is an IAM User, it provides a user ARN value.
11191 11192 11193 11194 11195 11196 |
# File 'lib/aws-sdk-s3/types.rb', line 11191 class Initiator < Struct.new( :id, :display_name) SENSITIVE = [] include Aws::Structure end |