Class: Aws::S3::Types::IntelligentTieringFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::IntelligentTieringFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
The Filter is used to identify objects that the S3 Intelligent-Tiering configuration applies to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and ⇒ Types::IntelligentTieringAndOperator
A conjunction (logical AND) of predicates, which is used in evaluating a metrics filter.
-
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
-
#tag ⇒ Types::Tag
A container of a key value name pair.
Instance Attribute Details
#and ⇒ Types::IntelligentTieringAndOperator
A conjunction (logical AND) of predicates, which is used in evaluating a metrics filter. The operator must have at least two predicates, and an object must match all of the predicates in order for the filter to apply.
10239 10240 10241 10242 10243 10244 10245 |
# File 'lib/aws-sdk-s3/types.rb', line 10239 class IntelligentTieringFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [ XML related object key constraints].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints
10239 10240 10241 10242 10243 10244 10245 |
# File 'lib/aws-sdk-s3/types.rb', line 10239 class IntelligentTieringFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |
#tag ⇒ Types::Tag
A container of a key value name pair.
10239 10240 10241 10242 10243 10244 10245 |
# File 'lib/aws-sdk-s3/types.rb', line 10239 class IntelligentTieringFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |