Class: Aws::S3::Types::InventoryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies the S3 Inventory configuration for an Amazon S3 bucket. For more information, see [GET Bucket inventory][1] in the *Amazon S3 API Reference*.

[1]: docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketGETInventoryConfig.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationTypes::InventoryDestination

Contains information about where to publish the inventory results.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::InventoryFilter

Specifies an inventory filter. The inventory only includes objects that meet the filter’s criteria.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the inventory configuration.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#included_object_versionsString

Object versions to include in the inventory list. If set to All, the list includes all the object versions, which adds the version-related fields VersionId, IsLatest, and DeleteMarker to the list. If set to Current, the list does not contain these version-related fields.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#is_enabledBoolean

Specifies whether the inventory is enabled or disabled. If set to True, an inventory list is generated. If set to False, no inventory list is generated.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#optional_fieldsArray<String>

Contains the optional fields that are included in the inventory results.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::InventorySchedule

Specifies the schedule for generating inventory results.



10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
# File 'lib/aws-sdk-s3/types.rb', line 10374

class InventoryConfiguration < Struct.new(
  :destination,
  :is_enabled,
  :filter,
  :id,
  :included_object_versions,
  :optional_fields,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end