Class: Aws::S3::Types::LambdaFunctionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

A container for specifying the configuration for Lambda notifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<String>

The Amazon S3 bucket event for which to invoke the Lambda function. For more information, see Supported Event Types in the Amazon S3 User Guide.

Returns:



11973
11974
11975
11976
11977
11978
11979
11980
# File 'lib/aws-sdk-s3/types.rb', line 11973

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::NotificationConfigurationFilter

Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.

Returns:



11973
11974
11975
11976
11977
11978
11979
11980
# File 'lib/aws-sdk-s3/types.rb', line 11973

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#idString

An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.

Returns:



11973
11974
11975
11976
11977
11978
11979
11980
# File 'lib/aws-sdk-s3/types.rb', line 11973

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_function_arnString

The Amazon Resource Name (ARN) of the Lambda function that Amazon S3 invokes when the specified event type occurs.

Returns:



11973
11974
11975
11976
11977
11978
11979
11980
# File 'lib/aws-sdk-s3/types.rb', line 11973

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end