Class: Aws::S3::Types::LifecycleRuleFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::LifecycleRuleFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
The ‘Filter` is used to identify objects that a Lifecycle Rule applies to. A `Filter` can have exactly one of `Prefix`, `Tag`, `ObjectSizeGreaterThan`, `ObjectSizeLessThan`, or `And` specified. If the `Filter` element is left empty, the Lifecycle Rule applies to all objects in the bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and ⇒ Types::LifecycleRuleAndOperator
This is used in a Lifecycle Rule Filter to apply a logical AND to two or more predicates.
-
#object_size_greater_than ⇒ Integer
Minimum object size to which the rule applies.
-
#object_size_less_than ⇒ Integer
Maximum object size to which the rule applies.
-
#prefix ⇒ String
Prefix identifying one or more objects to which the rule applies.
-
#tag ⇒ Types::Tag
This tag must exist in the object’s tag set in order for the rule to apply.
Instance Attribute Details
#and ⇒ Types::LifecycleRuleAndOperator
This is used in a Lifecycle Rule Filter to apply a logical AND to two or more predicates. The Lifecycle Rule will apply to any object matching all of the predicates configured inside the And operator.
10994 10995 10996 10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-s3/types.rb', line 10994 class LifecycleRuleFilter < Struct.new( :prefix, :tag, :object_size_greater_than, :object_size_less_than, :and) SENSITIVE = [] include Aws::Structure end |
#object_size_greater_than ⇒ Integer
Minimum object size to which the rule applies.
10994 10995 10996 10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-s3/types.rb', line 10994 class LifecycleRuleFilter < Struct.new( :prefix, :tag, :object_size_greater_than, :object_size_less_than, :and) SENSITIVE = [] include Aws::Structure end |
#object_size_less_than ⇒ Integer
Maximum object size to which the rule applies.
10994 10995 10996 10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-s3/types.rb', line 10994 class LifecycleRuleFilter < Struct.new( :prefix, :tag, :object_size_greater_than, :object_size_less_than, :and) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
Prefix identifying one or more objects to which the rule applies.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [ XML related object key constraints].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints
10994 10995 10996 10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-s3/types.rb', line 10994 class LifecycleRuleFilter < Struct.new( :prefix, :tag, :object_size_greater_than, :object_size_less_than, :and) SENSITIVE = [] include Aws::Structure end |
#tag ⇒ Types::Tag
This tag must exist in the object’s tag set in order for the rule to apply.
<note markdown=“1”> This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
</note>
10994 10995 10996 10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-s3/types.rb', line 10994 class LifecycleRuleFilter < Struct.new( :prefix, :tag, :object_size_greater_than, :object_size_less_than, :and) SENSITIVE = [] include Aws::Structure end |