Class: Aws::S3::Types::ListBucketAnalyticsConfigurationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configuration_listArray<Types::AnalyticsConfiguration>

The list of analytics configurations for a bucket.

Returns:



12286
12287
12288
12289
12290
12291
12292
12293
# File 'lib/aws-sdk-s3/types.rb', line 12286

class ListBucketAnalyticsConfigurationsOutput < Struct.new(
  :is_truncated,
  :continuation_token,
  :next_continuation_token,
  :analytics_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#continuation_tokenString

The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.

Returns:

  • (String)


12286
12287
12288
12289
12290
12291
12292
12293
# File 'lib/aws-sdk-s3/types.rb', line 12286

class ListBucketAnalyticsConfigurationsOutput < Struct.new(
  :is_truncated,
  :continuation_token,
  :next_continuation_token,
  :analytics_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#is_truncatedBoolean

Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.

Returns:

  • (Boolean)


12286
12287
12288
12289
12290
12291
12292
12293
# File 'lib/aws-sdk-s3/types.rb', line 12286

class ListBucketAnalyticsConfigurationsOutput < Struct.new(
  :is_truncated,
  :continuation_token,
  :next_continuation_token,
  :analytics_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_continuation_tokenString

NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.

Returns:

  • (String)


12286
12287
12288
12289
12290
12291
12292
12293
# File 'lib/aws-sdk-s3/types.rb', line 12286

class ListBucketAnalyticsConfigurationsOutput < Struct.new(
  :is_truncated,
  :continuation_token,
  :next_continuation_token,
  :analytics_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end