Class: Aws::S3::Types::ListBucketAnalyticsConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket from which analytics configurations are retrieved.

Returns:

  • (String)


12314
12315
12316
12317
12318
12319
12320
# File 'lib/aws-sdk-s3/types.rb', line 12314

class ListBucketAnalyticsConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#continuation_tokenString

The ContinuationToken that represents a placeholder from where this request should begin.

Returns:

  • (String)


12314
12315
12316
12317
12318
12319
12320
# File 'lib/aws-sdk-s3/types.rb', line 12314

class ListBucketAnalyticsConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


12314
12315
12316
12317
12318
12319
12320
# File 'lib/aws-sdk-s3/types.rb', line 12314

class ListBucketAnalyticsConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end