Class: Aws::S3::Types::ListBucketIntelligentTieringConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListBucketIntelligentTieringConfigurationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
-
#continuation_token ⇒ String
The
ContinuationTokenthat represents a placeholder from where this request should begin. -
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
12375 12376 12377 12378 12379 12380 12381 |
# File 'lib/aws-sdk-s3/types.rb', line 12375 class ListBucketIntelligentTieringConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
The ContinuationToken that represents a placeholder from where
this request should begin.
12375 12376 12377 12378 12379 12380 12381 |
# File 'lib/aws-sdk-s3/types.rb', line 12375 class ListBucketIntelligentTieringConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
12375 12376 12377 12378 12379 12380 12381 |
# File 'lib/aws-sdk-s3/types.rb', line 12375 class ListBucketIntelligentTieringConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |