Class: Aws::S3::Types::ListDirectoryBucketsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListDirectoryBucketsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#buckets ⇒ Array<Types::Bucket>
The list of buckets owned by the requester.
-
#continuation_token ⇒ String
If
ContinuationTokenwas sent with the request, it is included in the response.
Instance Attribute Details
#buckets ⇒ Array<Types::Bucket>
The list of buckets owned by the requester.
11368 11369 11370 11371 11372 11373 |
# File 'lib/aws-sdk-s3/types.rb', line 11368 class ListDirectoryBucketsOutput < Struct.new( :buckets, :continuation_token) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
If ContinuationToken was sent with the request, it is included in the response. You can use the returned ContinuationToken for pagination of the list response.
11368 11369 11370 11371 11372 11373 |
# File 'lib/aws-sdk-s3/types.rb', line 11368 class ListDirectoryBucketsOutput < Struct.new( :buckets, :continuation_token) SENSITIVE = [] include Aws::Structure end |