Class: Aws::S3::Types::ListDirectoryBucketsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#continuation_tokenString

ContinuationToken indicates to Amazon S3 that the list is being continued on buckets in this account with a token. ContinuationToken is obfuscated and is not a real bucket name. You can use this ContinuationToken for the pagination of the list results.

Returns:

  • (String)


11426
11427
11428
11429
11430
11431
# File 'lib/aws-sdk-s3/types.rb', line 11426

class ListDirectoryBucketsRequest < Struct.new(
  :continuation_token,
  :max_directory_buckets)
  SENSITIVE = []
  include Aws::Structure
end

#max_directory_bucketsInteger

Maximum number of buckets to be returned in response. When the number is more than the count of buckets that are owned by an Amazon Web Services account, return all the buckets in response.

Returns:

  • (Integer)


11426
11427
11428
11429
11430
11431
# File 'lib/aws-sdk-s3/types.rb', line 11426

class ListDirectoryBucketsRequest < Struct.new(
  :continuation_token,
  :max_directory_buckets)
  SENSITIVE = []
  include Aws::Structure
end