Class: Aws::S3::Types::ListObjectAnnotationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_countInteger

The number of annotations returned.

Returns:

  • (Integer)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#annotation_prefixString

The prefix used to filter the response.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#annotationsArray<Types::AnnotationEntry>

The list of annotations attached to the object.

Returns:



13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The bucket name.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#continuation_tokenString

The continuation token used in this request.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#max_annotation_resultsInteger

The maximum number of annotations returned in the response.

Returns:

  • (Integer)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#next_continuation_tokenString

The continuation token to use to retrieve the next page of results.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#object_version_idString

The version ID of the object.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
# File 'lib/aws-sdk-s3/types.rb', line 13068

class ListObjectAnnotationsOutput < Struct.new(
  :annotations,
  :bucket,
  :key,
  :object_version_id,
  :annotation_prefix,
  :max_annotation_results,
  :annotation_count,
  :continuation_token,
  :next_continuation_token,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end