Class: Aws::S3::Types::ListObjectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListObjectsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket containing the objects.
-
#delimiter ⇒ String
A delimiter is a character that you use to group keys.
-
#encoding_type ⇒ String
Encoding type used by Amazon S3 to encode the [object keys][1] in the response.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#marker ⇒ String
Marker is where you want Amazon S3 to start listing from.
-
#max_keys ⇒ Integer
Sets the maximum number of keys returned in the response.
-
#optional_object_attributes ⇒ Array<String>
Specifies the optional fields that you want returned in the response.
-
#prefix ⇒ String
Limits the response to keys that begin with the specified prefix.
-
#request_payer ⇒ String
Confirms that the requester knows that she or he will be charged for the list objects request.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket containing the objects.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style
requests are not supported. Directory bucket names must be unique in
the chosen Zone (Availability Zone or Local Zone). Bucket names must
follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide.
Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts,
you must direct requests to the S3 on Outposts hostname. The S3 on
Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket
must be the Outposts access point ARN or the access point alias. For
more information about S3 on Outposts, see What is S3 on
Outposts? in the Amazon S3 User Guide.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A delimiter is a character that you use to group keys.
CommonPrefixes is filtered out from results if it is not
lexicographically greater than the key-marker.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#encoding_type ⇒ String
Encoding type used by Amazon S3 to encode the object keys in the response. Responses are encoded only in UTF-8. An object key can contain any Unicode character. However, the XML 1.0 parser can't parse certain characters, such as characters with an ASCII value from 0 to 10. For characters that aren't supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response. For more information about characters to avoid in object key names, see Object key naming guidelines.
test_file(3).png will appear
as test_file%283%29.png.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Marker is where you want Amazon S3 to start listing from. Amazon S3 starts listing after this specified key. Marker can be any key in the bucket.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#max_keys ⇒ Integer
Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#optional_object_attributes ⇒ Array<String>
Specifies the optional fields that you want returned in the response. Fields that you do not specify are not returned.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
Limits the response to keys that begin with the specified prefix.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |
#request_payer ⇒ String
Confirms that the requester knows that she or he will be charged for the list objects request. Bucket owners need not specify this parameter in their requests.
13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 13625 13626 13627 |
# File 'lib/aws-sdk-s3/types.rb', line 13615 class ListObjectsRequest < Struct.new( :bucket, :delimiter, :encoding_type, :marker, :max_keys, :prefix, :request_payer, :expected_bucket_owner, :optional_object_attributes) SENSITIVE = [] include Aws::Structure end |