Class: Aws::S3::Types::LocationInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies the location where the bucket will be created.

For directory buckets, the location type is Availability Zone or Local Zone. For more information about directory buckets, see Working with directory buckets in the Amazon S3 User Guide.

This functionality is only supported by directory buckets.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the location where the bucket will be created.

For directory buckets, the name of the location is the Zone ID of the Availability Zone (AZ) or Local Zone (LZ) where the bucket will be created. An example AZ ID value is usw2-az1.

Returns:

  • (String)


14300
14301
14302
14303
14304
14305
# File 'lib/aws-sdk-s3/types.rb', line 14300

class LocationInfo < Struct.new(
  :type,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of location where the bucket will be created.

Returns:

  • (String)


14300
14301
14302
14303
14304
14305
# File 'lib/aws-sdk-s3/types.rb', line 14300

class LocationInfo < Struct.new(
  :type,
  :name)
  SENSITIVE = []
  include Aws::Structure
end