Class: Aws::S3::Types::MetadataTableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The V1 S3 Metadata configuration for a general purpose bucket.

If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using CreateBucketMetadataConfiguration so that you can expire journal table records and create a live inventory table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_tables_destinationTypes::S3TablesDestination

The destination information for the metadata table configuration. The destination table bucket must be in the same Region and Amazon Web Services account as the general purpose bucket. The specified metadata table name must be unique within the aws_s3_metadata namespace in the destination table bucket.



14307
14308
14309
14310
14311
# File 'lib/aws-sdk-s3/types.rb', line 14307

class MetadataTableConfiguration < Struct.new(
  :s3_tables_destination)
  SENSITIVE = []
  include Aws::Structure
end