Class: Aws::S3::Types::NoSuchAnnotation
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::S3::Types::NoSuchAnnotation
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
The specified annotation does not exist on this object.
The specified annotation does not exist on this object.