Class: Aws::S3::Types::NoncurrentVersionExpiration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::NoncurrentVersionExpiration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass NoncurrentVersionExpiration data as a hash:
{
noncurrent_days: 1,
}Specifies when noncurrent object versions expire. Upon expiration, Amazon S3 permanently deletes the noncurrent object versions. You set this lifecycle configuration action on a bucket that has versioning enabled (or suspended) to request that Amazon S3 delete noncurrent object versions at a specific period in the object's lifetime.
Instance Attribute Summary collapse
-
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
Instance Attribute Details
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see How Amazon S3 Calculates When an Object Became Noncurrent in the Amazon Simple Storage Service Developer Guide.
5350 5351 5352 5353 |
# File 'lib/aws-sdk-s3/types.rb', line 5350 class NoncurrentVersionExpiration < Struct.new( :noncurrent_days) include Aws::Structure end |