Class: Aws::S3::Types::NoncurrentVersionTransition
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::NoncurrentVersionTransition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass NoncurrentVersionTransition data as a hash:
{
noncurrent_days: 1,
storage_class: "GLACIER", # accepts GLACIER, STANDARD_IA, ONEZONE_IA
}Container for the transition rule that describes when noncurrent objects transition to the STANDARD_IA, ONEZONE_IA or GLACIER storage class. If your bucket is versioning-enabled (or versioning is suspended), you can set this action to request that Amazon S3 transition noncurrent object versions to the STANDARD_IA, ONEZONE_IA or GLACIER storage class at a specific period in the object's lifetime.
Instance Attribute Summary collapse
-
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
-
#storage_class ⇒ String
The class of storage used to store the object.
Instance Attribute Details
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see How Amazon S3 Calculates When an Object Became Noncurrent in the Amazon Simple Storage Service Developer Guide.
5389 5390 5391 5392 5393 |
# File 'lib/aws-sdk-s3/types.rb', line 5389 class NoncurrentVersionTransition < Struct.new( :noncurrent_days, :storage_class) include Aws::Structure end |
#storage_class ⇒ String
The class of storage used to store the object.
5389 5390 5391 5392 5393 |
# File 'lib/aws-sdk-s3/types.rb', line 5389 class NoncurrentVersionTransition < Struct.new( :noncurrent_days, :storage_class) include Aws::Structure end |