Class: Aws::S3::Types::ObjectIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ObjectIdentifier
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Object Identifier is unique value to identify objects.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#etag ⇒ String
An entity tag (ETag) is an identifier assigned by a web server to a specific version of a resource found at a URL.
-
#key ⇒ String
Key name of the object.
-
#last_modified_time ⇒ Time
If present, the objects are deleted only if its modification times matches the provided
Timestamp. -
#size ⇒ Integer
If present, the objects are deleted only if its size matches the provided size in bytes.
-
#version_id ⇒ String
Version ID for the specific version of the object to delete.
Instance Attribute Details
#etag ⇒ String
An entity tag (ETag) is an identifier assigned by a web server to a
specific version of a resource found at a URL. This header field
makes the request method conditional on ETags.
15131 15132 15133 15134 15135 15136 15137 15138 15139 |
# File 'lib/aws-sdk-s3/types.rb', line 15131 class ObjectIdentifier < Struct.new( :key, :version_id, :etag, :last_modified_time, :size) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
Key name of the object.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.
15131 15132 15133 15134 15135 15136 15137 15138 15139 |
# File 'lib/aws-sdk-s3/types.rb', line 15131 class ObjectIdentifier < Struct.new( :key, :version_id, :etag, :last_modified_time, :size) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
If present, the objects are deleted only if its modification times
matches the provided Timestamp.
15131 15132 15133 15134 15135 15136 15137 15138 15139 |
# File 'lib/aws-sdk-s3/types.rb', line 15131 class ObjectIdentifier < Struct.new( :key, :version_id, :etag, :last_modified_time, :size) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
If present, the objects are deleted only if its size matches the provided size in bytes.
15131 15132 15133 15134 15135 15136 15137 15138 15139 |
# File 'lib/aws-sdk-s3/types.rb', line 15131 class ObjectIdentifier < Struct.new( :key, :version_id, :etag, :last_modified_time, :size) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Version ID for the specific version of the object to delete.
15131 15132 15133 15134 15135 15136 15137 15138 15139 |
# File 'lib/aws-sdk-s3/types.rb', line 15131 class ObjectIdentifier < Struct.new( :key, :version_id, :etag, :last_modified_time, :size) SENSITIVE = [] include Aws::Structure end |