Class: Aws::S3::Types::ObjectLockRetention
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ObjectLockRetention
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A Retention configuration for an object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_hold ⇒ String
The event hold status for the object.
-
#event_hold_duration ⇒ Types::EventHoldDuration
The event hold duration for the object.
-
#mode ⇒ String
Indicates the Retention mode for the specified object.
-
#retain_until_date ⇒ Time
The date on which this Object Lock Retention will expire.
Instance Attribute Details
#event_hold ⇒ String
The event hold status for the object. Set to ON to enable an event
hold or OFF to disable it.
15202 15203 15204 15205 15206 15207 15208 15209 |
# File 'lib/aws-sdk-s3/types.rb', line 15202 class ObjectLockRetention < Struct.new( :mode, :retain_until_date, :event_hold, :event_hold_duration) SENSITIVE = [] include Aws::Structure end |
#event_hold_duration ⇒ Types::EventHoldDuration
The event hold duration for the object. Specifies how long the object remains protected after the event hold is released.
15202 15203 15204 15205 15206 15207 15208 15209 |
# File 'lib/aws-sdk-s3/types.rb', line 15202 class ObjectLockRetention < Struct.new( :mode, :retain_until_date, :event_hold, :event_hold_duration) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Indicates the Retention mode for the specified object.
15202 15203 15204 15205 15206 15207 15208 15209 |
# File 'lib/aws-sdk-s3/types.rb', line 15202 class ObjectLockRetention < Struct.new( :mode, :retain_until_date, :event_hold, :event_hold_duration) SENSITIVE = [] include Aws::Structure end |
#retain_until_date ⇒ Time
The date on which this Object Lock Retention will expire.
15202 15203 15204 15205 15206 15207 15208 15209 |
# File 'lib/aws-sdk-s3/types.rb', line 15202 class ObjectLockRetention < Struct.new( :mode, :retain_until_date, :event_hold, :event_hold_duration) SENSITIVE = [] include Aws::Structure end |