Class: Aws::S3::Types::ObjectLockRule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The container element for an Object Lock rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_retentionTypes::DefaultRetention

The default Object Lock retention settings for new objects in this bucket. You can specify:

  • A default retention period, by using Days or Years.

  • A default event hold duration, by using DefaultEventHold. This setting also uses days or years.

You can set one or both. You cannot use days and years in the same setting.



15228
15229
15230
15231
15232
# File 'lib/aws-sdk-s3/types.rb', line 15228

class ObjectLockRule < Struct.new(
  :default_retention)
  SENSITIVE = []
  include Aws::Structure
end