Class: Aws::S3::Types::ObjectPart

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

A container for elements related to an individual part.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksum_crc32String

The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32cString

The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32C` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc64nvmeString

The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC64NVME` checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, `CRC64NVME`, to the uploaded object). For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_md5String

The Base64 encoded, 128-bit ‘MD5` digest of the part. This checksum is present if the multipart upload request was created with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha1String

The Base64 encoded, 160-bit ‘SHA1` checksum of the part. This checksum is present if the multipart upload request was created with the `SHA1` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha256String

The Base64 encoded, 256-bit ‘SHA256` checksum of the part. This checksum is present if the multipart upload request was created with the `SHA256` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha512String

The Base64 encoded, 512-bit ‘SHA512` digest of the part. This checksum is present if the multipart upload request was created with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash128String

The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH128` checksum algorithm. For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash3String

The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH3` checksum algorithm. For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash64String

The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH64` checksum algorithm. For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#part_numberInteger

The part number identifying the part. This value is a positive integer between 1 and 10,000.

Returns:

  • (Integer)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The size of the uploaded part in bytes.

Returns:

  • (Integer)


14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-s3/types.rb', line 14552

class ObjectPart < Struct.new(
  :part_number,
  :size,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128)
  SENSITIVE = []
  include Aws::Structure
end