Class: Aws::S3::Types::PartitionedPrefix
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PartitionedPrefix
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Amazon S3 keys for log objects are partitioned in the following format:
[DestinationPrefix][SourceAccountId]/[SourceRegion]/[SourceBucket]/[YYYY]/[MM]/[DD]/[YYYY]-[MM]-[DD]-[hh]-[mm]-[ss]-[UniqueString]
PartitionedPrefix defaults to EventTime delivery when server access logs are delivered.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#partition_date_source ⇒ String
Specifies the partition date source for the partitioned prefix.
Instance Attribute Details
#partition_date_source ⇒ String
Specifies the partition date source for the partitioned prefix.
PartitionDateSource can be EventTime or DeliveryTime.
For DeliveryTime, the time in the log file names corresponds to
the delivery time for the log files.
For EventTime, The logs delivered are for a specific day only. The
year, month, and day correspond to the day on which the event
occurred, and the hour, minutes and seconds are set to 00 in the
key.
15758 15759 15760 15761 15762 |
# File 'lib/aws-sdk-s3/types.rb', line 15758 class PartitionedPrefix < Struct.new( :partition_date_source) SENSITIVE = [] include Aws::Structure end |