Class: Aws::S3::Types::PublicAccessBlockConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PublicAccessBlockConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass PublicAccessBlockConfiguration data as a hash:
{
block_public_acls: false,
ignore_public_acls: false,
block_public_policy: false,
restrict_public_buckets: false,
}
Instance Attribute Summary collapse
-
#block_public_acls ⇒ Boolean
Specifies whether Amazon S3 should block public access control lists (ACLs) for this bucket and objects in this bucket.
-
#block_public_policy ⇒ Boolean
Specifies whether Amazon S3 should block public bucket policies for this bucket.
-
#ignore_public_acls ⇒ Boolean
Specifies whether Amazon S3 should ignore public ACLs for this bucket and objects in this bucket.
-
#restrict_public_buckets ⇒ Boolean
Specifies whether Amazon S3 should restrict public bucket policies for this bucket.
Instance Attribute Details
#block_public_acls ⇒ Boolean
Specifies whether Amazon S3 should block public access control lists
(ACLs) for this bucket and objects in this bucket. Setting this
element to TRUE causes the following behavior:
-
PUT Bucket acl and PUT Object acl calls fail if the specified ACL is public.
-
PUT Object calls fail if the request includes a public ACL.
Enabling this setting doesn't affect existing policies or ACLs.
6431 6432 6433 6434 6435 6436 6437 |
# File 'lib/aws-sdk-s3/types.rb', line 6431 class PublicAccessBlockConfiguration < Struct.new( :block_public_acls, :ignore_public_acls, :block_public_policy, :restrict_public_buckets) include Aws::Structure end |
#block_public_policy ⇒ Boolean
Specifies whether Amazon S3 should block public bucket policies for
this bucket. Setting this element to TRUE causes Amazon S3 to
reject calls to PUT Bucket policy if the specified bucket policy
allows public access.
Enabling this setting doesn't affect existing bucket policies.
6431 6432 6433 6434 6435 6436 6437 |
# File 'lib/aws-sdk-s3/types.rb', line 6431 class PublicAccessBlockConfiguration < Struct.new( :block_public_acls, :ignore_public_acls, :block_public_policy, :restrict_public_buckets) include Aws::Structure end |
#ignore_public_acls ⇒ Boolean
Specifies whether Amazon S3 should ignore public ACLs for this
bucket and objects in this bucket. Setting this element to TRUE
causes Amazon S3 to ignore all public ACLs on this bucket and
objects in this bucket.
Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
6431 6432 6433 6434 6435 6436 6437 |
# File 'lib/aws-sdk-s3/types.rb', line 6431 class PublicAccessBlockConfiguration < Struct.new( :block_public_acls, :ignore_public_acls, :block_public_policy, :restrict_public_buckets) include Aws::Structure end |
#restrict_public_buckets ⇒ Boolean
Specifies whether Amazon S3 should restrict public bucket policies
for this bucket. Setting this element to TRUE restricts access to
this bucket to only AWS services and authorized users within this
account if the bucket has a public policy.
Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
6431 6432 6433 6434 6435 6436 6437 |
# File 'lib/aws-sdk-s3/types.rb', line 6431 class PublicAccessBlockConfiguration < Struct.new( :block_public_acls, :ignore_public_acls, :block_public_policy, :restrict_public_buckets) include Aws::Structure end |