Class: Aws::S3::Types::PutBucketAccelerateConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketAccelerateConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerate_configuration ⇒ Types::AccelerateConfiguration
Container for setting the transfer acceleration state.
-
#bucket ⇒ String
The name of the bucket for which the accelerate configuration is set.
-
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#accelerate_configuration ⇒ Types::AccelerateConfiguration
Container for setting the transfer acceleration state.
14421 14422 14423 14424 14425 14426 14427 14428 |
# File 'lib/aws-sdk-s3/types.rb', line 14421 class PutBucketAccelerateConfigurationRequest < Struct.new( :bucket, :accelerate_configuration, :expected_bucket_owner, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket for which the accelerate configuration is set.
14421 14422 14423 14424 14425 14426 14427 14428 |
# File 'lib/aws-sdk-s3/types.rb', line 14421 class PutBucketAccelerateConfigurationRequest < Struct.new( :bucket, :accelerate_configuration, :expected_bucket_owner, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ‘400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
14421 14422 14423 14424 14425 14426 14427 14428 |
# File 'lib/aws-sdk-s3/types.rb', line 14421 class PutBucketAccelerateConfigurationRequest < Struct.new( :bucket, :accelerate_configuration, :expected_bucket_owner, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
14421 14422 14423 14424 14425 14426 14427 14428 |
# File 'lib/aws-sdk-s3/types.rb', line 14421 class PutBucketAccelerateConfigurationRequest < Struct.new( :bucket, :accelerate_configuration, :expected_bucket_owner, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |