Class: Aws::S3::Types::PutBucketAclRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_control_policyTypes::AccessControlPolicy

Contains the elements that set the ACL permissions for an object per grantee.



16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#aclString

The canned ACL to apply to the bucket.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The bucket to which to apply the ACL.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The Base64 encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#grant_full_controlString

Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#grant_readString

Allows grantee to list the objects in the bucket.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#grant_read_acpString

Allows grantee to read the bucket ACL.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#grant_writeString

Allows grantee to create new objects in the bucket.

For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#grant_write_acpString

Allows grantee to write the ACL for the applicable bucket.

Returns:

  • (String)


16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/aws-sdk-s3/types.rb', line 16063

class PutBucketAclRequest < Struct.new(
  :acl,
  :access_control_policy,
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :grant_full_control,
  :grant_read,
  :grant_read_acp,
  :grant_write,
  :grant_write_acp,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end