Class: Aws::S3::Types::PutBucketAnalyticsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configurationTypes::AnalyticsConfiguration

The configuration and any analyses for the analytics filter.

Returns:



16101
16102
16103
16104
16105
16106
16107
16108
# File 'lib/aws-sdk-s3/types.rb', line 16101

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket to which an analytics configuration is stored.

Returns:



16101
16102
16103
16104
16105
16106
16107
16108
# File 'lib/aws-sdk-s3/types.rb', line 16101

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:



16101
16102
16103
16104
16105
16106
16107
16108
# File 'lib/aws-sdk-s3/types.rb', line 16101

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID that identifies the analytics configuration.

Returns:



16101
16102
16103
16104
16105
16106
16107
16108
# File 'lib/aws-sdk-s3/types.rb', line 16101

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end