Class: Aws::S3::Types::PutBucketCorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketCorsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
Specifies the bucket impacted by the ‘cors`configuration.
-
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK.
-
#content_md5 ⇒ String
The Base64 encoded 128-bit
MD5digest of the data. -
#cors_configuration ⇒ Types::CORSConfiguration
Describes the cross-origin access configuration for objects in an Amazon S3 bucket.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
Specifies the bucket impacted by the ‘cors`configuration.
14574 14575 14576 14577 14578 14579 14580 14581 14582 |
# File 'lib/aws-sdk-s3/types.rb', line 14574 class PutBucketCorsRequest < Struct.new( :bucket, :cors_configuration, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ‘400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
14574 14575 14576 14577 14578 14579 14580 14581 14582 |
# File 'lib/aws-sdk-s3/types.rb', line 14574 class PutBucketCorsRequest < Struct.new( :bucket, :cors_configuration, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The Base64 encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to [RFC 1864.]
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
14574 14575 14576 14577 14578 14579 14580 14581 14582 |
# File 'lib/aws-sdk-s3/types.rb', line 14574 class PutBucketCorsRequest < Struct.new( :bucket, :cors_configuration, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#cors_configuration ⇒ Types::CORSConfiguration
Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see [Enabling Cross-Origin Resource Sharing] in the *Amazon S3 User Guide*.
14574 14575 14576 14577 14578 14579 14580 14581 14582 |
# File 'lib/aws-sdk-s3/types.rb', line 14574 class PutBucketCorsRequest < Struct.new( :bucket, :cors_configuration, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
14574 14575 14576 14577 14578 14579 14580 14581 14582 |
# File 'lib/aws-sdk-s3/types.rb', line 14574 class PutBucketCorsRequest < Struct.new( :bucket, :cors_configuration, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |