Class: Aws::S3::Types::PutBucketInventoryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketInventoryConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket where the inventory configuration will be stored.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the inventory configuration.
-
#inventory_configuration ⇒ Types::InventoryConfiguration
Specifies the inventory configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket where the inventory configuration will be stored.
14758 14759 14760 14761 14762 14763 14764 14765 |
# File 'lib/aws-sdk-s3/types.rb', line 14758 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
14758 14759 14760 14761 14762 14763 14764 14765 |
# File 'lib/aws-sdk-s3/types.rb', line 14758 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the inventory configuration.
14758 14759 14760 14761 14762 14763 14764 14765 |
# File 'lib/aws-sdk-s3/types.rb', line 14758 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#inventory_configuration ⇒ Types::InventoryConfiguration
Specifies the inventory configuration.
14758 14759 14760 14761 14762 14763 14764 14765 |
# File 'lib/aws-sdk-s3/types.rb', line 14758 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |