Class: Aws::S3::Types::PutBucketLoggingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketLoggingRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket for which to set the logging parameters.
-
#bucket_logging_status ⇒ Types::BucketLoggingStatus
Container for logging status information.
-
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK.
-
#content_md5 ⇒ String
The MD5 hash of the
PutBucketLoggingrequest body. -
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket for which to set the logging parameters.
14924 14925 14926 14927 14928 14929 14930 14931 14932 |
# File 'lib/aws-sdk-s3/types.rb', line 14924 class PutBucketLoggingRequest < Struct.new( :bucket, :bucket_logging_status, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket_logging_status ⇒ Types::BucketLoggingStatus
Container for logging status information.
14924 14925 14926 14927 14928 14929 14930 14931 14932 |
# File 'lib/aws-sdk-s3/types.rb', line 14924 class PutBucketLoggingRequest < Struct.new( :bucket, :bucket_logging_status, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ‘400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
14924 14925 14926 14927 14928 14929 14930 14931 14932 |
# File 'lib/aws-sdk-s3/types.rb', line 14924 class PutBucketLoggingRequest < Struct.new( :bucket, :bucket_logging_status, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The MD5 hash of the PutBucketLogging request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
14924 14925 14926 14927 14928 14929 14930 14931 14932 |
# File 'lib/aws-sdk-s3/types.rb', line 14924 class PutBucketLoggingRequest < Struct.new( :bucket, :bucket_logging_status, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
14924 14925 14926 14927 14928 14929 14930 14931 14932 |
# File 'lib/aws-sdk-s3/types.rb', line 14924 class PutBucketLoggingRequest < Struct.new( :bucket, :bucket_logging_status, :content_md5, :checksum_algorithm, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |