Class: Aws::S3::Types::PutBucketMetricsConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketMetricsConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket for which the metrics configuration is set.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the metrics configuration.
-
#metrics_configuration ⇒ Types::MetricsConfiguration
Specifies the metrics configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket for which the metrics configuration is set.
Directory buckets - When you use this operation with a
directory bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name .
Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local
Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide
16590 16591 16592 16593 16594 16595 16596 16597 |
# File 'lib/aws-sdk-s3/types.rb', line 16590 class PutBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :metrics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
501 Not Implemented.
16590 16591 16592 16593 16594 16595 16596 16597 |
# File 'lib/aws-sdk-s3/types.rb', line 16590 class PutBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :metrics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.
16590 16591 16592 16593 16594 16595 16596 16597 |
# File 'lib/aws-sdk-s3/types.rb', line 16590 class PutBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :metrics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#metrics_configuration ⇒ Types::MetricsConfiguration
Specifies the metrics configuration.
16590 16591 16592 16593 16594 16595 16596 16597 |
# File 'lib/aws-sdk-s3/types.rb', line 16590 class PutBucketMetricsConfigurationRequest < Struct.new( :bucket, :id, :metrics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |