Class: Aws::S3::Types::PutBucketOwnershipControlsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose OwnershipControls you want to set.

Returns:

  • (String)


16728
16729
16730
16731
16732
16733
16734
16735
16736
# File 'lib/aws-sdk-s3/types.rb', line 16728

class PutBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :content_md5,
  :expected_bucket_owner,
  :ownership_controls,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum-algorithm header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

Returns:

  • (String)


16728
16729
16730
16731
16732
16733
16734
16735
16736
# File 'lib/aws-sdk-s3/types.rb', line 16728

class PutBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :content_md5,
  :expected_bucket_owner,
  :ownership_controls,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The MD5 hash of the OwnershipControls request body.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

Returns:

  • (String)


16728
16729
16730
16731
16732
16733
16734
16735
16736
# File 'lib/aws-sdk-s3/types.rb', line 16728

class PutBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :content_md5,
  :expected_bucket_owner,
  :ownership_controls,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


16728
16729
16730
16731
16732
16733
16734
16735
16736
# File 'lib/aws-sdk-s3/types.rb', line 16728

class PutBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :content_md5,
  :expected_bucket_owner,
  :ownership_controls,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#ownership_controlsTypes::OwnershipControls

The OwnershipControls (BucketOwnerEnforced, BucketOwnerPreferred, or ObjectWriter) that you want to apply to this Amazon S3 bucket.



16728
16729
16730
16731
16732
16733
16734
16735
16736
# File 'lib/aws-sdk-s3/types.rb', line 16728

class PutBucketOwnershipControlsRequest < Struct.new(
  :bucket,
  :content_md5,
  :expected_bucket_owner,
  :ownership_controls,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end