Class: Aws::S3::Types::PutBucketWebsiteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketWebsiteRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name.
-
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK.
-
#content_md5 ⇒ String
The Base64 encoded 128-bit ‘MD5` digest of the data.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#website_configuration ⇒ Types::WebsiteConfiguration
Container for the request.
Instance Attribute Details
#bucket ⇒ String
The bucket name.
16989 16990 16991 16992 16993 16994 16995 16996 16997 |
# File 'lib/aws-sdk-s3/types.rb', line 16989 class PutBucketWebsiteRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :website_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding ‘x-amz-checksum` or `x-amz-trailer` header sent. Otherwise, Amazon S3 fails the request with the HTTP status code `400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
If you provide an individual checksum, Amazon S3 ignores any provided ‘ChecksumAlgorithm` parameter.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
16989 16990 16991 16992 16993 16994 16995 16996 16997 |
# File 'lib/aws-sdk-s3/types.rb', line 16989 class PutBucketWebsiteRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :website_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The Base64 encoded 128-bit ‘MD5` digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see [RFC 1864].
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
16989 16990 16991 16992 16993 16994 16995 16996 16997 |
# File 'lib/aws-sdk-s3/types.rb', line 16989 class PutBucketWebsiteRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :website_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
16989 16990 16991 16992 16993 16994 16995 16996 16997 |
# File 'lib/aws-sdk-s3/types.rb', line 16989 class PutBucketWebsiteRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :website_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#website_configuration ⇒ Types::WebsiteConfiguration
Container for the request.
16989 16990 16991 16992 16993 16994 16995 16996 16997 |
# File 'lib/aws-sdk-s3/types.rb', line 16989 class PutBucketWebsiteRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :website_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |