Class: Aws::S3::Types::PutObjectAnnotationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_nameString

The name of the annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32String

The CRC32 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32cString

The CRC32C checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc64nvmeString

The CRC64NVME checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_md5String

The MD5 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha1String

The SHA1 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha256String

The SHA256 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha512String

The SHA512 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_typeString

The type of checksum used.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash128String

The XXHASH128 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash3String

The XXHASH3 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash64String

The XXHASH64 checksum of the stored annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The entity tag of the annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#object_version_idString

The version ID of the object that the annotation was attached to.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#server_side_encryptionString

The server-side encryption algorithm used to encrypt the annotation.

Returns:

  • (String)


17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
# File 'lib/aws-sdk-s3/types.rb', line 17452

class PutObjectAnnotationOutput < Struct.new(
  :key,
  :annotation_name,
  :object_version_id,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end