Class: Aws::S3::Types::PutObjectAnnotationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutObjectAnnotationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_name ⇒ String
The name of the annotation.
-
#annotation_payload ⇒ IO
The annotation payload.
-
#bucket ⇒ String
The name of the bucket that contains the object.
-
#checksum_algorithm ⇒ String
The checksum algorithm to use.
-
#checksum_crc32 ⇒ String
Base64-encoded CRC32 checksum of the annotation payload.
-
#checksum_crc32c ⇒ String
Base64-encoded CRC32C checksum of the annotation payload.
-
#checksum_crc64nvme ⇒ String
Base64-encoded CRC64NVME checksum of the annotation payload.
-
#checksum_md5 ⇒ String
Base64-encoded MD5 checksum of the annotation payload.
-
#checksum_sha1 ⇒ String
Base64-encoded SHA1 checksum of the annotation payload.
-
#checksum_sha256 ⇒ String
Base64-encoded SHA256 checksum of the annotation payload.
-
#checksum_sha512 ⇒ String
Base64-encoded SHA512 checksum of the annotation payload.
-
#checksum_xxhash128 ⇒ String
Base64-encoded XXHASH128 checksum of the annotation payload.
-
#checksum_xxhash3 ⇒ String
Base64-encoded XXHASH3 checksum of the annotation payload.
-
#checksum_xxhash64 ⇒ String
Base64-encoded XXHASH64 checksum of the annotation payload.
-
#content_md5 ⇒ String
Base64-encoded MD5 digest of the message.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#key ⇒ String
The object key.
-
#object_if_match ⇒ String
If specified, the operation only succeeds if the object's ETag matches the provided value.
-
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request.
-
#version_id ⇒ String
The version ID of the object to attach the annotation to.
Instance Attribute Details
#annotation_name ⇒ String
The name of the annotation.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#annotation_payload ⇒ IO
The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket that contains the object.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
The checksum algorithm to use. Supported values: CRC32, CRC32C,
CRC64NVME, SHA1, SHA256, SHA512, MD5, XXHASH64,
XXHASH3, XXHASH128.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32 ⇒ String
Base64-encoded CRC32 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
Base64-encoded CRC32C checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
Base64-encoded CRC64NVME checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
Base64-encoded MD5 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
Base64-encoded SHA1 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
Base64-encoded SHA256 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
Base64-encoded SHA512 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
Base64-encoded XXHASH128 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
Base64-encoded XXHASH3 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
Base64-encoded XXHASH64 checksum of the annotation payload.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
Base64-encoded MD5 digest of the message.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#object_if_match ⇒ String
If specified, the operation only succeeds if the object's ETag matches the provided value.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the object to attach the annotation to.
17582 17583 17584 17585 17586 17587 17588 17589 17590 17591 17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 17602 17603 17604 17605 |
# File 'lib/aws-sdk-s3/types.rb', line 17582 class PutObjectAnnotationRequest < Struct.new( :bucket, :key, :version_id, :annotation_name, :annotation_payload, :object_if_match, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :content_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |