Class: Aws::S3::Types::PutObjectLockConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutObjectLockConfigurationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
17748 17749 17750 17751 17752 |
# File 'lib/aws-sdk-s3/types.rb', line 17748 class PutObjectLockConfigurationOutput < Struct.new( :request_charged) SENSITIVE = [] include Aws::Structure end |