Class: Aws::S3::Types::PutPublicAccessBlockRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to set.

Returns:

  • (String)


19087
19088
19089
19090
19091
19092
19093
19094
19095
# File 'lib/aws-sdk-s3/types.rb', line 19087

class PutPublicAccessBlockRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :public_access_block_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

Returns:

  • (String)


19087
19088
19089
19090
19091
19092
19093
19094
19095
# File 'lib/aws-sdk-s3/types.rb', line 19087

class PutPublicAccessBlockRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :public_access_block_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The MD5 hash of the PutPublicAccessBlock request body.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

Returns:

  • (String)


19087
19088
19089
19090
19091
19092
19093
19094
19095
# File 'lib/aws-sdk-s3/types.rb', line 19087

class PutPublicAccessBlockRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :public_access_block_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


19087
19088
19089
19090
19091
19092
19093
19094
19095
# File 'lib/aws-sdk-s3/types.rb', line 19087

class PutPublicAccessBlockRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :public_access_block_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#public_access_block_configurationTypes::PublicAccessBlockConfiguration

The PublicAccessBlock configuration that you want to apply to this Amazon S3 bucket. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see The Meaning of "Public" in the Amazon S3 User Guide.



19087
19088
19089
19090
19091
19092
19093
19094
19095
# File 'lib/aws-sdk-s3/types.rb', line 19087

class PutPublicAccessBlockRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :public_access_block_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end