Class: Aws::S3::Types::QueueConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::QueueConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Specifies the configuration for publishing messages to an Amazon Simple Queue Service (Amazon SQS) queue when Amazon S3 detects specified events.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<String>
A collection of bucket events for which to send notifications.
-
#filter ⇒ Types::NotificationConfigurationFilter
Specifies object key name filtering rules.
-
#id ⇒ String
An optional unique identifier for configurations in a notification configuration.
-
#queue_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 publishes a message when it detects events of the specified type.
Instance Attribute Details
#events ⇒ Array<String>
A collection of bucket events for which to send notifications
19129 19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-s3/types.rb', line 19129 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::NotificationConfigurationFilter
Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.
19129 19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-s3/types.rb', line 19129 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
19129 19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-s3/types.rb', line 19129 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) SENSITIVE = [] include Aws::Structure end |
#queue_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 publishes a message when it detects events of the specified type.
19129 19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-s3/types.rb', line 19129 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) SENSITIVE = [] include Aws::Structure end |