Class: Aws::S3::Types::RecordExpiration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::RecordExpiration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
The journal table record expiration settings for a journal table in an S3 Metadata configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#days ⇒ Integer
If you enable journal table record expiration, you can set the number of days to retain your journal table records.
-
#expiration ⇒ String
Specifies whether journal table record expiration is enabled or disabled.
Instance Attribute Details
#days ⇒ Integer
If you enable journal table record expiration, you can set the number of days to retain your journal table records. Journal table records must be retained for a minimum of 7 days. To set this value, specify any whole number from 7 to 2147483647. For example, to retain your journal table records for one year, set this value to 365.
17324 17325 17326 17327 17328 17329 |
# File 'lib/aws-sdk-s3/types.rb', line 17324 class RecordExpiration < Struct.new( :expiration, :days) SENSITIVE = [] include Aws::Structure end |
#expiration ⇒ String
Specifies whether journal table record expiration is enabled or disabled.
17324 17325 17326 17327 17328 17329 |
# File 'lib/aws-sdk-s3/types.rb', line 17324 class RecordExpiration < Struct.new( :expiration, :days) SENSITIVE = [] include Aws::Structure end |