Method: Aws::S3::Types::ReplicationRule#prefix

Defined in:
lib/aws-sdk-s3/types.rb

#prefixString

An object key name prefix that identifies the object or objects to which the rule applies. The maximum prefix length is 1,024 characters. To include all objects in a bucket, specify an empty string.

Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [ XML related object key constraints].

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints

Returns:

  • (String)


17743
17744
17745
17746
17747
17748
17749
17750
17751
17752
17753
17754
17755
# File 'lib/aws-sdk-s3/types.rb', line 17743

class ReplicationRule < Struct.new(
  :id,
  :priority,
  :prefix,
  :filter,
  :status,
  :source_selection_criteria,
  :existing_object_replication,
  :destination,
  :delete_marker_replication)
  SENSITIVE = []
  include Aws::Structure
end