Class: Aws::S3::Types::ReplicationRuleFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ReplicationRuleFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A filter that identifies the subset of objects to which the replication rule applies. A Filter must specify exactly one Prefix, Tag, or an And child element.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and ⇒ Types::ReplicationRuleAndOperator
A container for specifying rule filters.
-
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
-
#tag ⇒ Types::Tag
A container for specifying a tag key and value.
Instance Attribute Details
#and ⇒ Types::ReplicationRuleAndOperator
A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter. For example:
-
If you specify both a
Prefixand aTagfilter, wrap these filters in anAndtag. -
If you specify a filter based on multiple tags, wrap the
Tagelements in anAndtag.
17824 17825 17826 17827 17828 17829 17830 |
# File 'lib/aws-sdk-s3/types.rb', line 17824 class ReplicationRuleFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [ XML related object key constraints].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints
17824 17825 17826 17827 17828 17829 17830 |
# File 'lib/aws-sdk-s3/types.rb', line 17824 class ReplicationRuleFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |
#tag ⇒ Types::Tag
A container for specifying a tag key and value.
The rule applies only to objects that have the tag in their tag set.
17824 17825 17826 17827 17828 17829 17830 |
# File 'lib/aws-sdk-s3/types.rb', line 17824 class ReplicationRuleFilter < Struct.new( :prefix, :tag, :and) SENSITIVE = [] include Aws::Structure end |