Class: Aws::S3::Types::SelectParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::SelectParameters
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
Describes the parameters for Select job types.
Learn How to optimize querying your data in Amazon S3 using Amazon Athena, S3 Object Lambda, or client-side filtering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expression ⇒ String
Amazon S3 Select is no longer available to new customers.
-
#expression_type ⇒ String
The type of the provided expression (for example, SQL).
-
#input_serialization ⇒ Types::InputSerialization
Describes the serialization format of the object.
-
#output_serialization ⇒ Types::OutputSerialization
Describes how the results of the Select job are serialized.
Instance Attribute Details
#expression ⇒ String
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more
The expression that is used to query the object.
20763 20764 20765 20766 20767 20768 20769 20770 |
# File 'lib/aws-sdk-s3/types.rb', line 20763 class SelectParameters < Struct.new( :input_serialization, :expression_type, :expression, :output_serialization) SENSITIVE = [] include Aws::Structure end |
#expression_type ⇒ String
The type of the provided expression (for example, SQL).
20763 20764 20765 20766 20767 20768 20769 20770 |
# File 'lib/aws-sdk-s3/types.rb', line 20763 class SelectParameters < Struct.new( :input_serialization, :expression_type, :expression, :output_serialization) SENSITIVE = [] include Aws::Structure end |
#input_serialization ⇒ Types::InputSerialization
Describes the serialization format of the object.
20763 20764 20765 20766 20767 20768 20769 20770 |
# File 'lib/aws-sdk-s3/types.rb', line 20763 class SelectParameters < Struct.new( :input_serialization, :expression_type, :expression, :output_serialization) SENSITIVE = [] include Aws::Structure end |
#output_serialization ⇒ Types::OutputSerialization
Describes how the results of the Select job are serialized.
20763 20764 20765 20766 20767 20768 20769 20770 |
# File 'lib/aws-sdk-s3/types.rb', line 20763 class SelectParameters < Struct.new( :input_serialization, :expression_type, :expression, :output_serialization) SENSITIVE = [] include Aws::Structure end |