Class: Aws::S3::Types::SessionCredentials

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The established temporary security credentials of the session.

Directory buckets - These session credentials are only supported for the authentication and authorization of Zonal endpoint API operations on directory buckets.

Constant Summary collapse

SENSITIVE =
[:secret_access_key, :session_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_key_idString

A unique identifier that's associated with a secret access key. The access key ID and the secret access key are used together to sign programmatic Amazon Web Services requests cryptographically.



21011
21012
21013
21014
21015
21016
21017
21018
# File 'lib/aws-sdk-s3/types.rb', line 21011

class SessionCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:secret_access_key, :session_token]
  include Aws::Structure
end

#expirationTime

Temporary security credentials expire after a specified interval. After temporary credentials expire, any calls that you make with those credentials will fail. So you must generate a new set of temporary credentials. Temporary credentials cannot be extended or refreshed beyond the original specified interval.



21011
21012
21013
21014
21015
21016
21017
21018
# File 'lib/aws-sdk-s3/types.rb', line 21011

class SessionCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:secret_access_key, :session_token]
  include Aws::Structure
end

#secret_access_keyString

A key that's used with the access key ID to cryptographically sign programmatic Amazon Web Services requests. Signing a request identifies the sender and prevents the request from being altered.



21011
21012
21013
21014
21015
21016
21017
21018
# File 'lib/aws-sdk-s3/types.rb', line 21011

class SessionCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:secret_access_key, :session_token]
  include Aws::Structure
end

#session_tokenString

A part of the temporary security credentials. The session token is used to validate the temporary security credentials.



21011
21012
21013
21014
21015
21016
21017
21018
# File 'lib/aws-sdk-s3/types.rb', line 21011

class SessionCredentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:secret_access_key, :session_token]
  include Aws::Structure
end