Class: Aws::S3::Types::TargetGrant

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Container for granting information.

Buckets that use the bucket owner enforced setting for Object Ownership don't support target grants. For more information, see Permissions server access log delivery in the Amazon S3 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#granteeTypes::Grantee

Container for the person being granted permissions.

Returns:



21216
21217
21218
21219
21220
21221
# File 'lib/aws-sdk-s3/types.rb', line 21216

class TargetGrant < Struct.new(
  :grantee,
  :permission)
  SENSITIVE = []
  include Aws::Structure
end

#permissionString

Logging permissions assigned to the grantee for the bucket.

Returns:



21216
21217
21218
21219
21220
21221
# File 'lib/aws-sdk-s3/types.rb', line 21216

class TargetGrant < Struct.new(
  :grantee,
  :permission)
  SENSITIVE = []
  include Aws::Structure
end