Class: Aws::S3::Types::TopicConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

A container for specifying the configuration for publication of messages to an Amazon Simple Notification Service (Amazon SNS) topic when Amazon S3 detects specified events.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<String>

The Amazon S3 bucket event about which to send notifications. For more information, see Supported Event Types in the Amazon S3 User Guide.

Returns:

  • (Array<String>)


21127
21128
21129
21130
21131
21132
21133
21134
# File 'lib/aws-sdk-s3/types.rb', line 21127

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::NotificationConfigurationFilter

Specifies object key name filtering rules. For information about key name filtering, see Configuring event notifications using object key name filtering in the Amazon S3 User Guide.



21127
21128
21129
21130
21131
21132
21133
21134
# File 'lib/aws-sdk-s3/types.rb', line 21127

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#idString

An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.

Returns:

  • (String)


21127
21128
21129
21130
21131
21132
21133
21134
# File 'lib/aws-sdk-s3/types.rb', line 21127

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#topic_arnString

The Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 publishes a message when it detects events of the specified type.

Returns:

  • (String)


21127
21128
21129
21130
21131
21132
21133
21134
# File 'lib/aws-sdk-s3/types.rb', line 21127

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end