Class: Aws::S3::Types::Transition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies when an object transitions to a specified storage class. For more information about Amazon S3 lifecycle configuration rules, see

Transitioning Objects Using Amazon S3 Lifecycle][1

in the *Amazon S3

User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/lifecycle-transition-general-considerations.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateTime

Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.



19401
19402
19403
19404
19405
19406
19407
# File 'lib/aws-sdk-s3/types.rb', line 19401

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#daysInteger

Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is INTELLIGENT_TIERING, GLACIER_IR, GLACIER, or DEEP_ARCHIVE, valid values are 0 or positive integers. If the specified storage class is STANDARD_IA or ONEZONE_IA, valid values are positive integers greater than 30. Be aware that some storage classes have a minimum storage duration and that you’re charged for transitioning objects before their minimum storage duration. For more information, see [ Constraints and considerations for transitions][1] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-transition-general-considerations.html#lifecycle-configuration-constraints



19401
19402
19403
19404
19405
19406
19407
# File 'lib/aws-sdk-s3/types.rb', line 19401

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The storage class to which you want the object to transition.



19401
19402
19403
19404
19405
19406
19407
# File 'lib/aws-sdk-s3/types.rb', line 19401

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end