Class: Aws::S3::Types::UpdateBucketMetadataAnnotationTableConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UpdateBucketMetadataAnnotationTableConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_table_configuration ⇒ Types::AnnotationTableConfigurationUpdates
The annotation table configuration updates to apply.
-
#bucket ⇒ String
The name of the bucket whose annotation table configuration to update.
-
#checksum_algorithm ⇒ String
Checksum algorithm for the request payload.
-
#content_md5 ⇒ String
Base64-encoded MD5 digest of the message body.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#annotation_table_configuration ⇒ Types::AnnotationTableConfigurationUpdates
The annotation table configuration updates to apply.
21236 21237 21238 21239 21240 21241 21242 21243 21244 |
# File 'lib/aws-sdk-s3/types.rb', line 21236 class UpdateBucketMetadataAnnotationTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :annotation_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket whose annotation table configuration to update.
21236 21237 21238 21239 21240 21241 21242 21243 21244 |
# File 'lib/aws-sdk-s3/types.rb', line 21236 class UpdateBucketMetadataAnnotationTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :annotation_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Checksum algorithm for the request payload.
21236 21237 21238 21239 21240 21241 21242 21243 21244 |
# File 'lib/aws-sdk-s3/types.rb', line 21236 class UpdateBucketMetadataAnnotationTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :annotation_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
Base64-encoded MD5 digest of the message body.
21236 21237 21238 21239 21240 21241 21242 21243 21244 |
# File 'lib/aws-sdk-s3/types.rb', line 21236 class UpdateBucketMetadataAnnotationTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :annotation_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
21236 21237 21238 21239 21240 21241 21242 21243 21244 |
# File 'lib/aws-sdk-s3/types.rb', line 21236 class UpdateBucketMetadataAnnotationTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :annotation_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |