Class: Aws::S3::Types::UpdateBucketMetadataInventoryTableConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable an inventory table for.



19436
19437
19438
19439
19440
19441
19442
19443
19444
# File 'lib/aws-sdk-s3/types.rb', line 19436

class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :inventory_table_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

The checksum algorithm to use with your inventory table configuration.



19436
19437
19438
19439
19440
19441
19442
19443
19444
# File 'lib/aws-sdk-s3/types.rb', line 19436

class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :inventory_table_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The Content-MD5 header for the inventory table configuration.



19436
19437
19438
19439
19440
19441
19442
19443
19444
# File 'lib/aws-sdk-s3/types.rb', line 19436

class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :inventory_table_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable an inventory table for.



19436
19437
19438
19439
19440
19441
19442
19443
19444
# File 'lib/aws-sdk-s3/types.rb', line 19436

class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :inventory_table_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#inventory_table_configurationTypes::InventoryTableConfigurationUpdates

The contents of your inventory table configuration.



19436
19437
19438
19439
19440
19441
19442
19443
19444
# File 'lib/aws-sdk-s3/types.rb', line 19436

class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :inventory_table_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end