Class: Aws::S3::Types::UpdateObjectEncryptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the general purpose bucket that contains the specified object key name.

When you use this operation with an access point attached to a general purpose bucket, you must either provide the alias of the access point in place of the bucket name or you must specify the access point Amazon Resource Name (ARN). When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form ‘ AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com`. When using this operation with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see [ Referencing access points] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-points-naming.html

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

Indicates the algorithm used to create the checksum for the object when you use an Amazon Web Services SDK. This header doesn’t provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding ‘x-amz-checksum` or `x-amz-trailer` header sent. Otherwise, Amazon S3 fails the request with the HTTP status code `400 Bad Request`. For more information, see [ Checking object integrity ][1] in the *Amazon S3 User Guide*.

If you provide an individual checksum, Amazon S3 ignores any provided ‘ChecksumAlgorithm` parameter.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The MD5 hash for the request body. For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide doesn’t match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The key name of the object that you want to update the server-side encryption type for.

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#object_encryptionTypes::ObjectEncryption

The updated server-side encryption type for this object. The ‘UpdateObjectEncryption` operation supports the SSE-S3 and SSE-KMS encryption types.

Valid Values: ‘SSES3` | `SSEKMS`



20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the object that you want to update the server-side encryption type for.

Returns:

  • (String)


20500
20501
20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
# File 'lib/aws-sdk-s3/types.rb', line 20500

class UpdateObjectEncryptionRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :object_encryption,
  :request_payer,
  :expected_bucket_owner,
  :content_md5,
  :checksum_algorithm)
  SENSITIVE = []
  include Aws::Structure
end