Class: Aws::S3::Types::UpdateObjectEncryptionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UpdateObjectEncryptionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
21450 21451 21452 21453 21454 |
# File 'lib/aws-sdk-s3/types.rb', line 21450 class UpdateObjectEncryptionResponse < Struct.new( :request_charged) SENSITIVE = [] include Aws::Structure end |