Class: Aws::S3::Types::UploadPartCopyOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UploadPartCopyOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:ssekms_key_id]
Instance Attribute Summary collapse
-
#bucket_key_enabled ⇒ Boolean
Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
-
#copy_part_result ⇒ Types::CopyPartResult
Container for all response elements.
-
#copy_source_version_id ⇒ String
The version of the source object that was copied, if you have enabled versioning on the source bucket.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
-
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used.
-
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
-
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
Instance Attribute Details
#bucket_key_enabled ⇒ Boolean
Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#copy_part_result ⇒ Types::CopyPartResult
Container for all response elements.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#copy_source_version_id ⇒ String
The version of the source object that was copied, if you have enabled versioning on the source bucket.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
aws:fsx.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
21726 21727 21728 21729 21730 21731 21732 21733 21734 21735 21736 21737 |
# File 'lib/aws-sdk-s3/types.rb', line 21726 class UploadPartCopyOutput < Struct.new( :copy_source_version_id, :copy_part_result, :server_side_encryption, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |