Class: Aws::S3::Types::VersioningConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::VersioningConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Describes the versioning state of an Amazon S3 bucket. For more information, see PUT Bucket versioning in the Amazon S3 API Reference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mfa_delete ⇒ String
Specifies whether MFA delete is enabled in the bucket versioning configuration.
-
#status ⇒ String
The versioning state of the bucket.
Instance Attribute Details
#mfa_delete ⇒ String
Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is only returned if the bucket has been configured with MFA delete. If the bucket has never been so configured, this element is not returned.
22595 22596 22597 22598 22599 22600 |
# File 'lib/aws-sdk-s3/types.rb', line 22595 class VersioningConfiguration < Struct.new( :mfa_delete, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The versioning state of the bucket.
22595 22596 22597 22598 22599 22600 |
# File 'lib/aws-sdk-s3/types.rb', line 22595 class VersioningConfiguration < Struct.new( :mfa_delete, :status) SENSITIVE = [] include Aws::Structure end |