Class: Aws::S3::Waiters::BucketExists
- Inherits:
-
Object
- Object
- Aws::S3::Waiters::BucketExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-s3/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BucketExists
constructor
A new instance of BucketExists.
-
#wait(params = {}) ⇒ Types::HeadBucketOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BucketExists
Returns a new instance of BucketExists.
87 88 |
# File 'lib/aws-sdk-s3/waiters.rb', line 87
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
127 128 129 |
# File 'lib/aws-sdk-s3/waiters.rb', line 127 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::HeadBucketOutput
Returns a response object which responds to the following methods:
- #bucket_arn => String
- #bucket_location_type => String
- #bucket_location_name => String
- #bucket_region => String
- #access_point_alias => Boolean
122 |
# File 'lib/aws-sdk-s3/waiters.rb', line 122
def wait: (
|