Class: Aws::S3::Waiters::ObjectExists
- Inherits:
-
Object
- Object
- Aws::S3::Waiters::ObjectExists
- Defined in:
- lib/aws-sdk-s3/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ObjectExists
constructor
A new instance of ObjectExists.
-
#wait(params = {}) ⇒ Types::HeadObjectOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ObjectExists
Returns a new instance of ObjectExists.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/aws-sdk-s3/waiters.rb', line 108 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 20, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :head_object, acceptors: [ { "expected" => 200, "matcher" => "status", "state" => "success" }, { "expected" => 404, "matcher" => "status", "state" => "retry" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
138 139 140 |
# File 'lib/aws-sdk-s3/waiters.rb', line 138 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::HeadObjectOutput
Returns a response object which responds to the following methods:
- #delete_marker => Boolean
- #accept_ranges => String
- #expiration => String
- #restore => String
- #last_modified => Time
- #content_length => Integer
- #etag => String
- #missing_meta => Integer
- #version_id => String
- #cache_control => String
- #content_disposition => String
- #content_encoding => String
- #content_language => String
- #content_type => String
- #expires => Time
- #expires_string => String
- #website_redirect_location => String
- #server_side_encryption => String
- #metadata => Hash<String,String>
- #sse_customer_algorithm => String
- #sse_customer_key_md5 => String
- #ssekms_key_id => String
- #storage_class => String
- #request_charged => String
- #replication_status => String
- #parts_count => Integer
133 134 135 |
# File 'lib/aws-sdk-s3/waiters.rb', line 133 def wait(params = {}) @waiter.wait(client: @client, params: params) end |