Method: Aws::S3::Types::UploadPartRequest#checksum_algorithm
- Defined in:
- lib/aws-sdk-s3/types.rb
#checksum_algorithm ⇒ String
Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code ‘400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
This checksum algorithm must be the same for all parts and it match the checksum value supplied in the CreateMultipartUpload request.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 |
# File 'lib/aws-sdk-s3/types.rb', line 17028 class UploadPartRequest < Struct.new( :body, :bucket, :content_length, :content_md5, :checksum_algorithm, :checksum_crc32, :checksum_crc32c, :checksum_sha1, :checksum_sha256, :key, :part_number, :upload_id, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5, :request_payer, :expected_bucket_owner) SENSITIVE = [:sse_customer_key] include Aws::Structure end |