Class: Aws::S3::MultipartUpload
- Inherits:
-
Object
- Object
- Aws::S3::MultipartUpload
- Extended by:
- Deprecations
- Defined in:
- sig/multipart_upload.rbs,
lib/aws-sdk-s3/multipart_upload.rb,
lib/aws-sdk-s3/customizations/multipart_upload.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #bucket_name ⇒ String
- #checksum_algorithm ⇒ "CRC32", ...
- #checksum_type ⇒ "COMPOSITE", "FULL_OBJECT"
- #id ⇒ String
- #initiated ⇒ ::Time
- #initiator ⇒ Types::Initiator
- #key ⇒ ::String
- #object_key ⇒ String
- #owner ⇒ Types::Owner
- #storage_class ⇒ "STANDARD", ...
- #upload_id ⇒ ::String
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #object ⇒ Object
- #part(part_number) ⇒ MultipartUploadPart
- #parts(options = {}) ⇒ Object
Instance Method Summary collapse
- #basic_complete ⇒ Object
- #client ⇒ Client
- #data ⇒ Types::MultipartUpload
- #data_loaded? ⇒ Boolean
- #initialize(*args) ⇒ MultipartUpload constructor
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::S3::Client] #wait_until instead
Constructor Details
#initialize(bucket_name, object_key, id, options) ⇒ void #initialize(bucket_name:, object_key:, id:, client:) ⇒ void #initialize(args) ⇒ void
26 27 28 29 30 31 32 33 34 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 26 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @bucket_name = extract_bucket_name(args, ) @object_key = extract_object_key(args, ) @id = extract_id(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#abort(options = {}) ⇒ Object
291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 291 def abort( = {}) = .merge( bucket: @bucket_name, key: @object_key, upload_id: @id ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.abort_multipart_upload() end resp.data end |
#basic_complete ⇒ Object
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 |
# File 'lib/aws-sdk-s3/customizations/multipart_upload.rb', line 7 def complete( = {}) = .merge( bucket: @bucket_name, key: @object_key, upload_id: @id ) Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.complete_multipart_upload() end Object.new( bucket_name: @bucket_name, key: @object_key, client: @client ) end |
#bucket_name ⇒ String
39 40 41 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 39 def bucket_name @bucket_name end |
#checksum_algorithm ⇒ "CRC32", ...
104 105 106 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 104 def checksum_algorithm data[:checksum_algorithm] end |
#checksum_type ⇒ "COMPOSITE", "FULL_OBJECT"
116 117 118 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 116 def checksum_type data[:checksum_type] end |
#client ⇒ Client
123 124 125 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 123 def client @client end |
#complete(options = {}) ⇒ Object
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 563 def complete( = {}) = .merge( bucket: @bucket_name, key: @object_key, upload_id: @id ) Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.complete_multipart_upload() end Object.new( bucket_name: @bucket_name, key: @object_key, client: @client ) end |
#data ⇒ Types::MultipartUpload
138 139 140 141 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 138 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
146 147 148 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 146 def data_loaded? !!@data end |
#id ⇒ String
49 50 51 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 49 def id @id end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
702 703 704 705 706 707 708 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 702 def identifiers { bucket_name: @bucket_name, object_key: @object_key, id: @id } end |
#initiated ⇒ ::Time
67 68 69 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 67 def initiated data[:initiated] end |
#initiator ⇒ Types::Initiator
98 99 100 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 98 def initiator data[:initiator] end |
#key ⇒ ::String
61 62 63 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 61 def key data[:key] end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
129 130 131 132 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 129 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#object ⇒ Object
582 583 584 585 586 587 588 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 582 def object Object.new( bucket_name: @bucket_name, key: @object_key, client: @client ) end |
#object_key ⇒ String
44 45 46 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 44 def object_key @object_key end |
#owner ⇒ Types::Owner
92 93 94 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 92 def owner data[:owner] end |
#part(part_number) ⇒ MultipartUploadPart
592 593 594 595 596 597 598 599 600 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 592 def part(part_number) MultipartUploadPart.new( bucket_name: @bucket_name, object_key: @object_key, multipart_upload_id: @id, part_number: part_number, client: @client ) end |
#parts(options = {}) ⇒ Object
672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 672 def parts( = {}) batches = Enumerator.new do |y| = .merge( bucket: @bucket_name, key: @object_key, upload_id: @id ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.list_parts() end resp.each_page do |page| batch = [] page.data.parts.each do |p| batch << MultipartUploadPart.new( bucket_name: [:bucket], object_key: [:key], multipart_upload_id: [:upload_id], part_number: p.part_number, data: p, client: @client ) end y.yield(batch) end end MultipartUploadPart::Collection.new(batches) end |
#storage_class ⇒ "STANDARD", ...
80 81 82 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 80 def storage_class data[:storage_class] end |
#upload_id ⇒ ::String
55 56 57 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 55 def upload_id data[:upload_id] end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::S3::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/aws-sdk-s3/multipart_upload.rb', line 230 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |