Class: Aws::S3::MultipartUploadPart

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
lib/aws-sdk-s3/multipart_upload_part.rb

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(bucket_name, object_key, multipart_upload_id, part_number, options = {}) ⇒ MultipartUploadPart #initialize(options = {}) ⇒ MultipartUploadPart

Returns a new instance of MultipartUploadPart.

Overloads:

  • #initialize(bucket_name, object_key, multipart_upload_id, part_number, options = {}) ⇒ MultipartUploadPart

    Parameters:

    • bucket_name (String)
    • object_key (String)
    • multipart_upload_id (String)
    • part_number (Integer)

    Options Hash (options):

  • #initialize(options = {}) ⇒ MultipartUploadPart

    Options Hash (options):

    • :bucket_name (required, String)
    • :object_key (required, String)
    • :multipart_upload_id (required, String)
    • :part_number (required, Integer)
    • :client (Client)


28
29
30
31
32
33
34
35
36
37
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 28

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @bucket_name = extract_bucket_name(args, options)
  @object_key = extract_object_key(args, options)
  @multipart_upload_id = extract_multipart_upload_id(args, options)
  @part_number = extract_part_number(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#bucket_nameString

Returns:

  • (String)


42
43
44
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 42

def bucket_name
  @bucket_name
end

#checksum_crc32String

The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This checksum is present if the object was uploaded with the `CRC32` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


88
89
90
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 88

def checksum_crc32
  data[:checksum_crc32]
end

#checksum_crc32cString

The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This checksum is present if the object was uploaded with the `CRC32C` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


101
102
103
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 101

def checksum_crc32c
  data[:checksum_crc32c]
end

#checksum_crc64nvmeString

The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC64NVME` checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, `CRC64NVME`, to the uploaded object). For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


116
117
118
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 116

def checksum_crc64nvme
  data[:checksum_crc64nvme]
end

#checksum_md5String

The Base64 encoded, 128-bit ‘MD5` digest of the part. This checksum is present if the multipart upload request was created with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


168
169
170
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 168

def checksum_md5
  data[:checksum_md5]
end

#checksum_sha1String

The Base64 encoded, 160-bit ‘SHA1` checksum of the part. This checksum is present if the object was uploaded with the `SHA1` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


129
130
131
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 129

def checksum_sha1
  data[:checksum_sha1]
end

#checksum_sha256String

The Base64 encoded, 256-bit ‘SHA256` checksum of the part. This checksum is present if the object was uploaded with the `SHA256` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


142
143
144
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 142

def checksum_sha256
  data[:checksum_sha256]
end

#checksum_sha512String

The Base64 encoded, 512-bit ‘SHA512` digest of the part. This checksum is present if the multipart upload request was created with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


155
156
157
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 155

def checksum_sha512
  data[:checksum_sha512]
end

#checksum_xxhash128String

The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH128` checksum algorithm. For more information, see

Checking object integrity][1

in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


207
208
209
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 207

def checksum_xxhash128
  data[:checksum_xxhash128]
end

#checksum_xxhash3String

The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH3` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


194
195
196
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 194

def checksum_xxhash3
  data[:checksum_xxhash3]
end

#checksum_xxhash64String

The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH64` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


181
182
183
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 181

def checksum_xxhash64
  data[:checksum_xxhash64]
end

#clientClient

Returns:



214
215
216
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 214

def client
  @client
end

#copy_from(options = {}) ⇒ Types::UploadPartCopyOutput

Examples:

Request syntax with placeholder values


multipart_upload_part.copy_from({
  copy_source: "CopySource", # required
  copy_source_if_match: "CopySourceIfMatch",
  copy_source_if_modified_since: Time.now,
  copy_source_if_none_match: "CopySourceIfNoneMatch",
  copy_source_if_unmodified_since: Time.now,
  copy_source_range: "CopySourceRange",
  sse_customer_algorithm: "SSECustomerAlgorithm",
  sse_customer_key: "SSECustomerKey",
  sse_customer_key_md5: "SSECustomerKeyMD5",
  copy_source_sse_customer_algorithm: "CopySourceSSECustomerAlgorithm",
  copy_source_sse_customer_key: "CopySourceSSECustomerKey",
  copy_source_sse_customer_key_md5: "CopySourceSSECustomerKeyMD5",
  request_payer: "requester", # accepts requester
  expected_bucket_owner: "AccountId",
  expected_source_bucket_owner: "AccountId",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :copy_source (required, String)

    Specifies the source object for the copy operation. You specify the value in one of two formats, depending on whether you want to access the source object through an [access point]:

    • For objects not accessed through an access point, specify the name of the source bucket and key of the source object, separated by a slash (/). For example, to copy the object ‘reports/january.pdf` from the bucket `awsexamplebucket`, use `awsexamplebucket/reports/january.pdf`. The value must be URL-encoded.

    • For objects accessed through access points, specify the Amazon Resource Name (ARN) of the object as accessed through the access point, in the format ‘arn:aws:s3:<Region>:<account-id>:accesspoint/<access-point-name>/object/<key>`. For example, to copy the object `reports/january.pdf` through access point `my-access-point` owned by account `123456789012` in Region `us-west-2`, use the URL encoding of `arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf`. The value must be URL encoded.

      <note markdown=“1”> * Amazon S3 supports copy operations using Access points only when

      the source and destination buckets are in the same Amazon Web
      Services Region.
      
      • Access points are not supported by directory buckets.

      </note>
      

      Alternatively, for objects accessed through Amazon S3 on Outposts, specify the ARN of the object as accessed in the format ‘arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/object/<key>`. For example, to copy the object `reports/january.pdf` through outpost `my-outpost` owned by account `123456789012` in Region `us-west-2`, use the URL encoding of `arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/object/reports/january.pdf`. The value must be URL-encoded.

    If your bucket has versioning enabled, you could have multiple versions of the same object. By default, ‘x-amz-copy-source` identifies the current version of the source object to copy. To copy a specific version of the source object to copy, append `?versionId=<version-id>` to the `x-amz-copy-source` request header (for example, `x-amz-copy-source: /awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893`).

    If the current version is a delete marker and you don’t specify a versionId in the ‘x-amz-copy-source` request header, Amazon S3 returns a `404 Not Found` error, because the object does not exist. If you specify versionId in the `x-amz-copy-source` and the versionId is a delete marker, Amazon S3 returns an HTTP `400 Bad Request` error, because you are not allowed to specify a delete marker as a version for the `x-amz-copy-source`.

    <note markdown=“1”> **Directory buckets** - S3 Versioning isn’t enabled and supported for directory buckets.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html

  • :copy_source_if_match (String)

    Copies the object if its entity tag (ETag) matches the specified tag.

    If both of the ‘x-amz-copy-source-if-match` and `x-amz-copy-source-if-unmodified-since` headers are present in the request as follows:

    ‘x-amz-copy-source-if-match` condition evaluates to `true`, and;

    ‘x-amz-copy-source-if-unmodified-since` condition evaluates to `false`;

    Amazon S3 returns ‘200 OK` and copies the data.

  • :copy_source_if_modified_since (Time, DateTime, Date, Integer, String)

    Copies the object if it has been modified since the specified time.

    If both of the ‘x-amz-copy-source-if-none-match` and `x-amz-copy-source-if-modified-since` headers are present in the request as follows:

    ‘x-amz-copy-source-if-none-match` condition evaluates to `false`, and;

    ‘x-amz-copy-source-if-modified-since` condition evaluates to `true`;

    Amazon S3 returns ‘412 Precondition Failed` response code.

  • :copy_source_if_none_match (String)

    Copies the object if its entity tag (ETag) is different than the specified ETag.

    If both of the ‘x-amz-copy-source-if-none-match` and `x-amz-copy-source-if-modified-since` headers are present in the request as follows:

    ‘x-amz-copy-source-if-none-match` condition evaluates to `false`, and;

    ‘x-amz-copy-source-if-modified-since` condition evaluates to `true`;

    Amazon S3 returns ‘412 Precondition Failed` response code.

  • :copy_source_if_unmodified_since (Time, DateTime, Date, Integer, String)

    Copies the object if it hasn’t been modified since the specified time.

    If both of the ‘x-amz-copy-source-if-match` and `x-amz-copy-source-if-unmodified-since` headers are present in the request as follows:

    ‘x-amz-copy-source-if-match` condition evaluates to `true`, and;

    ‘x-amz-copy-source-if-unmodified-since` condition evaluates to `false`;

    Amazon S3 returns ‘200 OK` and copies the data.

  • :copy_source_range (String)

    The range of bytes to copy from the source object. The range value must use the form bytes=first-last, where the first and last are the zero-based byte offsets to copy. For example, bytes=0-9 indicates that you want to copy the first 10 bytes of the source. You can copy a range only if the source object is greater than 5 MB.

  • :sse_customer_algorithm (String)

    Specifies the algorithm to use when encrypting the object (for example, AES256).

    <note markdown=“1”> This functionality is not supported when the destination bucket is a directory bucket.

    </note>
    
  • :sse_customer_key (String)

    Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the ‘x-amz-server-side-encryption-customer-algorithm` header. This must be the same encryption key specified in the initiate multipart upload request.

    <note markdown=“1”> This functionality is not supported when the destination bucket is a directory bucket.

    </note>
    
  • :sse_customer_key_md5 (String)

    Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

    <note markdown=“1”> This functionality is not supported when the destination bucket is a directory bucket.

    </note>
    
  • :copy_source_sse_customer_algorithm (String)

    Specifies the algorithm to use when decrypting the source object (for example, ‘AES256`).

    <note markdown=“1”> This functionality is not supported when the source object is in a directory bucket.

    </note>
    
  • :copy_source_sse_customer_key (String)

    Specifies the customer-provided encryption key for Amazon S3 to use to decrypt the source object. The encryption key provided in this header must be one that was used when the source object was created.

    <note markdown=“1”> This functionality is not supported when the source object is in a directory bucket.

    </note>
    
  • :copy_source_sse_customer_key_md5 (String)

    Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

    <note markdown=“1”> This functionality is not supported when the source object is in a directory bucket.

    </note>
    
  • :request_payer (String)

    Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

  • :expected_bucket_owner (String)

    The account ID of the expected destination bucket owner. If the account ID that you provide does not match the actual owner of the destination bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

  • :expected_source_bucket_owner (String)

    The account ID of the expected source bucket owner. If the account ID that you provide does not match the actual owner of the source bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 566

def copy_from(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    upload_id: @multipart_upload_id,
    part_number: @part_number
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.upload_part_copy(options)
  end
  resp.data
end

#dataTypes::Part

Returns the data for this Aws::S3::MultipartUploadPart.

Returns:

Raises:

  • (NotImplementedError)

    Raises when #data_loaded? is ‘false`.



229
230
231
232
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 229

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns ‘true` if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns ‘true` if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



237
238
239
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 237

def data_loaded?
  !!@data
end

#etagString

Entity tag returned when the part was uploaded.

Returns:

  • (String)


69
70
71
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 69

def etag
  data[:etag]
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 809

def identifiers
  {
    bucket_name: @bucket_name,
    object_key: @object_key,
    multipart_upload_id: @multipart_upload_id,
    part_number: @part_number
  }
end

#last_modifiedTime

Date and time at which the part was uploaded.

Returns:

  • (Time)


63
64
65
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 63

def last_modified
  data[:last_modified]
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


220
221
222
223
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 220

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#multipart_uploadMultipartUpload

Returns:



798
799
800
801
802
803
804
805
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 798

def multipart_upload
  MultipartUpload.new(
    bucket_name: @bucket_name,
    object_key: @object_key,
    id: @multipart_upload_id,
    client: @client
  )
end

#multipart_upload_idString

Returns:

  • (String)


52
53
54
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 52

def multipart_upload_id
  @multipart_upload_id
end

#object_keyString

Returns:

  • (String)


47
48
49
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 47

def object_key
  @object_key
end

#part_numberInteger

Returns:

  • (Integer)


57
58
59
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 57

def part_number
  @part_number
end

#sizeInteger

Size in bytes of the uploaded part data.

Returns:

  • (Integer)


75
76
77
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 75

def size
  data[:size]
end

#upload(options = {}) ⇒ Types::UploadPartOutput

Examples:

Request syntax with placeholder values


multipart_upload_part.upload({
  body: source_file,
  content_length: 1,
  content_md5: "ContentMD5",
  checksum_algorithm: "CRC32", # accepts CRC32, CRC32C, SHA1, SHA256, CRC64NVME, SHA512, MD5, XXHASH64, XXHASH3, XXHASH128
  checksum_crc32: "ChecksumCRC32",
  checksum_crc32c: "ChecksumCRC32C",
  checksum_crc64nvme: "ChecksumCRC64NVME",
  checksum_sha1: "ChecksumSHA1",
  checksum_sha256: "ChecksumSHA256",
  checksum_sha512: "ChecksumSHA512",
  checksum_md5: "ChecksumMD5",
  checksum_xxhash64: "ChecksumXXHASH64",
  checksum_xxhash3: "ChecksumXXHASH3",
  checksum_xxhash128: "ChecksumXXHASH128",
  sse_customer_algorithm: "SSECustomerAlgorithm",
  sse_customer_key: "SSECustomerKey",
  sse_customer_key_md5: "SSECustomerKeyMD5",
  request_payer: "requester", # accepts requester
  expected_bucket_owner: "AccountId",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :body (String, StringIO, File)

    Object data.

  • :content_length (Integer)

    Size of the body in bytes. This parameter is useful when the size of the body cannot be determined automatically.

  • :content_md5 (String)

    The Base64 encoded 128-bit MD5 digest of the part data. This parameter is auto-populated when using the command from the CLI. This parameter is required if object lock parameters are specified.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :checksum_algorithm (String)

    Indicates the algorithm used to create the checksum for the object when you use the SDK. This header will not provide any additional functionality if you don’t use the SDK. When you send this header, there must be a corresponding ‘x-amz-checksum` or `x-amz-trailer` header sent. Otherwise, Amazon S3 fails the request with the HTTP status code `400 Bad Request`. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    If you provide an individual checksum, Amazon S3 ignores any provided ‘ChecksumAlgorithm` parameter.

    This checksum algorithm must be the same for all parts and it match the checksum value supplied in the ‘CreateMultipartUpload` request.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_crc32 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit ‘CRC32` checksum of the object. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_crc32c (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 32-bit ‘CRC32C` checksum of the object. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_crc64nvme (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_sha1 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 160-bit ‘SHA1` digest of the object. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_sha256 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 256-bit ‘SHA256` digest of the object. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_sha512 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 512-bit ‘SHA512` digest of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_md5 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit ‘MD5` digest of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_xxhash64 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_xxhash3 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :checksum_xxhash128 (String)

    This header can be used as a data integrity check to verify that the data received is the same data that was originally sent. This header specifies the Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

    [1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

  • :sse_customer_algorithm (String)

    Specifies the algorithm to use when encrypting the object (for example, AES256).

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :sse_customer_key (String)

    Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the ‘x-amz-server-side-encryption-customer-algorithm header`. This must be the same encryption key specified in the initiate multipart upload request.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :sse_customer_key_md5 (String)

    Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    
  • :request_payer (String)

    Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

    <note markdown=“1”> This functionality is not supported for directory buckets.

    </note>
    

    [1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

  • :expected_bucket_owner (String)

    The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 782

def upload(options = {})
  options = options.merge(
    bucket: @bucket_name,
    key: @object_key,
    upload_id: @multipart_upload_id,
    part_number: @part_number
  )
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.upload_part(options)
  end
  resp.data
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::S3::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

## Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

## Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

## Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

## Callbacks

You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

## Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 321

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end