Class: Aws::S3::MultipartUploadPart
- Inherits:
-
Object
- Object
- Aws::S3::MultipartUploadPart
- Extended by:
- Deprecations
- Defined in:
- lib/aws-sdk-s3/multipart_upload_part.rb
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #bucket_name ⇒ String
-
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part.
-
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part.
-
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part.
-
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part.
-
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part.
-
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part.
-
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part.
-
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part.
-
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part.
-
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part.
-
#etag ⇒ String
Entity tag returned when the part was uploaded.
-
#last_modified ⇒ Time
Date and time at which the part was uploaded.
- #multipart_upload_id ⇒ String
- #object_key ⇒ String
- #part_number ⇒ Integer
-
#size ⇒ Integer
Size in bytes of the uploaded part data.
Actions collapse
- #copy_from(options = {}) ⇒ Types::UploadPartCopyOutput
- #upload(options = {}) ⇒ Types::UploadPartOutput
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #multipart_upload ⇒ MultipartUpload
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Part
Returns the data for this MultipartUploadPart.
-
#data_loaded? ⇒ Boolean
Returns ‘true` if this resource is loaded.
-
#initialize(*args) ⇒ MultipartUploadPart
constructor
A new instance of MultipartUploadPart.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::S3::Client] #wait_until instead
Constructor Details
#initialize(bucket_name, object_key, multipart_upload_id, part_number, options = {}) ⇒ MultipartUploadPart #initialize(options = {}) ⇒ MultipartUploadPart
Returns a new instance of MultipartUploadPart.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 28 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @bucket_name = extract_bucket_name(args, ) @object_key = extract_object_key(args, ) @multipart_upload_id = extract_multipart_upload_id(args, ) @part_number = extract_part_number(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#bucket_name ⇒ String
42 43 44 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 42 def bucket_name @bucket_name end |
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This checksum is present if the object was uploaded with the `CRC32` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
88 89 90 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 88 def checksum_crc32 data[:checksum_crc32] end |
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This checksum is present if the object was uploaded with the `CRC32C` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
101 102 103 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 101 def checksum_crc32c data[:checksum_crc32c] end |
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC64NVME` checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, `CRC64NVME`, to the uploaded object). For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
116 117 118 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 116 def checksum_crc64nvme data[:checksum_crc64nvme] end |
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part. This checksum is present if the multipart upload request was created with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
168 169 170 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 168 def checksum_md5 data[:checksum_md5] end |
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part. This checksum is present if the object was uploaded with the `SHA1` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
129 130 131 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 129 def checksum_sha1 data[:checksum_sha1] end |
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part. This checksum is present if the object was uploaded with the `SHA256` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
142 143 144 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 142 def checksum_sha256 data[:checksum_sha256] end |
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part. This checksum is present if the multipart upload request was created with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
155 156 157 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 155 def checksum_sha512 data[:checksum_sha512] end |
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH128` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
207 208 209 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 207 def checksum_xxhash128 data[:checksum_xxhash128] end |
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH3` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
194 195 196 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 194 def checksum_xxhash3 data[:checksum_xxhash3] end |
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH64` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
181 182 183 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 181 def checksum_xxhash64 data[:checksum_xxhash64] end |
#client ⇒ Client
214 215 216 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 214 def client @client end |
#copy_from(options = {}) ⇒ Types::UploadPartCopyOutput
566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 566 def copy_from( = {}) = .merge( bucket: @bucket_name, key: @object_key, upload_id: @multipart_upload_id, part_number: @part_number ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.upload_part_copy() end resp.data end |
#data ⇒ Types::Part
Returns the data for this Aws::S3::MultipartUploadPart.
229 230 231 232 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 229 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
237 238 239 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 237 def data_loaded? !!@data end |
#etag ⇒ String
Entity tag returned when the part was uploaded.
69 70 71 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 69 def etag data[:etag] end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 809 def identifiers { bucket_name: @bucket_name, object_key: @object_key, multipart_upload_id: @multipart_upload_id, part_number: @part_number } end |
#last_modified ⇒ Time
Date and time at which the part was uploaded.
63 64 65 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 63 def last_modified data[:last_modified] end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
220 221 222 223 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 220 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#multipart_upload ⇒ MultipartUpload
798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 798 def multipart_upload MultipartUpload.new( bucket_name: @bucket_name, object_key: @object_key, id: @multipart_upload_id, client: @client ) end |
#multipart_upload_id ⇒ String
52 53 54 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 52 def multipart_upload_id @multipart_upload_id end |
#object_key ⇒ String
47 48 49 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 47 def object_key @object_key end |
#part_number ⇒ Integer
57 58 59 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 57 def part_number @part_number end |
#size ⇒ Integer
Size in bytes of the uploaded part data.
75 76 77 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 75 def size data[:size] end |
#upload(options = {}) ⇒ Types::UploadPartOutput
782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 782 def upload( = {}) = .merge( bucket: @bucket_name, key: @object_key, upload_id: @multipart_upload_id, part_number: @part_number ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.upload_part() end resp.data end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::S3::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
## Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
## Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
## Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/aws-sdk-s3/multipart_upload_part.rb', line 321 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |