Class: Aws::S3::ObjectAcl
- Inherits:
-
Object
- Object
- Aws::S3::ObjectAcl
- Extended by:
- Deprecations
- Defined in:
- sig/object_acl.rbs,
lib/aws-sdk-s3/object_acl.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #bucket_name ⇒ String
- #grants ⇒ ::Array[Types::Grant]
- #object_key ⇒ String
- #owner ⇒ Types::Owner
- #request_charged ⇒ "requester"
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #object ⇒ Object
Instance Method Summary collapse
- #client ⇒ Client
- #data ⇒ Types::GetObjectAclOutput
- #data_loaded? ⇒ Boolean
- #initialize(*args) ⇒ ObjectAcl constructor
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::S3::Client] #wait_until instead
Constructor Details
#initialize(bucket_name, object_key, options) ⇒ void #initialize(bucket_name:, object_key:, client:) ⇒ void #initialize(args) ⇒ void
24 25 26 27 28 29 30 31 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 24 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @bucket_name = extract_bucket_name(args, ) @object_key = extract_object_key(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#bucket_name ⇒ String
36 37 38 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 36 def bucket_name @bucket_name end |
#data ⇒ Types::GetObjectAclOutput
102 103 104 105 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 102 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
110 111 112 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 110 def data_loaded? !!@data end |
#grants ⇒ ::Array[Types::Grant]
53 54 55 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 53 def grants data[:grants] end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
360 361 362 363 364 365 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 360 def identifiers { bucket_name: @bucket_name, object_key: @object_key } end |
#load ⇒ self Also known as: reload
87 88 89 90 91 92 93 94 95 96 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 87 def load resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.get_object_acl( bucket: @bucket_name, key: @object_key ) end @data = resp.data self end |
#object ⇒ Object
350 351 352 353 354 355 356 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 350 def object Object.new( bucket_name: @bucket_name, key: @object_key, client: @client ) end |
#object_key ⇒ String
41 42 43 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 41 def object_key @object_key end |
#owner ⇒ Types::Owner
47 48 49 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 47 def owner data[:owner] end |
#put(options = {}) ⇒ Object
336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 336 def put( = {}) = .merge( bucket: @bucket_name, key: @object_key ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.put_object_acl() end resp.data end |
#request_charged ⇒ "requester"
70 71 72 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 70 def request_charged data[:request_charged] end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::S3::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-s3/object_acl.rb', line 194 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |