Class: Aws::S3::ObjectVersion
- Inherits:
-
Object
- Object
- Aws::S3::ObjectVersion
- Extended by:
- Deprecations
- Defined in:
- sig/object_version.rbs,
lib/aws-sdk-s3/object_version.rb,
lib/aws-sdk-s3/customizations/object_version.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #bucket_name ⇒ String
- #checksum_algorithm ⇒ ::Array[("CRC32" | "CRC32C" | "SHA1" | "SHA256" | "CRC64NVME" | "SHA512" | "MD5" | "XXHASH64" | "XXHASH3" | "XXHASH128")]
- #checksum_type ⇒ "COMPOSITE", "FULL_OBJECT"
- #etag ⇒ ::String
- #id ⇒ String
- #is_latest ⇒ Boolean
- #key ⇒ ::String
- #last_modified ⇒ ::Time
- #object_key ⇒ String
- #owner ⇒ Types::Owner
- #restore_status ⇒ Types::RestoreStatus
- #size ⇒ ::Integer
- #storage_class ⇒ "STANDARD"
- #version_id ⇒ ::String
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #object ⇒ Object
Instance Method Summary collapse
- #client ⇒ Client
- #data ⇒ Types::ObjectVersion
- #data_loaded? ⇒ Boolean
- #initialize(*args) ⇒ ObjectVersion constructor
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::S3::Client] #wait_until instead
Constructor Details
#initialize(bucket_name, object_key, id, options) ⇒ void #initialize(bucket_name:, object_key:, id:, client:) ⇒ void #initialize(args) ⇒ void
26 27 28 29 30 31 32 33 34 |
# File 'lib/aws-sdk-s3/object_version.rb', line 26 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @bucket_name = extract_bucket_name(args, ) @object_key = extract_object_key(args, ) @id = extract_id(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#bucket_name ⇒ String
39 40 41 |
# File 'lib/aws-sdk-s3/object_version.rb', line 39 def bucket_name @bucket_name end |
#checksum_algorithm ⇒ ::Array[("CRC32" | "CRC32C" | "SHA1" | "SHA256" | "CRC64NVME" | "SHA512" | "MD5" | "XXHASH64" | "XXHASH3" | "XXHASH128")]
61 62 63 |
# File 'lib/aws-sdk-s3/object_version.rb', line 61 def checksum_algorithm data[:checksum_algorithm] end |
#checksum_type ⇒ "COMPOSITE", "FULL_OBJECT"
73 74 75 |
# File 'lib/aws-sdk-s3/object_version.rb', line 73 def checksum_type data[:checksum_type] end |
#client ⇒ Client
137 138 139 |
# File 'lib/aws-sdk-s3/object_version.rb', line 137 def client @client end |
#data ⇒ Types::ObjectVersion
152 153 154 155 |
# File 'lib/aws-sdk-s3/object_version.rb', line 152 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
160 161 162 |
# File 'lib/aws-sdk-s3/object_version.rb', line 160 def data_loaded? !!@data end |
#delete(options = {}) ⇒ Object
353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-s3/object_version.rb', line 353 def delete( = {}) = .merge( bucket: @bucket_name, key: @object_key, version_id: @id ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.delete_object() end resp.data end |
#etag ⇒ ::String
55 56 57 |
# File 'lib/aws-sdk-s3/object_version.rb', line 55 def etag data[:etag] end |
#get(options = {}, &block) ⇒ Object
580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/aws-sdk-s3/object_version.rb', line 580 def get( = {}, &block) = .merge( bucket: @bucket_name, key: @object_key, version_id: @id ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.get_object(, &block) end resp.data end |
#head(options = {}) ⇒ Object
772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/aws-sdk-s3/object_version.rb', line 772 def head( = {}) = .merge( bucket: @bucket_name, key: @object_key, version_id: @id ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.head_object() end resp.data end |
#id ⇒ String
49 50 51 |
# File 'lib/aws-sdk-s3/object_version.rb', line 49 def id @id end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
797 798 799 800 801 802 803 |
# File 'lib/aws-sdk-s3/object_version.rb', line 797 def identifiers { bucket_name: @bucket_name, object_key: @object_key, id: @id } end |
#is_latest ⇒ Boolean
104 105 106 |
# File 'lib/aws-sdk-s3/object_version.rb', line 104 def is_latest data[:is_latest] end |
#key ⇒ ::String
91 92 93 |
# File 'lib/aws-sdk-s3/object_version.rb', line 91 def key data[:key] end |
#last_modified ⇒ ::Time
110 111 112 |
# File 'lib/aws-sdk-s3/object_version.rb', line 110 def last_modified data[:last_modified] end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
143 144 145 146 |
# File 'lib/aws-sdk-s3/object_version.rb', line 143 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#object ⇒ Object
787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-s3/object_version.rb', line 787 def object Object.new( bucket_name: @bucket_name, key: @object_key, client: @client ) end |
#object_key ⇒ String
44 45 46 |
# File 'lib/aws-sdk-s3/object_version.rb', line 44 def object_key @object_key end |
#owner ⇒ Types::Owner
116 117 118 |
# File 'lib/aws-sdk-s3/object_version.rb', line 116 def owner data[:owner] end |
#restore_status ⇒ Types::RestoreStatus
130 131 132 |
# File 'lib/aws-sdk-s3/object_version.rb', line 130 def restore_status data[:restore_status] end |
#size ⇒ ::Integer
79 80 81 |
# File 'lib/aws-sdk-s3/object_version.rb', line 79 def size data[:size] end |
#storage_class ⇒ "STANDARD"
85 86 87 |
# File 'lib/aws-sdk-s3/object_version.rb', line 85 def storage_class data[:storage_class] end |
#version_id ⇒ ::String
97 98 99 |
# File 'lib/aws-sdk-s3/object_version.rb', line 97 def version_id data[:version_id] end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::S3::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-s3/object_version.rb', line 244 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |