Class: Aws::S3::Types::AnnotationEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::AnnotationEntry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Describes a single annotation attached to an object, including its name, last modified time, size, ETag, checksum algorithm, and replication status. Returned in the response from ‘ListObjectAnnotations`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_name ⇒ String
The name of the annotation.
-
#checksum_algorithm ⇒ Array<String>
The checksum algorithm used for the annotation.
-
#etag ⇒ String
The entity tag of the annotation.
-
#last_modified ⇒ Time
The date and time the annotation was last modified.
-
#replication_status ⇒ String
The replication status of the annotation.
-
#size ⇒ Integer
The size of the annotation payload, in bytes.
Instance Attribute Details
#annotation_name ⇒ String
The name of the annotation.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ Array<String>
The checksum algorithm used for the annotation.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The entity tag of the annotation.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date and time the annotation was last modified.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |
#replication_status ⇒ String
The replication status of the annotation.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the annotation payload, in bytes.
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-s3/types.rb', line 419 class AnnotationEntry < Struct.new( :annotation_name, :last_modified, :etag, :checksum_algorithm, :size, :replication_status) SENSITIVE = [] include Aws::Structure end |