Class: Aws::S3::Types::AnnotationTableConfigurationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::AnnotationTableConfigurationResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Contains the current state of the annotation table associated with a bucket’s Amazon S3 Metadata configuration, including its provisioning status and identifiers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_state ⇒ String
The current configuration state of the annotation table.
-
#error ⇒ Types::ErrorDetails
If an S3 Metadata V1 ‘CreateBucketMetadataTableConfiguration` or V2 `CreateBucketMetadataConfiguration` request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
-
#role ⇒ String
The ARN of the IAM role associated with the annotation table.
-
#table_arn ⇒ String
The ARN of the annotation table.
-
#table_name ⇒ String
The name of the annotation table.
-
#table_status ⇒ String
The provisioning status of the annotation table.
Instance Attribute Details
#configuration_state ⇒ String
The current configuration state of the annotation table.
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::ErrorDetails
If an S3 Metadata V1 ‘CreateBucketMetadataTableConfiguration` or V2 `CreateBucketMetadataConfiguration` request succeeds, but S3 Metadata was unable to create the table, this structure contains the error code and error message.
<note markdown=“1”> If you created your S3 Metadata configuration before July 15, 2025, we recommend that you delete and re-create your configuration by using [CreateBucketMetadataConfiguration] so that you can expire journal table records and create a live inventory table.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucketMetadataConfiguration.html
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the IAM role associated with the annotation table.
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |
#table_arn ⇒ String
The ARN of the annotation table.
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the annotation table.
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |
#table_status ⇒ String
The provisioning status of the annotation table. Possible values: ‘CREATING`, `BACKFILLING`, `ACTIVE`, `FAILED`.
517 518 519 520 521 522 523 524 525 526 |
# File 'lib/aws-sdk-s3/types.rb', line 517 class AnnotationTableConfigurationResult < Struct.new( :configuration_state, :table_status, :error, :table_name, :table_arn, :role) SENSITIVE = [] include Aws::Structure end |