Class: Aws::S3::Types::CompletedPart
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::CompletedPart
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Details of the parts that were uploaded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part.
-
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part.
-
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part.
-
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part.
-
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part.
-
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part.
-
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part.
-
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part.
-
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part.
-
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part.
-
#etag ⇒ String
Entity tag returned when the part was uploaded.
-
#part_number ⇒ Integer
Part number that identifies the part.
Instance Attribute Details
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32C` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC64NVME` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part. This checksum is present if the multipart upload request was created with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part. This checksum is present if the multipart upload request was created with the `SHA1` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part. This checksum is present if the multipart upload request was created with the `SHA256` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part. This checksum is present if the multipart upload request was created with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH128` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH3` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH64` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
Entity tag returned when the part was uploaded.
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |
#part_number ⇒ Integer
Part number that identifies the part. This is a positive integer between 1 and 10,000.
<note markdown=“1”> * **General purpose buckets** - In ‘CompleteMultipartUpload`, when a
additional checksum (including `x-amz-checksum-crc32`,
`x-amz-checksum-crc32c`, `x-amz-checksum-sha1`, or
`x-amz-checksum-sha256`) is applied to each part, the `PartNumber`
must start at 1 and the part numbers must be consecutive.
Otherwise, Amazon S3 generates an HTTP `400 Bad Request` status
code and an `InvalidPartOrder` error code.
-
**Directory buckets** - In ‘CompleteMultipartUpload`, the `PartNumber` must start at 1 and the part numbers must be consecutive.
</note>
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-s3/types.rb', line 1732 class CompletedPart < Struct.new( :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :part_number) SENSITIVE = [] include Aws::Structure end |