Class: Aws::S3::Types::CopyObjectResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::CopyObjectResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Container for all response elements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the object.
-
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the object.
-
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the object.
-
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the object.
-
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` digest of the object.
-
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` digest of the object.
-
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the object.
-
#checksum_type ⇒ String
The checksum type that is used to calculate the object’s checksum value.
-
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the object.
-
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the object.
-
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the object.
-
#etag ⇒ String
Returns the ETag of the new object.
-
#last_modified ⇒ Time
Creation date of the object.
Instance Attribute Details
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the object. This checksum is only present if the object was uploaded with the object. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the object. This checksum is only present if the checksum was uploaded with the object. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the object. This checksum is present if the object being copied was uploaded with the `CRC64NVME` checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, `CRC64NVME`, to the uploaded object). For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the object. This checksum is only present if the object was uploaded with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` digest of the object. This checksum is only present if the checksum was uploaded with the object. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` digest of the object. This checksum is only present if the checksum was uploaded with the object. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the object. This checksum is only present if the object was uploaded with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_type ⇒ String
The checksum type that is used to calculate the object’s checksum value. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the object. This checksum is only present if the object was uploaded with the `XXHASH128` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the object. This checksum is only present if the object was uploaded with the `XXHASH3` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the object. This checksum is only present if the object was uploaded with the `XXHASH64` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
Returns the ETag of the new object. The ETag reflects only changes to the contents of an object, not its metadata.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
Creation date of the object.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-s3/types.rb', line 2970 class CopyObjectResult < Struct.new( :etag, :last_modified, :checksum_type, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |