Class: Aws::S3::Types::CopyPartResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::CopyPartResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Container for all response elements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part.
-
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part.
-
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part.
-
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part.
-
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` digest of the part.
-
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` digest of the part.
-
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part.
-
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part.
-
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part.
-
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part.
-
#etag ⇒ String
Entity tag of the object.
-
#last_modified ⇒ Time
Date and time at which the object was uploaded.
Instance Attribute Details
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC32C` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This checksum is present if the multipart upload request was created with the `CRC64NVME` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` digest of the part. This checksum is present if the multipart upload request was created with the `MD5` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` digest of the part. This checksum is present if the multipart upload request was created with the `SHA1` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` digest of the part. This checksum is present if the multipart upload request was created with the `SHA256` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` digest of the part. This checksum is present if the multipart upload request was created with the `SHA512` checksum algorithm. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH128` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH3` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This checksum is present if the multipart upload request was created with the `XXHASH64` checksum algorithm. For more information, see
- Checking object integrity][1
-
in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
Entity tag of the object.
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
Date and time at which the object was uploaded.
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/aws-sdk-s3/types.rb', line 3110 class CopyPartResult < Struct.new( :etag, :last_modified, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128) SENSITIVE = [] include Aws::Structure end |