Class: Aws::S3::Types::DeleteBucketAnalyticsConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteBucketAnalyticsConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket from which an analytics configuration is deleted.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID that identifies the analytics configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket from which an analytics configuration is deleted.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-s3/types.rb', line 4780 class DeleteBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-s3/types.rb', line 4780 class DeleteBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID that identifies the analytics configuration.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-s3/types.rb', line 4780 class DeleteBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |