Class: Aws::S3::Types::DeleteBucketAnalyticsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket from which an analytics configuration is deleted.

Returns:

  • (String)


4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-s3/types.rb', line 4573

class DeleteBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-s3/types.rb', line 4573

class DeleteBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID that identifies the analytics configuration.

Returns:

  • (String)


4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-s3/types.rb', line 4573

class DeleteBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end