Class: Aws::S3::Types::DeleteBucketIntelligentTieringConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteBucketIntelligentTieringConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
4868 4869 4870 4871 4872 4873 4874 |
# File 'lib/aws-sdk-s3/types.rb', line 4868 class DeleteBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
4868 4869 4870 4871 4872 4873 4874 |
# File 'lib/aws-sdk-s3/types.rb', line 4868 class DeleteBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
4868 4869 4870 4871 4872 4873 4874 |
# File 'lib/aws-sdk-s3/types.rb', line 4868 class DeleteBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |