Class: Aws::S3::Types::DeleteBucketReplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name.

Returns:

  • (String)


5114
5115
5116
5117
5118
5119
# File 'lib/aws-sdk-s3/types.rb', line 5114

class DeleteBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


5114
5115
5116
5117
5118
5119
# File 'lib/aws-sdk-s3/types.rb', line 5114

class DeleteBucketReplicationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end