Class: Aws::S3::Types::DeleteBucketReplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteBucketReplicationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The bucket name.
4506 4507 4508 4509 4510 4511 |
# File 'lib/aws-sdk-s3/types.rb', line 4506 class DeleteBucketReplicationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
4506 4507 4508 4509 4510 4511 |
# File 'lib/aws-sdk-s3/types.rb', line 4506 class DeleteBucketReplicationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |