Class: Aws::S3::Types::DeleteObjectAnnotationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#object_version_idString

The version ID of the object that the annotation was deleted from.

Returns:

  • (String)


5298
5299
5300
5301
5302
5303
# File 'lib/aws-sdk-s3/types.rb', line 5298

class DeleteObjectAnnotationOutput < Struct.new(
  :object_version_id,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


5298
5299
5300
5301
5302
5303
# File 'lib/aws-sdk-s3/types.rb', line 5298

class DeleteObjectAnnotationOutput < Struct.new(
  :object_version_id,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end