Class: Aws::S3::Types::DeleteObjectAnnotationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteObjectAnnotationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#object_version_id ⇒ String
The version ID of the object that the annotation was deleted from.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#object_version_id ⇒ String
The version ID of the object that the annotation was deleted from.
5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-s3/types.rb', line 5298 class DeleteObjectAnnotationOutput < Struct.new( :object_version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-s3/types.rb', line 5298 class DeleteObjectAnnotationOutput < Struct.new( :object_version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |