Class: Aws::S3::Types::DeleteObjectAnnotationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeleteObjectAnnotationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#object_version_id ⇒ String
The version ID of the object that the annotation was deleted from.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#object_version_id ⇒ String
The version ID of the object that the annotation was deleted from.
5293 5294 5295 5296 5297 5298 |
# File 'lib/aws-sdk-s3/types.rb', line 5293 class DeleteObjectAnnotationOutput < Struct.new( :object_version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html
5293 5294 5295 5296 5297 5298 |
# File 'lib/aws-sdk-s3/types.rb', line 5293 class DeleteObjectAnnotationOutput < Struct.new( :object_version_id, :request_charged) SENSITIVE = [] include Aws::Structure end |