Class: Aws::S3::Types::DeleteObjectAnnotationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_nameString

The name of the annotation to delete. Annotation names are UTF-8 encoded and cannot start with aws or s3 (case-insensitive).

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket that contains the object.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#object_if_matchString

If specified, the operation only succeeds if the object's ETag matches the provided value.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the object.

Returns:

  • (String)


5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
# File 'lib/aws-sdk-s3/types.rb', line 5354

class DeleteObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :object_if_match)
  SENSITIVE = []
  include Aws::Structure
end