Class: Aws::S3::Types::DeletePublicAccessBlockRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The Amazon S3 bucket whose PublicAccessBlock configuration you want to delete.

Returns:

  • (String)


5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-s3/types.rb', line 5878

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-s3/types.rb', line 5878

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end