Class: Aws::S3::Types::DeletePublicAccessBlockRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The Amazon S3 bucket whose ‘PublicAccessBlock` configuration you want to delete.

Returns:

  • (String)


5577
5578
5579
5580
5581
5582
# File 'lib/aws-sdk-s3/types.rb', line 5577

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


5577
5578
5579
5580
5581
5582
# File 'lib/aws-sdk-s3/types.rb', line 5577

class DeletePublicAccessBlockRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end