Class: Aws::S3::Types::DeletePublicAccessBlockRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::DeletePublicAccessBlockRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The Amazon S3 bucket whose
PublicAccessBlockconfiguration you want to delete. -
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The Amazon S3 bucket whose PublicAccessBlock configuration you want to delete.
5171 5172 5173 5174 5175 5176 |
# File 'lib/aws-sdk-s3/types.rb', line 5171 class DeletePublicAccessBlockRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
5171 5172 5173 5174 5175 5176 |
# File 'lib/aws-sdk-s3/types.rb', line 5171 class DeletePublicAccessBlockRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |