Class: Aws::S3::Types::ErrorDocument

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The error information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The object key name to use when a 4XX class error occurs.

Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.

Returns:

  • (String)


7133
7134
7135
7136
7137
# File 'lib/aws-sdk-s3/types.rb', line 7133

class ErrorDocument < Struct.new(
  :key)
  SENSITIVE = []
  include Aws::Structure
end