Class: Aws::S3::Types::EventHoldDuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::EventHoldDuration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Contains the event hold duration configuration, specified in either days or years.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#days ⇒ Integer
The number of days for the event hold duration.
-
#years ⇒ Integer
The number of years for the event hold duration.
Instance Attribute Details
#days ⇒ Integer
The number of days for the event hold duration. The minimum value is 1 and the maximum value is 36,500.
7229 7230 7231 7232 7233 7234 |
# File 'lib/aws-sdk-s3/types.rb', line 7229 class EventHoldDuration < Struct.new( :days, :years) SENSITIVE = [] include Aws::Structure end |
#years ⇒ Integer
The number of years for the event hold duration. The minimum value is 1 and the maximum value is 100.
7229 7230 7231 7232 7233 7234 |
# File 'lib/aws-sdk-s3/types.rb', line 7229 class EventHoldDuration < Struct.new( :days, :years) SENSITIVE = [] include Aws::Structure end |