Class: Aws::S3::Types::GetBucketAccelerateConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


7259
7260
7261
7262
7263
7264
# File 'lib/aws-sdk-s3/types.rb', line 7259

class GetBucketAccelerateConfigurationOutput < Struct.new(
  :status,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The accelerate configuration of the bucket.

Returns:

  • (String)


7259
7260
7261
7262
7263
7264
# File 'lib/aws-sdk-s3/types.rb', line 7259

class GetBucketAccelerateConfigurationOutput < Struct.new(
  :status,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end