Class: Aws::S3::Types::GetBucketAnalyticsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket from which an analytics configuration is retrieved.

Returns:

  • (String)


7387
7388
7389
7390
7391
7392
7393
# File 'lib/aws-sdk-s3/types.rb', line 7387

class GetBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


7387
7388
7389
7390
7391
7392
7393
# File 'lib/aws-sdk-s3/types.rb', line 7387

class GetBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID that identifies the analytics configuration.

Returns:

  • (String)


7387
7388
7389
7390
7391
7392
7393
# File 'lib/aws-sdk-s3/types.rb', line 7387

class GetBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end