Class: Aws::S3::Types::GetBucketIntelligentTieringConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketIntelligentTieringConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
7526 7527 7528 7529 7530 7531 7532 |
# File 'lib/aws-sdk-s3/types.rb', line 7526 class GetBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
7526 7527 7528 7529 7530 7531 7532 |
# File 'lib/aws-sdk-s3/types.rb', line 7526 class GetBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
7526 7527 7528 7529 7530 7531 7532 |
# File 'lib/aws-sdk-s3/types.rb', line 7526 class GetBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |