Class: Aws::S3::Types::GetBucketIntelligentTieringConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.

Returns:



6810
6811
6812
6813
6814
6815
6816
# File 'lib/aws-sdk-s3/types.rb', line 6810

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



6810
6811
6812
6813
6814
6815
6816
# File 'lib/aws-sdk-s3/types.rb', line 6810

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the S3 Intelligent-Tiering configuration.

Returns:



6810
6811
6812
6813
6814
6815
6816
# File 'lib/aws-sdk-s3/types.rb', line 6810

class GetBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end