Class: Aws::S3::Types::GetBucketInventoryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketInventoryConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket containing the inventory configuration to retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the inventory configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket containing the inventory configuration to retrieve.
Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ‘s3express-control.region-code.amazonaws.com/bucket-name `. Virtual-hosted-style requests aren’t supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format ‘ bucket-base-name–zone-id–x-s3` (for example, ` DOC-EXAMPLE-BUCKET–usw2-az1–x-s3`). For information about bucket naming restrictions, see [Directory bucket naming rules] in the *Amazon S3 User Guide*
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-bucket-naming-rules.html
7275 7276 7277 7278 7279 7280 7281 |
# File 'lib/aws-sdk-s3/types.rb', line 7275 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
<note markdown=“1”> For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code ‘501 Not Implemented`.
</note>
7275 7276 7277 7278 7279 7280 7281 |
# File 'lib/aws-sdk-s3/types.rb', line 7275 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the inventory configuration.
7275 7276 7277 7278 7279 7280 7281 |
# File 'lib/aws-sdk-s3/types.rb', line 7275 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |