Class: Aws::S3::Types::GetBucketInventoryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketInventoryConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket containing the inventory configuration to retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the inventory configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket containing the inventory configuration to retrieve.
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-s3/types.rb', line 6848 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-s3/types.rb', line 6848 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the inventory configuration.
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-s3/types.rb', line 6848 class GetBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |