Class: Aws::S3::Types::GetBucketLifecycleConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the lifecycle information.

Returns:

  • (String)


7647
7648
7649
7650
7651
7652
# File 'lib/aws-sdk-s3/types.rb', line 7647

class GetBucketLifecycleConfigurationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.

Returns:

  • (String)


7647
7648
7649
7650
7651
7652
# File 'lib/aws-sdk-s3/types.rb', line 7647

class GetBucketLifecycleConfigurationRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end