Class: Aws::S3::Types::GetBucketLifecycleRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the lifecycle information.

Returns:

  • (String)


7665
7666
7667
7668
7669
7670
# File 'lib/aws-sdk-s3/types.rb', line 7665

class GetBucketLifecycleRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


7665
7666
7667
7668
7669
7670
# File 'lib/aws-sdk-s3/types.rb', line 7665

class GetBucketLifecycleRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end