Class: Aws::S3::Types::GetBucketLoggingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketLoggingRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name for which to get the logging information.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The bucket name for which to get the logging information.
7758 7759 7760 7761 7762 7763 |
# File 'lib/aws-sdk-s3/types.rb', line 7758 class GetBucketLoggingRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
7758 7759 7760 7761 7762 7763 |
# File 'lib/aws-sdk-s3/types.rb', line 7758 class GetBucketLoggingRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |