Class: Aws::S3::Types::GetBucketPolicyStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketPolicyStatusRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose policy status you want to retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose policy status you want to retrieve.
7817 7818 7819 7820 7821 7822 |
# File 'lib/aws-sdk-s3/types.rb', line 7817 class GetBucketPolicyStatusRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
7817 7818 7819 7820 7821 7822 |
# File 'lib/aws-sdk-s3/types.rb', line 7817 class GetBucketPolicyStatusRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |