Class: Aws::S3::Types::GetBucketReplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketReplicationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name for which to get the replication information.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The bucket name for which to get the replication information.
8160 8161 8162 8163 8164 8165 |
# File 'lib/aws-sdk-s3/types.rb', line 8160 class GetBucketReplicationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
8160 8161 8162 8163 8164 8165 |
# File 'lib/aws-sdk-s3/types.rb', line 8160 class GetBucketReplicationRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |