Class: Aws::S3::Types::GetBucketRequestPaymentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketRequestPaymentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket for which to get the payment request configuration.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket for which to get the payment request configuration
8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-s3/types.rb', line 8179 class GetBucketRequestPaymentRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-s3/types.rb', line 8179 class GetBucketRequestPaymentRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |