Class: Aws::S3::Types::GetBucketRequestPaymentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the payment request configuration

Returns:

  • (String)


7883
7884
7885
7886
7887
7888
# File 'lib/aws-sdk-s3/types.rb', line 7883

class GetBucketRequestPaymentRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


7883
7884
7885
7886
7887
7888
# File 'lib/aws-sdk-s3/types.rb', line 7883

class GetBucketRequestPaymentRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end