Class: Aws::S3::Types::GetBucketVersioningOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mfa_deleteString

Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is only returned if the bucket has been configured with MFA delete. If the bucket has never been so configured, this element is not returned.

Returns:

  • (String)


8231
8232
8233
8234
8235
8236
# File 'lib/aws-sdk-s3/types.rb', line 8231

class GetBucketVersioningOutput < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The versioning state of the bucket.

Returns:

  • (String)


8231
8232
8233
8234
8235
8236
# File 'lib/aws-sdk-s3/types.rb', line 8231

class GetBucketVersioningOutput < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end