Class: Aws::S3::Types::GetBucketVersioningRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which to get the versioning information.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
# File 'lib/aws-sdk-s3/types.rb', line 8251

class GetBucketVersioningRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
# File 'lib/aws-sdk-s3/types.rb', line 8251

class GetBucketVersioningRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end