Class: Aws::S3::Types::GetBucketWebsiteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetBucketWebsiteRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The bucket name for which to get the website configuration.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The bucket name for which to get the website configuration.
8316 8317 8318 8319 8320 8321 |
# File 'lib/aws-sdk-s3/types.rb', line 8316 class GetBucketWebsiteRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
8316 8317 8318 8319 8320 8321 |
# File 'lib/aws-sdk-s3/types.rb', line 8316 class GetBucketWebsiteRequest < Struct.new( :bucket, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |