Class: Aws::S3::Types::GetBucketWebsiteRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The bucket name for which to get the website configuration.

Returns:

  • (String)


8006
8007
8008
8009
8010
8011
# File 'lib/aws-sdk-s3/types.rb', line 8006

class GetBucketWebsiteRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


8006
8007
8008
8009
8010
8011
# File 'lib/aws-sdk-s3/types.rb', line 8006

class GetBucketWebsiteRequest < Struct.new(
  :bucket,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end