Class: Aws::S3::Types::GetObjectAclOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grantsArray<Types::Grant>

A list of grants.

Returns:



8348
8349
8350
8351
8352
8353
8354
# File 'lib/aws-sdk-s3/types.rb', line 8348

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#ownerTypes::Owner

Container for the bucket owner's ID.

Returns:



8348
8349
8350
8351
8352
8353
8354
# File 'lib/aws-sdk-s3/types.rb', line 8348

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


8348
8349
8350
8351
8352
8353
8354
# File 'lib/aws-sdk-s3/types.rb', line 8348

class GetObjectAclOutput < Struct.new(
  :owner,
  :grants,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end