Class: Aws::S3::Types::GetObjectAclOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectAclOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grants ⇒ Array<Types::Grant>
A list of grants.
-
#owner ⇒ Types::Owner
Container for the bucket owner's ID.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#grants ⇒ Array<Types::Grant>
A list of grants.
8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-s3/types.rb', line 8348 class GetObjectAclOutput < Struct.new( :owner, :grants, :request_charged) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ Types::Owner
Container for the bucket owner's ID.
8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-s3/types.rb', line 8348 class GetObjectAclOutput < Struct.new( :owner, :grants, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-s3/types.rb', line 8348 class GetObjectAclOutput < Struct.new( :owner, :grants, :request_charged) SENSITIVE = [] include Aws::Structure end |