Class: Aws::S3::Types::GetObjectAnnotationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectAnnotationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_payload ⇒ IO
The annotation payload.
-
#checksum_crc32 ⇒ String
The CRC32 checksum of the annotation payload.
-
#checksum_crc32c ⇒ String
The CRC32C checksum of the annotation payload.
-
#checksum_crc64nvme ⇒ String
The CRC64NVME checksum of the annotation payload.
-
#checksum_md5 ⇒ String
The MD5 checksum of the annotation payload.
-
#checksum_sha1 ⇒ String
The SHA1 checksum of the annotation payload.
-
#checksum_sha256 ⇒ String
The SHA256 checksum of the annotation payload.
-
#checksum_sha512 ⇒ String
The SHA512 checksum of the annotation payload.
-
#checksum_type ⇒ String
The type of checksum used.
-
#checksum_xxhash128 ⇒ String
The XXHASH128 checksum of the annotation payload.
-
#checksum_xxhash3 ⇒ String
The XXHASH3 checksum of the annotation payload.
-
#checksum_xxhash64 ⇒ String
The XXHASH64 checksum of the annotation payload.
-
#content_length ⇒ Integer
The size of the annotation payload, in bytes.
-
#etag ⇒ String
The entity tag of the annotation.
-
#last_modified ⇒ Time
The date and time the annotation was last modified.
-
#object_version_id ⇒ String
The version ID of the object that the annotation is attached to.
-
#replication_status ⇒ String
The replication status of the annotation.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#server_side_encryption ⇒ String
The server-side encryption algorithm used.
Instance Attribute Details
#annotation_payload ⇒ IO
The annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32 ⇒ String
The CRC32 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
The CRC32C checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The CRC64NVME checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
The MD5 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
The SHA1 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
The SHA256 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
The SHA512 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_type ⇒ String
The type of checksum used.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The XXHASH128 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The XXHASH3 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The XXHASH64 checksum of the annotation payload.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#content_length ⇒ Integer
The size of the annotation payload, in bytes.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The entity tag of the annotation.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date and time the annotation was last modified.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#object_version_id ⇒ String
The version ID of the object that the annotation is attached to.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#replication_status ⇒ String
The replication status of the annotation. Possible values include
PENDING, COMPLETED, FAILED, and REPLICA.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |
#server_side_encryption ⇒ String
The server-side encryption algorithm used.
8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/aws-sdk-s3/types.rb', line 8518 class GetObjectAnnotationOutput < Struct.new( :annotation_payload, :object_version_id, :last_modified, :content_length, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged, :replication_status) SENSITIVE = [] include Aws::Structure end |