Class: Aws::S3::Types::GetObjectAnnotationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_payloadIO

The annotation payload.

Returns:

  • (IO)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32String

The CRC32 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32cString

The CRC32C checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc64nvmeString

The CRC64NVME checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_md5String

The MD5 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha1String

The SHA1 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha256String

The SHA256 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha512String

The SHA512 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_typeString

The type of checksum used.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash128String

The XXHASH128 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash3String

The XXHASH3 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash64String

The XXHASH64 checksum of the annotation payload.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#content_lengthInteger

The size of the annotation payload, in bytes.

Returns:

  • (Integer)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The entity tag of the annotation.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time the annotation was last modified.

Returns:

  • (Time)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#object_version_idString

The version ID of the object that the annotation is attached to.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#replication_statusString

The replication status of the annotation. Possible values include ‘PENDING`, `COMPLETED`, `FAILED`, and `REPLICA`.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end

#server_side_encryptionString

The server-side encryption algorithm used.

Returns:

  • (String)


8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
# File 'lib/aws-sdk-s3/types.rb', line 8504

class GetObjectAnnotationOutput < Struct.new(
  :annotation_payload,
  :object_version_id,
  :last_modified,
  :content_length,
  :etag,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :checksum_type,
  :server_side_encryption,
  :request_charged,
  :replication_status)
  SENSITIVE = []
  include Aws::Structure
end