Class: Aws::S3::Types::GetObjectAnnotationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_nameString

The name of the annotation to retrieve.

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket that contains the object.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_modeString

Set to ‘ENABLED` to validate the checksum of the annotation payload on retrieval.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the object.

Returns:

  • (String)


8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-s3/types.rb', line 8578

class GetObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :annotation_name,
  :version_id,
  :request_payer,
  :expected_bucket_owner,
  :checksum_mode)
  SENSITIVE = []
  include Aws::Structure
end