Class: Aws::S3::Types::GetObjectAnnotationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectAnnotationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_name ⇒ String
The name of the annotation to retrieve.
-
#bucket ⇒ String
The name of the bucket that contains the object.
-
#checksum_mode ⇒ String
Set to ‘ENABLED` to validate the checksum of the annotation payload on retrieval.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#key ⇒ String
The object key.
-
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request.
-
#version_id ⇒ String
The version ID of the object.
Instance Attribute Details
#annotation_name ⇒ String
The name of the annotation to retrieve.
Length Constraints: Minimum length of 1. Maximum length of 512 bytes.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket that contains the object.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#checksum_mode ⇒ String
Set to ‘ENABLED` to validate the checksum of the annotation payload on retrieval.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the object.
8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 |
# File 'lib/aws-sdk-s3/types.rb', line 8578 class GetObjectAnnotationRequest < Struct.new( :bucket, :key, :annotation_name, :version_id, :request_payer, :expected_bucket_owner, :checksum_mode) SENSITIVE = [] include Aws::Structure end |