Class: Aws::S3::Types::GetObjectTorrentOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bodyIO

A Bencoded dictionary as defined by the BitTorrent specification

Returns:

  • (IO)


10032
10033
10034
10035
10036
10037
# File 'lib/aws-sdk-s3/types.rb', line 10032

class GetObjectTorrentOutput < Struct.new(
  :body,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


10032
10033
10034
10035
10036
10037
# File 'lib/aws-sdk-s3/types.rb', line 10032

class GetObjectTorrentOutput < Struct.new(
  :body,
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end