Class: Aws::S3::Types::GetObjectTorrentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::GetObjectTorrentOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ IO
A Bencoded dictionary as defined by the BitTorrent specification.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#body ⇒ IO
A Bencoded dictionary as defined by the BitTorrent specification
10151 10152 10153 10154 10155 10156 |
# File 'lib/aws-sdk-s3/types.rb', line 10151 class GetObjectTorrentOutput < Struct.new( :body, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
10151 10152 10153 10154 10155 10156 |
# File 'lib/aws-sdk-s3/types.rb', line 10151 class GetObjectTorrentOutput < Struct.new( :body, :request_charged) SENSITIVE = [] include Aws::Structure end |