Class: Aws::S3::Types::HeadBucketOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::HeadBucketOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_alias ⇒ Boolean
Indicates whether the bucket name used in the request is an access point alias.
-
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket.
-
#bucket_location_name ⇒ String
The name of the location where the bucket will be created.
-
#bucket_location_type ⇒ String
The type of location where the bucket is created.
-
#bucket_region ⇒ String
The Region that the bucket is located.
Instance Attribute Details
#access_point_alias ⇒ Boolean
Indicates whether the bucket name used in the request is an access point alias.
<note markdown=“1”> For directory buckets, the value of this field is ‘false`.
</note>
10219 10220 10221 10222 10223 10224 10225 10226 10227 |
# File 'lib/aws-sdk-s3/types.rb', line 10219 class HeadBucketOutput < Struct.new( :bucket_arn, :bucket_location_type, :bucket_location_name, :bucket_region, :access_point_alias) SENSITIVE = [] include Aws::Structure end |
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket. ARNs uniquely identify Amazon Web Services resources across all of Amazon Web Services.
<note markdown=“1”> This parameter is only supported for S3 directory buckets. For more information, see [Using tags with directory buckets].
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-buckets-tagging.html
10219 10220 10221 10222 10223 10224 10225 10226 10227 |
# File 'lib/aws-sdk-s3/types.rb', line 10219 class HeadBucketOutput < Struct.new( :bucket_arn, :bucket_location_type, :bucket_location_name, :bucket_region, :access_point_alias) SENSITIVE = [] include Aws::Structure end |
#bucket_location_name ⇒ String
The name of the location where the bucket will be created.
For directory buckets, the Zone ID of the Availability Zone or the Local Zone where the bucket is created. An example Zone ID value for an Availability Zone is ‘usw2-az1`.
<note markdown=“1”> This functionality is only supported by directory buckets.
</note>
10219 10220 10221 10222 10223 10224 10225 10226 10227 |
# File 'lib/aws-sdk-s3/types.rb', line 10219 class HeadBucketOutput < Struct.new( :bucket_arn, :bucket_location_type, :bucket_location_name, :bucket_region, :access_point_alias) SENSITIVE = [] include Aws::Structure end |
#bucket_location_type ⇒ String
The type of location where the bucket is created.
<note markdown=“1”> This functionality is only supported by directory buckets.
</note>
10219 10220 10221 10222 10223 10224 10225 10226 10227 |
# File 'lib/aws-sdk-s3/types.rb', line 10219 class HeadBucketOutput < Struct.new( :bucket_arn, :bucket_location_type, :bucket_location_name, :bucket_region, :access_point_alias) SENSITIVE = [] include Aws::Structure end |
#bucket_region ⇒ String
The Region that the bucket is located.
10219 10220 10221 10222 10223 10224 10225 10226 10227 |
# File 'lib/aws-sdk-s3/types.rb', line 10219 class HeadBucketOutput < Struct.new( :bucket_arn, :bucket_location_type, :bucket_location_name, :bucket_region, :access_point_alias) SENSITIVE = [] include Aws::Structure end |