Class: Aws::S3::Types::InvalidObjectState

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Object is archived and inaccessible until restored.

If the object you are retrieving is stored in the S3 Glacier Flexible Retrieval storage class, the S3 Glacier Deep Archive storage class, the S3 Intelligent-Tiering Archive Access tier, or the S3 Intelligent-Tiering Deep Archive Access tier, before you can retrieve the object you must first restore a copy using [RestoreObject]. Otherwise, this operation returns an ‘InvalidObjectState` error. For information about restoring archived objects, see [Restoring Archived Objects] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html [2]: docs.aws.amazon.com/AmazonS3/latest/dev/restoring-objects.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tierString

Returns:

  • (String)


10865
10866
10867
10868
10869
10870
# File 'lib/aws-sdk-s3/types.rb', line 10865

class InvalidObjectState < Struct.new(
  :storage_class,
  :access_tier)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

Returns:

  • (String)


10865
10866
10867
10868
10869
10870
# File 'lib/aws-sdk-s3/types.rb', line 10865

class InvalidObjectState < Struct.new(
  :storage_class,
  :access_tier)
  SENSITIVE = []
  include Aws::Structure
end