Class: Aws::S3::Types::InventoryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::InventoryConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Specifies the S3 Inventory configuration for an Amazon S3 bucket. For more information, see GET Bucket inventory in the Amazon S3 API Reference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ Types::InventoryDestination
Contains information about where to publish the inventory results.
-
#filter ⇒ Types::InventoryFilter
Specifies an inventory filter.
-
#id ⇒ String
The ID used to identify the inventory configuration.
-
#included_object_versions ⇒ String
Object versions to include in the inventory list.
-
#is_enabled ⇒ Boolean
Specifies whether the inventory is enabled or disabled.
-
#optional_fields ⇒ Array<String>
Contains the optional fields that are included in the inventory results.
-
#schedule ⇒ Types::InventorySchedule
Specifies the schedule for generating inventory results.
Instance Attribute Details
#destination ⇒ Types::InventoryDestination
Contains information about where to publish the inventory results.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::InventoryFilter
Specifies an inventory filter. The inventory only includes objects that meet the filter's criteria.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the inventory configuration.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#included_object_versions ⇒ String
Object versions to include in the inventory list. If set to All,
the list includes all the object versions, which adds the
version-related fields VersionId, IsLatest, and DeleteMarker
to the list. If set to Current, the list does not contain these
version-related fields.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#is_enabled ⇒ Boolean
Specifies whether the inventory is enabled or disabled. If set to
True, an inventory list is generated. If set to False, no
inventory list is generated.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#optional_fields ⇒ Array<String>
Contains the optional fields that are included in the inventory results.
Size | LastModifiedDate | StorageClass | ETag | IsMultipartUploaded | EncryptionStatus | BucketKeyStatus | ChecksumAlgorithm | LifecycleExpirationDate. Throws MalformedXML error if unsupported
optional field is provided.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::InventorySchedule
Specifies the schedule for generating inventory results.
11424 11425 11426 11427 11428 11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-s3/types.rb', line 11424 class InventoryConfiguration < Struct.new( :destination, :is_enabled, :filter, :id, :included_object_versions, :optional_fields, :schedule) SENSITIVE = [] include Aws::Structure end |