Class: Aws::S3::Types::InventoryS3BucketDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::InventoryS3BucketDestination
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Contains the bucket name, file format, bucket owner (optional), and prefix (optional) where S3 Inventory results are published.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID that owns the destination S3 bucket.
-
#bucket ⇒ String
The Amazon Resource Name (ARN) of the bucket where inventory results will be published.
-
#encryption ⇒ Types::InventoryEncryption
Contains the type of server-side encryption used to encrypt the inventory results.
-
#format ⇒ String
Specifies the output format of the inventory results.
-
#prefix ⇒ String
The prefix that is prepended to all inventory results.
Instance Attribute Details
#account_id ⇒ String
The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.
11535 11536 11537 11538 11539 11540 11541 11542 11543 |
# File 'lib/aws-sdk-s3/types.rb', line 11535 class InventoryS3BucketDestination < Struct.new( :account_id, :bucket, :format, :prefix, :encryption) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The Amazon Resource Name (ARN) of the bucket where inventory results will be published.
11535 11536 11537 11538 11539 11540 11541 11542 11543 |
# File 'lib/aws-sdk-s3/types.rb', line 11535 class InventoryS3BucketDestination < Struct.new( :account_id, :bucket, :format, :prefix, :encryption) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::InventoryEncryption
Contains the type of server-side encryption used to encrypt the inventory results.
11535 11536 11537 11538 11539 11540 11541 11542 11543 |
# File 'lib/aws-sdk-s3/types.rb', line 11535 class InventoryS3BucketDestination < Struct.new( :account_id, :bucket, :format, :prefix, :encryption) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the output format of the inventory results.
11535 11536 11537 11538 11539 11540 11541 11542 11543 |
# File 'lib/aws-sdk-s3/types.rb', line 11535 class InventoryS3BucketDestination < Struct.new( :account_id, :bucket, :format, :prefix, :encryption) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
The prefix that is prepended to all inventory results.
11535 11536 11537 11538 11539 11540 11541 11542 11543 |
# File 'lib/aws-sdk-s3/types.rb', line 11535 class InventoryS3BucketDestination < Struct.new( :account_id, :bucket, :format, :prefix, :encryption) SENSITIVE = [] include Aws::Structure end |