Class: Aws::S3::Types::InventoryS3BucketDestination

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Contains the bucket name, file format, bucket owner (optional), and prefix (optional) where S3 Inventory results are published.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.

Although this value is optional, we strongly recommend that you set it to help prevent problems if the destination bucket ownership changes.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
# File 'lib/aws-sdk-s3/types.rb', line 11521

class InventoryS3BucketDestination < Struct.new(
  :account_id,
  :bucket,
  :format,
  :prefix,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The Amazon Resource Name (ARN) of the bucket where inventory results will be published.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
# File 'lib/aws-sdk-s3/types.rb', line 11521

class InventoryS3BucketDestination < Struct.new(
  :account_id,
  :bucket,
  :format,
  :prefix,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::InventoryEncryption

Contains the type of server-side encryption used to encrypt the inventory results.



11521
11522
11523
11524
11525
11526
11527
11528
11529
# File 'lib/aws-sdk-s3/types.rb', line 11521

class InventoryS3BucketDestination < Struct.new(
  :account_id,
  :bucket,
  :format,
  :prefix,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

Specifies the output format of the inventory results.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
# File 'lib/aws-sdk-s3/types.rb', line 11521

class InventoryS3BucketDestination < Struct.new(
  :account_id,
  :bucket,
  :format,
  :prefix,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

The prefix that is prepended to all inventory results.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
# File 'lib/aws-sdk-s3/types.rb', line 11521

class InventoryS3BucketDestination < Struct.new(
  :account_id,
  :bucket,
  :format,
  :prefix,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end