Class: Aws::S3::Types::LambdaFunctionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Note:

When making an API call, you may pass LambdaFunctionConfiguration data as a hash:

{
  id: "NotificationId",
  lambda_function_arn: "LambdaFunctionArn", # required
  events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated, s3:ObjectRestore:Post, s3:ObjectRestore:Completed
  filter: {
    key: {
      filter_rules: [
        {
          name: "prefix", # accepts prefix, suffix
          value: "FilterRuleValue",
        },
      ],
    },
  },
}

A container for specifying the configuration for AWS Lambda notifications.

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<String>

Returns:

  • (Array<String>)


4385
4386
4387
4388
4389
4390
4391
# File 'lib/aws-sdk-s3/types.rb', line 4385

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  include Aws::Structure
end

#filterTypes::NotificationConfigurationFilter

A container for object key name filtering rules. For information about key name filtering, see Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.



4385
4386
4387
4388
4389
4390
4391
# File 'lib/aws-sdk-s3/types.rb', line 4385

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  include Aws::Structure
end

#idString

An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.

Returns:

  • (String)


4385
4386
4387
4388
4389
4390
4391
# File 'lib/aws-sdk-s3/types.rb', line 4385

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  include Aws::Structure
end

#lambda_function_arnString

The Amazon Resource Name (ARN) of the Lambda cloud function that Amazon S3 can invoke when it detects events of the specified type.

Returns:

  • (String)


4385
4386
4387
4388
4389
4390
4391
# File 'lib/aws-sdk-s3/types.rb', line 4385

class LambdaFunctionConfiguration < Struct.new(
  :id,
  :lambda_function_arn,
  :events,
  :filter)
  include Aws::Structure
end