Class: Aws::S3::Types::LambdaFunctionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::LambdaFunctionConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass LambdaFunctionConfiguration data as a hash:
{
id: "NotificationId",
lambda_function_arn: "LambdaFunctionArn", # required
events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated
filter: {
key: {
filter_rules: [
{
name: "prefix", # accepts prefix, suffix
value: "FilterRuleValue",
},
],
},
},
}Container for specifying the AWS Lambda notification configuration.
Instance Attribute Summary collapse
- #events ⇒ Array<String>
-
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules.
-
#id ⇒ String
Optional unique identifier for configurations in a notification configuration.
-
#lambda_function_arn ⇒ String
Lambda cloud function ARN that Amazon S3 can invoke when it detects events of the specified type.
Instance Attribute Details
#events ⇒ Array<String>
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-s3/types.rb', line 3957 class LambdaFunctionConfiguration < Struct.new( :id, :lambda_function_arn, :events, :filter) include Aws::Structure end |
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules. For information about key name filtering, go to Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-s3/types.rb', line 3957 class LambdaFunctionConfiguration < Struct.new( :id, :lambda_function_arn, :events, :filter) include Aws::Structure end |
#id ⇒ String
Optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-s3/types.rb', line 3957 class LambdaFunctionConfiguration < Struct.new( :id, :lambda_function_arn, :events, :filter) include Aws::Structure end |
#lambda_function_arn ⇒ String
Lambda cloud function ARN that Amazon S3 can invoke when it detects events of the specified type.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-s3/types.rb', line 3957 class LambdaFunctionConfiguration < Struct.new( :id, :lambda_function_arn, :events, :filter) include Aws::Structure end |