Class: Aws::S3::Types::ListBucketIntelligentTieringConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.

Returns:



11162
11163
11164
11165
11166
11167
11168
# File 'lib/aws-sdk-s3/types.rb', line 11162

class ListBucketIntelligentTieringConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#continuation_tokenString

The ContinuationToken that represents a placeholder from where this request should begin.

Returns:



11162
11163
11164
11165
11166
11167
11168
# File 'lib/aws-sdk-s3/types.rb', line 11162

class ListBucketIntelligentTieringConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:



11162
11163
11164
11165
11166
11167
11168
# File 'lib/aws-sdk-s3/types.rb', line 11162

class ListBucketIntelligentTieringConfigurationsRequest < Struct.new(
  :bucket,
  :continuation_token,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end