Class: Aws::S3::Types::ListBucketMetricsConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListBucketMetricsConfigurationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket containing the metrics configurations to retrieve.
-
#continuation_token ⇒ String
The marker that is used to continue a metrics configuration listing that has been truncated.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket containing the metrics configurations to retrieve.
Directory buckets - When you use this operation with a
directory bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name .
Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local
Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide
12543 12544 12545 12546 12547 12548 12549 |
# File 'lib/aws-sdk-s3/types.rb', line 12543 class ListBucketMetricsConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
The marker that is used to continue a metrics configuration listing
that has been truncated. Use the NextContinuationToken from a
previously truncated list response to continue the listing. The
continuation token is an opaque value that Amazon S3 understands.
12543 12544 12545 12546 12547 12548 12549 |
# File 'lib/aws-sdk-s3/types.rb', line 12543 class ListBucketMetricsConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
501 Not Implemented.
12543 12544 12545 12546 12547 12548 12549 |
# File 'lib/aws-sdk-s3/types.rb', line 12543 class ListBucketMetricsConfigurationsRequest < Struct.new( :bucket, :continuation_token, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |