Class: Aws::S3::Types::ListBucketsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketsArray<Types::Bucket>

The list of buckets owned by the requester.

Returns:



11321
11322
11323
11324
11325
11326
11327
11328
# File 'lib/aws-sdk-s3/types.rb', line 11321

class ListBucketsOutput < Struct.new(
  :buckets,
  :owner,
  :continuation_token,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#continuation_tokenString

ContinuationToken is included in the response when there are more buckets that can be listed with pagination. The next ListBuckets request to Amazon S3 can be continued with this ContinuationToken. ContinuationToken is obfuscated and is not a real bucket.

Returns:

  • (String)


11321
11322
11323
11324
11325
11326
11327
11328
# File 'lib/aws-sdk-s3/types.rb', line 11321

class ListBucketsOutput < Struct.new(
  :buckets,
  :owner,
  :continuation_token,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#ownerTypes::Owner

The owner of the buckets listed.

Returns:



11321
11322
11323
11324
11325
11326
11327
11328
# File 'lib/aws-sdk-s3/types.rb', line 11321

class ListBucketsOutput < Struct.new(
  :buckets,
  :owner,
  :continuation_token,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

If Prefix was sent with the request, it is included in the response.

All bucket names in the response begin with the specified bucket name prefix.

Returns:

  • (String)


11321
11322
11323
11324
11325
11326
11327
11328
# File 'lib/aws-sdk-s3/types.rb', line 11321

class ListBucketsOutput < Struct.new(
  :buckets,
  :owner,
  :continuation_token,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end