Class: Aws::S3::Types::ListBucketsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListBucketsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#buckets ⇒ Array<Types::Bucket>
The list of buckets owned by the requester.
-
#continuation_token ⇒ String
ContinuationTokenis included in the response when there are more buckets that can be listed with pagination. -
#owner ⇒ Types::Owner
The owner of the buckets listed.
-
#prefix ⇒ String
If
Prefixwas sent with the request, it is included in the response.
Instance Attribute Details
#buckets ⇒ Array<Types::Bucket>
The list of buckets owned by the requester.
12576 12577 12578 12579 12580 12581 12582 12583 |
# File 'lib/aws-sdk-s3/types.rb', line 12576 class ListBucketsOutput < Struct.new( :buckets, :owner, :continuation_token, :prefix) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
ContinuationToken is included in the response when there are more
buckets that can be listed with pagination. The next ListBuckets
request to Amazon S3 can be continued with this ContinuationToken.
ContinuationToken is obfuscated and is not a real bucket.
12576 12577 12578 12579 12580 12581 12582 12583 |
# File 'lib/aws-sdk-s3/types.rb', line 12576 class ListBucketsOutput < Struct.new( :buckets, :owner, :continuation_token, :prefix) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ Types::Owner
The owner of the buckets listed.
12576 12577 12578 12579 12580 12581 12582 12583 |
# File 'lib/aws-sdk-s3/types.rb', line 12576 class ListBucketsOutput < Struct.new( :buckets, :owner, :continuation_token, :prefix) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
If Prefix was sent with the request, it is included in the
response.
All bucket names in the response begin with the specified bucket name prefix.
12576 12577 12578 12579 12580 12581 12582 12583 |
# File 'lib/aws-sdk-s3/types.rb', line 12576 class ListBucketsOutput < Struct.new( :buckets, :owner, :continuation_token, :prefix) SENSITIVE = [] include Aws::Structure end |