Class: Aws::S3::Types::ListObjectAnnotationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListObjectAnnotationsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_count ⇒ Integer
The number of annotations returned.
-
#annotation_prefix ⇒ String
The prefix used to filter the response.
-
#annotations ⇒ Array<Types::AnnotationEntry>
The list of annotations attached to the object.
-
#bucket ⇒ String
The bucket name.
-
#continuation_token ⇒ String
The continuation token used in this request.
-
#key ⇒ String
The object key.
-
#max_annotation_results ⇒ Integer
The maximum number of annotations returned in the response.
-
#next_continuation_token ⇒ String
The continuation token to use to retrieve the next page of results.
-
#object_version_id ⇒ String
The version ID of the object.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#annotation_count ⇒ Integer
The number of annotations returned.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#annotation_prefix ⇒ String
The prefix used to filter the response.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#annotations ⇒ Array<Types::AnnotationEntry>
The list of annotations attached to the object.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The bucket name.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
The continuation token used in this request.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#max_annotation_results ⇒ Integer
The maximum number of annotations returned in the response.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#next_continuation_token ⇒ String
The continuation token to use to retrieve the next page of results.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#object_version_id ⇒ String
The version ID of the object.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 |
# File 'lib/aws-sdk-s3/types.rb', line 13068 class ListObjectAnnotationsOutput < Struct.new( :annotations, :bucket, :key, :object_version_id, :annotation_prefix, :max_annotation_results, :annotation_count, :continuation_token, :next_continuation_token, :request_charged) SENSITIVE = [] include Aws::Structure end |