Class: Aws::S3::Types::ListObjectAnnotationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListObjectAnnotationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_prefix ⇒ String
Filter results to annotations whose name begins with the specified prefix.
-
#bucket ⇒ String
The name of the bucket that contains the object.
-
#continuation_token ⇒ String
Continuation token returned by a previous request to retrieve the next page.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#key ⇒ String
The object key.
-
#max_annotation_results ⇒ Integer
The maximum number of annotations to return in the response.
-
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request.
-
#version_id ⇒ String
The version ID of the object.
Instance Attribute Details
#annotation_prefix ⇒ String
Filter results to annotations whose name begins with the specified prefix.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket that contains the object.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#continuation_token ⇒ String
Continuation token returned by a previous request to retrieve the next page.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#max_annotation_results ⇒ Integer
The maximum number of annotations to return in the response. Maximum is 1,000.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the object.
13134 13135 13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 |
# File 'lib/aws-sdk-s3/types.rb', line 13134 class ListObjectAnnotationsRequest < Struct.new( :bucket, :key, :version_id, :max_annotation_results, :annotation_prefix, :continuation_token, :request_payer, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |