Class: Aws::S3::Types::ListObjectVersionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListObjectVersionsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb,
lib/aws-sdk-s3/customizations/types/list_object_versions_output.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#common_prefixes ⇒ Array<Types::CommonPrefix>
All of the keys rolled up into a common prefix count as a single return when calculating the number of returns.
-
#delete_markers ⇒ Array<Types::DeleteMarkerEntry>
Container for an object that is a delete marker.
-
#delimiter ⇒ String
The delimiter grouping the included keys.
-
#encoding_type ⇒ String
Encoding type used by Amazon S3 to encode object key names in the XML response.
-
#is_truncated ⇒ Boolean
A flag that indicates whether Amazon S3 returned all of the results that satisfied the search criteria.
-
#key_marker ⇒ String
Marks the last key returned in a truncated response.
-
#max_keys ⇒ Integer
Specifies the maximum number of objects to return.
-
#name ⇒ String
The bucket name.
-
#next_key_marker ⇒ String
When the number of responses exceeds the value of
MaxKeys,NextKeyMarkerspecifies the first key not returned that satisfies the search criteria. -
#next_version_id_marker ⇒ String
When the number of responses exceeds the value of
MaxKeys,NextVersionIdMarkerspecifies the first object version not returned that satisfies the search criteria. -
#prefix ⇒ String
Selects objects that start with the value supplied by this parameter.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#version_id_marker ⇒ String
Marks the last version of the key returned in a truncated response.
-
#versions ⇒ Array<Types::ObjectVersion>
Container for version information.
Instance Method Summary collapse
-
#versions_delete_markers ⇒ Object
private
TODO : Remove this customization once the resource code generator correct handles the JMESPath || expression.
Instance Attribute Details
#common_prefixes ⇒ Array<Types::CommonPrefix>
All of the keys rolled up into a common prefix count as a single return when calculating the number of returns.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#delete_markers ⇒ Array<Types::DeleteMarkerEntry>
Container for an object that is a delete marker. To learn more about delete markers, see Working with delete markers.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
The delimiter grouping the included keys. A delimiter is a character
that you specify to group keys. All keys that contain the same
string between the prefix and the first occurrence of the delimiter
are grouped under a single result element in CommonPrefixes. These
groups are counted as one result against the max-keys limitation.
These keys are not returned elsewhere in the response.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#encoding_type ⇒ String
Encoding type used by Amazon S3 to encode object key names in the XML response.
If you specify the encoding-type request parameter, Amazon S3
includes this element in the response, and returns encoded key name
values in the following response elements:
KeyMarker, NextKeyMarker, Prefix, Key, and Delimiter.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether Amazon S3 returned all of the results
that satisfied the search criteria. If your results were truncated,
you can make a follow-up paginated request by using the
NextKeyMarker and NextVersionIdMarker response parameters as a
starting place in another request to return the rest of the results.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#key_marker ⇒ String
Marks the last key returned in a truncated response.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#max_keys ⇒ Integer
Specifies the maximum number of objects to return.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The bucket name.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#next_key_marker ⇒ String
When the number of responses exceeds the value of MaxKeys,
NextKeyMarker specifies the first key not returned that satisfies
the search criteria. Use this value for the key-marker request
parameter in a subsequent request.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#next_version_id_marker ⇒ String
When the number of responses exceeds the value of MaxKeys,
NextVersionIdMarker specifies the first object version not
returned that satisfies the search criteria. Use this value for the
version-id-marker request parameter in a subsequent request.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
Selects objects that start with the value supplied by this parameter.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#version_id_marker ⇒ String
Marks the last version of the key returned in a truncated response.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
#versions ⇒ Array<Types::ObjectVersion>
Container for version information.
13245 13246 13247 13248 13249 13250 13251 13252 13253 13254 13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-s3/types.rb', line 13245 class ListObjectVersionsOutput < Struct.new( :is_truncated, :key_marker, :version_id_marker, :next_key_marker, :next_version_id_marker, :versions, :delete_markers, :name, :prefix, :delimiter, :max_keys, :common_prefixes, :encoding_type, :request_charged) SENSITIVE = [] include Aws::Structure end |
Instance Method Details
#versions_delete_markers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
TODO : Remove this customization once the resource code generator correct handles the JMESPath || expression. Only used by the Bucket#object_versions collection.
9 10 11 |
# File 'lib/aws-sdk-s3/customizations/types/list_object_versions_output.rb', line 9 def versions_delete_markers versions + delete_markers end |