Class: Aws::S3::Types::ListPartsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ListPartsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:sse_customer_key]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket to which the parts are being uploaded.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#key ⇒ String
Object key for which the multipart upload was initiated.
-
#max_parts ⇒ Integer
Sets the maximum number of parts to return.
-
#part_number_marker ⇒ Integer
Specifies the part after which listing should begin.
-
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request.
-
#sse_customer_algorithm ⇒ String
The server-side encryption (SSE) algorithm used to encrypt the object.
-
#sse_customer_key ⇒ String
The server-side encryption (SSE) customer managed key.
-
#sse_customer_key_md5 ⇒ String
The MD5 server-side encryption (SSE) customer managed key.
-
#upload_id ⇒ String
Upload ID identifying the multipart upload whose parts are being listed.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket to which the parts are being uploaded.
Directory buckets - When you use this operation with a directory
bucket, you must use virtual-hosted-style requests in the format Bucket-name.s3express-zone-id.region-code.amazonaws.com. Path-style
requests are not supported. Directory bucket names must be unique in
the chosen Zone (Availability Zone or Local Zone). Bucket names must
follow the format bucket-base-name--zone-id--x-s3 (for example, amzn-s3-demo-bucket--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide.
Access points - When you use this action with an access point for general purpose buckets, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When you use this action with an access point for directory buckets, you must provide the access point name in place of the bucket name. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts,
you must direct requests to the S3 on Outposts hostname. The S3 on
Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com.
When you use this action with S3 on Outposts, the destination bucket
must be the Outposts access point ARN or the access point alias. For
more information about S3 on Outposts, see What is S3 on
Outposts? in the Amazon S3 User Guide.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#key ⇒ String
Object key for which the multipart upload was initiated.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#max_parts ⇒ Integer
Sets the maximum number of parts to return.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#part_number_marker ⇒ Integer
Specifies the part after which listing should begin. Only parts with higher part numbers will be listed.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#request_payer ⇒ String
Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see Downloading Objects in Requester Pays Buckets in the Amazon S3 User Guide.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#sse_customer_algorithm ⇒ String
The server-side encryption (SSE) algorithm used to encrypt the object. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#sse_customer_key ⇒ String
The server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#sse_customer_key_md5 ⇒ String
The MD5 server-side encryption (SSE) customer managed key. This parameter is needed only when the object was created using a checksum algorithm. For more information, see Protecting data using SSE-C keys in the Amazon S3 User Guide.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |
#upload_id ⇒ String
Upload ID identifying the multipart upload whose parts are being listed.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/aws-sdk-s3/types.rb', line 14257 class ListPartsRequest < Struct.new( :bucket, :key, :max_parts, :part_number_marker, :upload_id, :request_payer, :expected_bucket_owner, :sse_customer_algorithm, :sse_customer_key, :sse_customer_key_md5) SENSITIVE = [:sse_customer_key] include Aws::Structure end |