Class: Aws::S3::Types::ObjectEncryption

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Note:

ObjectEncryption is a union - when making an API calls you must set exactly one of the members.

The updated server-side encryption type for this object. The ‘UpdateObjectEncryption` operation supports the SSE-S3 and SSE-KMS encryption types.

Valid Values: ‘SSES3` | `SSEKMS`

Direct Known Subclasses

Ssekms, Unknown

Defined Under Namespace

Classes: Ssekms, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ssekmsTypes::SSEKMSEncryption

Specifies to update the object encryption type to server-side encryption with Key Management Service (KMS) keys (SSE-KMS).



14270
14271
14272
14273
14274
14275
14276
14277
14278
14279
# File 'lib/aws-sdk-s3/types.rb', line 14270

class ObjectEncryption < Struct.new(
  :ssekms,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Ssekms < ObjectEncryption; end
  class Unknown < ObjectEncryption; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



14270
14271
14272
# File 'lib/aws-sdk-s3/types.rb', line 14270

def unknown
  @unknown
end