Class: Aws::S3::Types::ObjectEncryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ObjectEncryption
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Note:
ObjectEncryption is a union - when making an API calls you must set exactly one of the members.
The updated server-side encryption type for this object. The UpdateObjectEncryption operation supports the SSE-S3 and SSE-KMS encryption types.
Valid Values: SSES3 \| SSEKMS
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ssekms ⇒ Types::SSEKMSEncryption
Specifies to update the object encryption type to server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ssekms ⇒ Types::SSEKMSEncryption
Specifies to update the object encryption type to server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
13649 13650 13651 13652 13653 13654 13655 13656 13657 13658 |
# File 'lib/aws-sdk-s3/types.rb', line 13649 class ObjectEncryption < Struct.new( :ssekms, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Ssekms < ObjectEncryption; end class Unknown < ObjectEncryption; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
13649 13650 13651 |
# File 'lib/aws-sdk-s3/types.rb', line 13649 def unknown @unknown end |