Class: Aws::S3::Types::ObjectVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ObjectVersion
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
The version of an object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum_algorithm ⇒ Array<String>
The algorithm that was used to create a checksum of the object.
-
#checksum_type ⇒ String
The checksum type that is used to calculate the object’s checksum value.
-
#etag ⇒ String
The entity tag is an MD5 hash of that version of the object.
-
#is_latest ⇒ Boolean
Specifies whether the object is (true) or is not (false) the latest version of an object.
-
#key ⇒ String
The object key.
-
#last_modified ⇒ Time
Date and time when the object was last modified.
-
#owner ⇒ Types::Owner
Specifies the owner of the object.
-
#restore_status ⇒ Types::RestoreStatus
Specifies the restoration status of an object.
-
#size ⇒ Integer
Size in bytes of the object.
-
#storage_class ⇒ String
The class of storage used to store the object.
-
#version_id ⇒ String
Version ID of an object.
Instance Attribute Details
#checksum_algorithm ⇒ Array<String>
The algorithm that was used to create a checksum of the object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#checksum_type ⇒ String
The checksum type that is used to calculate the object’s checksum value. For more information, see Checking object integrity in the Amazon S3 User Guide.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The entity tag is an MD5 hash of that version of the object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#is_latest ⇒ Boolean
Specifies whether the object is (true) or is not (false) the latest version of an object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
Date and time when the object was last modified.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ Types::Owner
Specifies the owner of the object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#restore_status ⇒ Types::RestoreStatus
Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see Working with archived objects in the Amazon S3 User Guide.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
Size in bytes of the object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
The class of storage used to store the object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Version ID of an object.
15280 15281 15282 15283 15284 15285 15286 15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15280 class ObjectVersion < Struct.new( :etag, :checksum_algorithm, :checksum_type, :size, :storage_class, :key, :version_id, :is_latest, :last_modified, :owner, :restore_status) SENSITIVE = [] include Aws::Structure end |