Class: Aws::S3::Types::ObjectVersion

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

The version of an object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksum_algorithmArray<String>

The algorithm that was used to create a checksum of the object.

Returns:

  • (Array<String>)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_typeString

The checksum type that is used to calculate the object’s checksum value. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The entity tag is an MD5 hash of that version of the object.

Returns:

  • (String)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#is_latestBoolean

Specifies whether the object is (true) or is not (false) the latest version of an object.

Returns:

  • (Boolean)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

Date and time when the object was last modified.

Returns:

  • (Time)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#ownerTypes::Owner

Specifies the owner of the object.

Returns:



15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#restore_statusTypes::RestoreStatus

Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see [ Working with archived objects] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/archived-objects.html



15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

Size in bytes of the object.

Returns:

  • (Integer)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The class of storage used to store the object.

Returns:

  • (String)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

Version ID of an object.

Returns:

  • (String)


15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
15276
15277
15278
15279
15280
# File 'lib/aws-sdk-s3/types.rb', line 15266

class ObjectVersion < Struct.new(
  :etag,
  :checksum_algorithm,
  :checksum_type,
  :size,
  :storage_class,
  :key,
  :version_id,
  :is_latest,
  :last_modified,
  :owner,
  :restore_status)
  SENSITIVE = []
  include Aws::Structure
end