Class: Aws::S3::Types::PutBucketAbacRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abac_statusTypes::AbacStatus

The ABAC status of the general purpose bucket. When ABAC is enabled for the general purpose bucket, you can use tags to manage access to the general purpose buckets as well as for cost tracking purposes. When ABAC is disabled for the general purpose buckets, you can only use tags for cost tracking purposes. For more information, see [Using tags with S3 general purpose buckets].

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/buckets-tagging.html

Returns:



15751
15752
15753
15754
15755
15756
15757
15758
15759
# File 'lib/aws-sdk-s3/types.rb', line 15751

class PutBucketAbacRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :expected_bucket_owner,
  :abac_status)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the general purpose bucket.

Returns:

  • (String)


15751
15752
15753
15754
15755
15756
15757
15758
15759
# File 'lib/aws-sdk-s3/types.rb', line 15751

class PutBucketAbacRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :expected_bucket_owner,
  :abac_status)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html

Returns:

  • (String)


15751
15752
15753
15754
15755
15756
15757
15758
15759
# File 'lib/aws-sdk-s3/types.rb', line 15751

class PutBucketAbacRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :expected_bucket_owner,
  :abac_status)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

The MD5 hash of the ‘PutBucketAbac` request body.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

Returns:

  • (String)


15751
15752
15753
15754
15755
15756
15757
15758
15759
# File 'lib/aws-sdk-s3/types.rb', line 15751

class PutBucketAbacRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :expected_bucket_owner,
  :abac_status)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID of the general purpose bucket’s owner.

Returns:

  • (String)


15751
15752
15753
15754
15755
15756
15757
15758
15759
# File 'lib/aws-sdk-s3/types.rb', line 15751

class PutBucketAbacRequest < Struct.new(
  :bucket,
  :content_md5,
  :checksum_algorithm,
  :expected_bucket_owner,
  :abac_status)
  SENSITIVE = []
  include Aws::Structure
end