Class: Aws::S3::Types::PutBucketAnalyticsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configurationTypes::AnalyticsConfiguration

The configuration and any analyses for the analytics filter.



15935
15936
15937
15938
15939
15940
15941
15942
# File 'lib/aws-sdk-s3/types.rb', line 15935

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket to which an analytics configuration is stored.

Returns:

  • (String)


15935
15936
15937
15938
15939
15940
15941
15942
# File 'lib/aws-sdk-s3/types.rb', line 15935

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


15935
15936
15937
15938
15939
15940
15941
15942
# File 'lib/aws-sdk-s3/types.rb', line 15935

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID that identifies the analytics configuration.

Returns:

  • (String)


15935
15936
15937
15938
15939
15940
15941
15942
# File 'lib/aws-sdk-s3/types.rb', line 15935

class PutBucketAnalyticsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :analytics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end