Class: Aws::S3::Types::PutBucketAnalyticsConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketAnalyticsConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The configuration and any analyses for the analytics filter.
-
#bucket ⇒ String
The name of the bucket to which an analytics configuration is stored.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID that identifies the analytics configuration.
Instance Attribute Details
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The configuration and any analyses for the analytics filter.
15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15287 class PutBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :analytics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket to which an analytics configuration is stored.
15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15287 class PutBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :analytics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15287 class PutBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :analytics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID that identifies the analytics configuration.
15287 15288 15289 15290 15291 15292 15293 15294 |
# File 'lib/aws-sdk-s3/types.rb', line 15287 class PutBucketAnalyticsConfigurationRequest < Struct.new( :bucket, :id, :analytics_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |