Class: Aws::S3::Types::PutBucketIntelligentTieringConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.

Returns:

  • (String)


16116
16117
16118
16119
16120
16121
16122
16123
# File 'lib/aws-sdk-s3/types.rb', line 16116

class PutBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner,
  :intelligent_tiering_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

Returns:

  • (String)


16116
16117
16118
16119
16120
16121
16122
16123
# File 'lib/aws-sdk-s3/types.rb', line 16116

class PutBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner,
  :intelligent_tiering_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the S3 Intelligent-Tiering configuration.

Returns:

  • (String)


16116
16117
16118
16119
16120
16121
16122
16123
# File 'lib/aws-sdk-s3/types.rb', line 16116

class PutBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner,
  :intelligent_tiering_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#intelligent_tiering_configurationTypes::IntelligentTieringConfiguration

Container for S3 Intelligent-Tiering configuration.



16116
16117
16118
16119
16120
16121
16122
16123
# File 'lib/aws-sdk-s3/types.rb', line 16116

class PutBucketIntelligentTieringConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :expected_bucket_owner,
  :intelligent_tiering_configuration)
  SENSITIVE = []
  include Aws::Structure
end