Class: Aws::S3::Types::PutBucketIntelligentTieringConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketIntelligentTieringConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
-
#intelligent_tiering_configuration ⇒ Types::IntelligentTieringConfiguration
Container for S3 Intelligent-Tiering configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
16102 16103 16104 16105 16106 16107 16108 16109 |
# File 'lib/aws-sdk-s3/types.rb', line 16102 class PutBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner, :intelligent_tiering_configuration) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).
16102 16103 16104 16105 16106 16107 16108 16109 |
# File 'lib/aws-sdk-s3/types.rb', line 16102 class PutBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner, :intelligent_tiering_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the S3 Intelligent-Tiering configuration.
16102 16103 16104 16105 16106 16107 16108 16109 |
# File 'lib/aws-sdk-s3/types.rb', line 16102 class PutBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner, :intelligent_tiering_configuration) SENSITIVE = [] include Aws::Structure end |
#intelligent_tiering_configuration ⇒ Types::IntelligentTieringConfiguration
Container for S3 Intelligent-Tiering configuration.
16102 16103 16104 16105 16106 16107 16108 16109 |
# File 'lib/aws-sdk-s3/types.rb', line 16102 class PutBucketIntelligentTieringConfigurationRequest < Struct.new( :bucket, :id, :expected_bucket_owner, :intelligent_tiering_configuration) SENSITIVE = [] include Aws::Structure end |