Class: Aws::S3::Types::PutBucketInventoryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutBucketInventoryConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the bucket where the inventory configuration will be stored.
-
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner.
-
#id ⇒ String
The ID used to identify the inventory configuration.
-
#inventory_configuration ⇒ Types::InventoryConfiguration
Specifies the inventory configuration.
Instance Attribute Details
#bucket ⇒ String
The name of the bucket where the inventory configuration will be stored.
Directory buckets - When you use this operation with a
directory bucket, you must use path-style requests in the format
https://s3express-control.region-code.amazonaws.com/bucket-name .
Virtual-hosted-style requests aren't supported. Directory bucket
names must be unique in the chosen Zone (Availability Zone or Local
Zone). Bucket names must also follow the format bucket-base-name--zone-id--x-s3 (for example, DOC-EXAMPLE-BUCKET--usw2-az1--x-s3). For information about bucket
naming restrictions, see Directory bucket naming rules in the
Amazon S3 User Guide
16168 16169 16170 16171 16172 16173 16174 16175 |
# File 'lib/aws-sdk-s3/types.rb', line 16168 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The account ID of the expected bucket owner. If the account ID that
you provide does not match the actual owner of the bucket, the
request fails with the HTTP status code 403 Forbidden (access
denied).
501 Not Implemented.
16168 16169 16170 16171 16172 16173 16174 16175 |
# File 'lib/aws-sdk-s3/types.rb', line 16168 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID used to identify the inventory configuration.
16168 16169 16170 16171 16172 16173 16174 16175 |
# File 'lib/aws-sdk-s3/types.rb', line 16168 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#inventory_configuration ⇒ Types::InventoryConfiguration
Specifies the inventory configuration.
16168 16169 16170 16171 16172 16173 16174 16175 |
# File 'lib/aws-sdk-s3/types.rb', line 16168 class PutBucketInventoryConfigurationRequest < Struct.new( :bucket, :id, :inventory_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |