Class: Aws::S3::Types::PutBucketMetricsConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket for which the metrics configuration is set.

Directory buckets - When you use this operation with a directory bucket, you must use path-style requests in the format ‘s3express-control.region-code.amazonaws.com/bucket-name `. Virtual-hosted-style requests aren’t supported. Directory bucket names must be unique in the chosen Zone (Availability Zone or Local Zone). Bucket names must also follow the format ‘ bucket-base-name–zone-id–x-s3` (for example, ` DOC-EXAMPLE-BUCKET–usw2-az1–x-s3`). For information about bucket naming restrictions, see [Directory bucket naming rules] in the *Amazon S3 User Guide*

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-bucket-naming-rules.html

Returns:

  • (String)


15776
15777
15778
15779
15780
15781
15782
15783
# File 'lib/aws-sdk-s3/types.rb', line 15776

class PutBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :metrics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

<note markdown=“1”> For directory buckets, this header is not supported in this API operation. If you specify this header, the request fails with the HTTP status code ‘501 Not Implemented`.

</note>

Returns:

  • (String)


15776
15777
15778
15779
15780
15781
15782
15783
# File 'lib/aws-sdk-s3/types.rb', line 15776

class PutBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :metrics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID used to identify the metrics configuration. The ID has a 64 character limit and can only contain letters, numbers, periods, dashes, and underscores.

Returns:

  • (String)


15776
15777
15778
15779
15780
15781
15782
15783
# File 'lib/aws-sdk-s3/types.rb', line 15776

class PutBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :metrics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_configurationTypes::MetricsConfiguration

Specifies the metrics configuration.



15776
15777
15778
15779
15780
15781
15782
15783
# File 'lib/aws-sdk-s3/types.rb', line 15776

class PutBucketMetricsConfigurationRequest < Struct.new(
  :bucket,
  :id,
  :metrics_configuration,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end