Class: Aws::S3::Types::PutBucketNotificationConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the bucket.

Returns:

  • (String)


16443
16444
16445
16446
16447
16448
16449
16450
# File 'lib/aws-sdk-s3/types.rb', line 16443

class PutBucketNotificationConfigurationRequest < Struct.new(
  :bucket,
  :notification_configuration,
  :expected_bucket_owner,
  :skip_destination_validation)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code ‘403 Forbidden` (access denied).

Returns:

  • (String)


16443
16444
16445
16446
16447
16448
16449
16450
# File 'lib/aws-sdk-s3/types.rb', line 16443

class PutBucketNotificationConfigurationRequest < Struct.new(
  :bucket,
  :notification_configuration,
  :expected_bucket_owner,
  :skip_destination_validation)
  SENSITIVE = []
  include Aws::Structure
end

#notification_configurationTypes::NotificationConfiguration

A container for specifying the notification configuration of the bucket. If this element is empty, notifications are turned off for the bucket.



16443
16444
16445
16446
16447
16448
16449
16450
# File 'lib/aws-sdk-s3/types.rb', line 16443

class PutBucketNotificationConfigurationRequest < Struct.new(
  :bucket,
  :notification_configuration,
  :expected_bucket_owner,
  :skip_destination_validation)
  SENSITIVE = []
  include Aws::Structure
end

#skip_destination_validationBoolean

Skips validation of Amazon SQS, Amazon SNS, and Lambda destinations. True or false value.

Returns:

  • (Boolean)


16443
16444
16445
16446
16447
16448
16449
16450
# File 'lib/aws-sdk-s3/types.rb', line 16443

class PutBucketNotificationConfigurationRequest < Struct.new(
  :bucket,
  :notification_configuration,
  :expected_bucket_owner,
  :skip_destination_validation)
  SENSITIVE = []
  include Aws::Structure
end