Class: Aws::S3::Types::PutObjectAclOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


17030
17031
17032
17033
17034
# File 'lib/aws-sdk-s3/types.rb', line 17030

class PutObjectAclOutput < Struct.new(
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end