Class: Aws::S3::Types::PutObjectAnnotationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutObjectAnnotationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_name ⇒ String
The name of the annotation.
-
#checksum_crc32 ⇒ String
The CRC32 checksum of the stored annotation.
-
#checksum_crc32c ⇒ String
The CRC32C checksum of the stored annotation.
-
#checksum_crc64nvme ⇒ String
The CRC64NVME checksum of the stored annotation.
-
#checksum_md5 ⇒ String
The MD5 checksum of the stored annotation.
-
#checksum_sha1 ⇒ String
The SHA1 checksum of the stored annotation.
-
#checksum_sha256 ⇒ String
The SHA256 checksum of the stored annotation.
-
#checksum_sha512 ⇒ String
The SHA512 checksum of the stored annotation.
-
#checksum_type ⇒ String
The type of checksum used.
-
#checksum_xxhash128 ⇒ String
The XXHASH128 checksum of the stored annotation.
-
#checksum_xxhash3 ⇒ String
The XXHASH3 checksum of the stored annotation.
-
#checksum_xxhash64 ⇒ String
The XXHASH64 checksum of the stored annotation.
-
#etag ⇒ String
The entity tag of the annotation.
-
#key ⇒ String
The object key.
-
#object_version_id ⇒ String
The version ID of the object that the annotation was attached to.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#server_side_encryption ⇒ String
The server-side encryption algorithm used to encrypt the annotation.
Instance Attribute Details
#annotation_name ⇒ String
The name of the annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32 ⇒ String
The CRC32 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_crc32c ⇒ String
The CRC32C checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The CRC64NVME checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_md5 ⇒ String
The MD5 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_sha1 ⇒ String
The SHA1 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_sha256 ⇒ String
The SHA256 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_sha512 ⇒ String
The SHA512 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_type ⇒ String
The type of checksum used.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The XXHASH128 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The XXHASH3 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The XXHASH64 checksum of the stored annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The entity tag of the annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#object_version_id ⇒ String
The version ID of the object that the annotation was attached to.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |
#server_side_encryption ⇒ String
The server-side encryption algorithm used to encrypt the annotation.
17286 17287 17288 17289 17290 17291 17292 17293 17294 17295 17296 17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-s3/types.rb', line 17286 class PutObjectAnnotationOutput < Struct.new( :key, :annotation_name, :object_version_id, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :checksum_type, :server_side_encryption, :request_charged) SENSITIVE = [] include Aws::Structure end |