Class: Aws::S3::Types::PutObjectAnnotationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_nameString

The name of the annotation.

Length Constraints: Minimum length of 1. Maximum length of 512 bytes.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#annotation_payloadIO

The annotation payload. Must be between 1 byte and 1 MiB in size, and must be valid UTF-8 encoded text. If the payload contains invalid UTF-8 bytes, the request fails with HTTP 415 (Unsupported Media Type). To store binary data, encode the payload using Base64 before uploading.

Returns:

  • (IO)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket that contains the object.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithmString

The checksum algorithm to use. Supported values: ‘CRC32`, `CRC32C`, `CRC64NVME`, `SHA1`, `SHA256`, `SHA512`, `MD5`, `XXHASH64`, `XXHASH3`, `XXHASH128`.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32String

Base64-encoded CRC32 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc32cString

Base64-encoded CRC32C checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_crc64nvmeString

Base64-encoded CRC64NVME checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_md5String

Base64-encoded MD5 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha1String

Base64-encoded SHA1 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha256String

Base64-encoded SHA256 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_sha512String

Base64-encoded SHA512 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash128String

Base64-encoded XXHASH128 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash3String

Base64-encoded XXHASH3 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_xxhash64String

Base64-encoded XXHASH64 checksum of the annotation payload.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#content_md5String

Base64-encoded MD5 digest of the message.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with an HTTP 403 (Access Denied) error.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#object_if_matchString

If specified, the operation only succeeds if the object’s ETag matches the provided value.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#request_payerString

Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. If either the source or destination S3 bucket has Requester Pays enabled, the requester will pay for the corresponding charges. For information about downloading objects from Requester Pays buckets, see [Downloading Objects in Requester Pays Buckets] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported for directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the object to attach the annotation to.

Returns:

  • (String)


17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
17412
17413
17414
17415
17416
17417
17418
17419
17420
17421
17422
17423
17424
17425
# File 'lib/aws-sdk-s3/types.rb', line 17402

class PutObjectAnnotationRequest < Struct.new(
  :bucket,
  :key,
  :version_id,
  :annotation_name,
  :annotation_payload,
  :object_if_match,
  :checksum_algorithm,
  :checksum_crc32,
  :checksum_crc32c,
  :checksum_crc64nvme,
  :checksum_sha1,
  :checksum_sha256,
  :checksum_sha512,
  :checksum_md5,
  :checksum_xxhash64,
  :checksum_xxhash3,
  :checksum_xxhash128,
  :content_md5,
  :request_payer,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end