Class: Aws::S3::Types::PutObjectLegalHoldOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutObjectLegalHoldOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
Instance Attribute Details
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.
17444 17445 17446 17447 17448 |
# File 'lib/aws-sdk-s3/types.rb', line 17444 class PutObjectLegalHoldOutput < Struct.new( :request_charged) SENSITIVE = [] include Aws::Structure end |