Class: Aws::S3::Types::PutObjectLockConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


17582
17583
17584
17585
17586
# File 'lib/aws-sdk-s3/types.rb', line 17582

class PutObjectLockConfigurationOutput < Struct.new(
  :request_charged)
  SENSITIVE = []
  include Aws::Structure
end