Class: Aws::S3::Types::PutPublicAccessBlockRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::PutPublicAccessBlockRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass PutPublicAccessBlockRequest data as a hash:
{
bucket: "BucketName", # required
content_md5: "ContentMD5",
public_access_block_configuration: { # required
block_public_acls: false,
ignore_public_acls: false,
block_public_policy: false,
restrict_public_buckets: false,
},
}
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket whose
PublicAccessBlockconfiguration you want to set. -
#content_md5 ⇒ String
The MD5 hash of the
PutPublicAccessBlockrequest body. -
#public_access_block_configuration ⇒ Types::PublicAccessBlockConfiguration
The
PublicAccessBlockconfiguration that you want to apply to this Amazon S3 bucket.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket whose PublicAccessBlock
configuration you want to set.
8042 8043 8044 8045 8046 8047 |
# File 'lib/aws-sdk-s3/types.rb', line 8042 class PutPublicAccessBlockRequest < Struct.new( :bucket, :content_md5, :public_access_block_configuration) include Aws::Structure end |
#content_md5 ⇒ String
The MD5 hash of the PutPublicAccessBlock request body.
8042 8043 8044 8045 8046 8047 |
# File 'lib/aws-sdk-s3/types.rb', line 8042 class PutPublicAccessBlockRequest < Struct.new( :bucket, :content_md5, :public_access_block_configuration) include Aws::Structure end |
#public_access_block_configuration ⇒ Types::PublicAccessBlockConfiguration
The PublicAccessBlock configuration that you want to apply to this
Amazon S3 bucket. You can enable the configuration options in any
combination. For more information about when Amazon S3 considers a
bucket or object public, see The Meaning of "Public" in the
Amazon Simple Storage Service Developer Guide.
8042 8043 8044 8045 8046 8047 |
# File 'lib/aws-sdk-s3/types.rb', line 8042 class PutPublicAccessBlockRequest < Struct.new( :bucket, :content_md5, :public_access_block_configuration) include Aws::Structure end |