Class: Aws::S3::Types::QueueConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::QueueConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass QueueConfiguration data as a hash:
{
id: "NotificationId",
queue_arn: "QueueArn", # required
events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated, s3:ObjectRestore:Post, s3:ObjectRestore:Completed
filter: {
key: {
filter_rules: [
{
name: "prefix", # accepts prefix, suffix
value: "FilterRuleValue",
},
],
},
},
}A container for specifying the configuration for publication of messages to an Amazon Simple Queue Service (Amazon SQS) queue.when Amazon S3 detects specified events.
Instance Attribute Summary collapse
- #events ⇒ Array<String>
-
#filter ⇒ Types::NotificationConfigurationFilter
A container for object key name filtering rules.
-
#id ⇒ String
An optional unique identifier for configurations in a notification configuration.
-
#queue_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 will publish a message when it detects events of the specified type.
Instance Attribute Details
#events ⇒ Array<String>
8099 8100 8101 8102 8103 8104 8105 |
# File 'lib/aws-sdk-s3/types.rb', line 8099 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#filter ⇒ Types::NotificationConfigurationFilter
A container for object key name filtering rules. For information about key name filtering, see Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.
8099 8100 8101 8102 8103 8104 8105 |
# File 'lib/aws-sdk-s3/types.rb', line 8099 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#id ⇒ String
An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
8099 8100 8101 8102 8103 8104 8105 |
# File 'lib/aws-sdk-s3/types.rb', line 8099 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#queue_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 will publish a message when it detects events of the specified type.
8099 8100 8101 8102 8103 8104 8105 |
# File 'lib/aws-sdk-s3/types.rb', line 8099 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |