Class: Aws::S3::Types::QueueConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::QueueConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass QueueConfiguration data as a hash:
{
id: "NotificationId",
queue_arn: "QueueArn", # required
events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated
filter: {
key: {
filter_rules: [
{
name: "prefix", # accepts prefix, suffix
value: "FilterRuleValue",
},
],
},
},
}Container for specifying an configuration when you want Amazon S3 to publish events to an Amazon Simple Queue Service (Amazon SQS) queue.
Instance Attribute Summary collapse
- #events ⇒ Array<String>
-
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules.
-
#id ⇒ String
Optional unique identifier for configurations in a notification configuration.
-
#queue_arn ⇒ String
Amazon SQS queue ARN to which Amazon S3 will publish a message when it detects events of specified type.
Instance Attribute Details
#events ⇒ Array<String>
7163 7164 7165 7166 7167 7168 7169 |
# File 'lib/aws-sdk-s3/types.rb', line 7163 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules. For information about key name filtering, go to Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.
7163 7164 7165 7166 7167 7168 7169 |
# File 'lib/aws-sdk-s3/types.rb', line 7163 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#id ⇒ String
Optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
7163 7164 7165 7166 7167 7168 7169 |
# File 'lib/aws-sdk-s3/types.rb', line 7163 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |
#queue_arn ⇒ String
Amazon SQS queue ARN to which Amazon S3 will publish a message when it detects events of specified type.
7163 7164 7165 7166 7167 7168 7169 |
# File 'lib/aws-sdk-s3/types.rb', line 7163 class QueueConfiguration < Struct.new( :id, :queue_arn, :events, :filter) include Aws::Structure end |