Class: Aws::S3::Types::ReplicationRuleAndOperator

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.

For example:

  • If you specify both a ‘Prefix` and a `Tag` filter, wrap these filters in an `And` tag.

  • If you specify a filter based on multiple tags, wrap the ‘Tag` elements in an `And` tag.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#prefixString

An object key name prefix that identifies the subset of objects to which the rule applies.

Returns:

  • (String)


19614
19615
19616
19617
19618
19619
# File 'lib/aws-sdk-s3/types.rb', line 19614

class ReplicationRuleAndOperator < Struct.new(
  :prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of tags containing key and value pairs.

Returns:



19614
19615
19616
19617
19618
19619
# File 'lib/aws-sdk-s3/types.rb', line 19614

class ReplicationRuleAndOperator < Struct.new(
  :prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end