Class: Aws::S3::Types::ReplicationRuleAndOperator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ReplicationRuleAndOperator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.
For example:
-
If you specify both a ‘Prefix` and a `Tag` filter, wrap these filters in an `And` tag.
-
If you specify a filter based on multiple tags, wrap the ‘Tag` elements in an `And` tag.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
-
#tags ⇒ Array<Types::Tag>
An array of tags containing key and value pairs.
Instance Attribute Details
#prefix ⇒ String
An object key name prefix that identifies the subset of objects to which the rule applies.
18744 18745 18746 18747 18748 18749 |
# File 'lib/aws-sdk-s3/types.rb', line 18744 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags containing key and value pairs.
18744 18745 18746 18747 18748 18749 |
# File 'lib/aws-sdk-s3/types.rb', line 18744 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |