Class: Aws::S3::Types::ReplicationTime
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::ReplicationTime
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
A container specifying S3 Replication Time Control (S3 RTC) related information, including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a ‘Metrics` block.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
Specifies whether the replication time is enabled.
-
#time ⇒ Types::ReplicationTimeValue
A container specifying the time by which replication should be complete for all objects and operations on objects.
Instance Attribute Details
#status ⇒ String
Specifies whether the replication time is enabled.
18812 18813 18814 18815 18816 18817 |
# File 'lib/aws-sdk-s3/types.rb', line 18812 class ReplicationTime < Struct.new( :status, :time) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Types::ReplicationTimeValue
A container specifying the time by which replication should be complete for all objects and operations on objects.
18812 18813 18814 18815 18816 18817 |
# File 'lib/aws-sdk-s3/types.rb', line 18812 class ReplicationTime < Struct.new( :status, :time) SENSITIVE = [] include Aws::Structure end |