Class: Aws::S3::Types::RestoreObjectOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_chargedString

If present, indicates that the requester was successfully charged for the request. For more information, see Using Requester Pays buckets for storage transfers and usage in the Amazon Simple Storage Service user guide.

This functionality is not supported for directory buckets.

Returns:

  • (String)


19758
19759
19760
19761
19762
19763
# File 'lib/aws-sdk-s3/types.rb', line 19758

class RestoreObjectOutput < Struct.new(
  :request_charged,
  :restore_output_path)
  SENSITIVE = []
  include Aws::Structure
end

#restore_output_pathString

Indicates the path in the provided S3 output location where Select results will be restored to.

Returns:

  • (String)


19758
19759
19760
19761
19762
19763
# File 'lib/aws-sdk-s3/types.rb', line 19758

class RestoreObjectOutput < Struct.new(
  :request_charged,
  :restore_output_path)
  SENSITIVE = []
  include Aws::Structure
end