Class: Aws::S3::Types::RestoreRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Container for restore job parameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#daysInteger

Lifetime of the active copy in days. Do not use with restores that specify OutputLocation.

The Days element is required for regular restores, and must not be provided for select requests.

Returns:

  • (Integer)


19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The optional description for the job.

Returns:

  • (String)


19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#glacier_job_parametersTypes::GlacierJobParameters

S3 Glacier related parameters pertaining to this job. Do not use with restores that specify OutputLocation.



19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#output_locationTypes::OutputLocation

Describes the location where the restore job's output is stored.



19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#select_parametersTypes::SelectParameters

Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more

Describes the parameters for Select job types.



19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

Retrieval tier at which the restore will be processed.

Returns:

  • (String)


19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more

Type of restore request.

Returns:

  • (String)


19918
19919
19920
19921
19922
19923
19924
19925
19926
19927
19928
# File 'lib/aws-sdk-s3/types.rb', line 19918

class RestoreRequest < Struct.new(
  :days,
  :glacier_job_parameters,
  :type,
  :tier,
  :description,
  :select_parameters,
  :output_location)
  SENSITIVE = []
  include Aws::Structure
end