Class: Aws::S3::Types::RestoreRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::RestoreRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Container for restore job parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#days ⇒ Integer
Lifetime of the active copy in days.
-
#description ⇒ String
The optional description for the job.
-
#glacier_job_parameters ⇒ Types::GlacierJobParameters
S3 Glacier related parameters pertaining to this job.
-
#output_location ⇒ Types::OutputLocation
Describes the location where the restore job’s output is stored.
-
#select_parameters ⇒ Types::SelectParameters
Amazon S3 Select is no longer available to new customers.
-
#tier ⇒ String
Retrieval tier at which the restore will be processed.
-
#type ⇒ String
Amazon S3 Select is no longer available to new customers.
Instance Attribute Details
#days ⇒ Integer
Lifetime of the active copy in days. Do not use with restores that specify OutputLocation.
The Days element is required for regular restores, and must not be provided for select requests.
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The optional description for the job.
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#glacier_job_parameters ⇒ Types::GlacierJobParameters
S3 Glacier related parameters pertaining to this job. Do not use with restores that specify OutputLocation.
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#output_location ⇒ Types::OutputLocation
Describes the location where the restore job’s output is stored.
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#select_parameters ⇒ Types::SelectParameters
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. [Learn more][1]
Describes the parameters for Select job types.
[1]: aws.amazon.com/blogs/storage/how-to-optimize-querying-your-data-in-amazon-s3/
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
Retrieval tier at which the restore will be processed.
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. [Learn more][1]
Type of restore request.
[1]: aws.amazon.com/blogs/storage/how-to-optimize-querying-your-data-in-amazon-s3/
18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/aws-sdk-s3/types.rb', line 18120 class RestoreRequest < Struct.new( :days, :glacier_job_parameters, :type, :tier, :description, :select_parameters, :output_location) SENSITIVE = [] include Aws::Structure end |