Class: Aws::S3::Types::SelectParameters

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more

Describes the parameters for Select job types.

Learn How to optimize querying your data in Amazon S3 using Amazon Athena, S3 Object Lambda, or client-side filtering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expressionString

Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more

The expression that is used to query the object.

Returns:

  • (String)


20567
20568
20569
20570
20571
20572
20573
20574
# File 'lib/aws-sdk-s3/types.rb', line 20567

class SelectParameters < Struct.new(
  :input_serialization,
  :expression_type,
  :expression,
  :output_serialization)
  SENSITIVE = []
  include Aws::Structure
end

#expression_typeString

The type of the provided expression (for example, SQL).

Returns:

  • (String)


20567
20568
20569
20570
20571
20572
20573
20574
# File 'lib/aws-sdk-s3/types.rb', line 20567

class SelectParameters < Struct.new(
  :input_serialization,
  :expression_type,
  :expression,
  :output_serialization)
  SENSITIVE = []
  include Aws::Structure
end

#input_serializationTypes::InputSerialization

Describes the serialization format of the object.



20567
20568
20569
20570
20571
20572
20573
20574
# File 'lib/aws-sdk-s3/types.rb', line 20567

class SelectParameters < Struct.new(
  :input_serialization,
  :expression_type,
  :expression,
  :output_serialization)
  SENSITIVE = []
  include Aws::Structure
end

#output_serializationTypes::OutputSerialization

Describes how the results of the Select job are serialized.



20567
20568
20569
20570
20571
20572
20573
20574
# File 'lib/aws-sdk-s3/types.rb', line 20567

class SelectParameters < Struct.new(
  :input_serialization,
  :expression_type,
  :expression,
  :output_serialization)
  SENSITIVE = []
  include Aws::Structure
end