Class: Aws::S3::Types::TargetGrant

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Container for granting information.

Buckets that use the bucket owner enforced setting for Object Ownership don't support target grants. For more information, see Permissions server access log delivery in the Amazon S3 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#granteeTypes::Grantee

Container for the person being granted permissions.

Returns:



21020
21021
21022
21023
21024
21025
# File 'lib/aws-sdk-s3/types.rb', line 21020

class TargetGrant < Struct.new(
  :grantee,
  :permission)
  SENSITIVE = []
  include Aws::Structure
end

#permissionString

Logging permissions assigned to the grantee for the bucket.

Returns:

  • (String)


21020
21021
21022
21023
21024
21025
# File 'lib/aws-sdk-s3/types.rb', line 21020

class TargetGrant < Struct.new(
  :grantee,
  :permission)
  SENSITIVE = []
  include Aws::Structure
end