Class: Aws::S3::Types::TargetGrant
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::TargetGrant
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Container for granting information.
Buckets that use the bucket owner enforced setting for Object Ownership don't support target grants. For more information, see Permissions server access log delivery in the Amazon S3 User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grantee ⇒ Types::Grantee
Container for the person being granted permissions.
-
#permission ⇒ String
Logging permissions assigned to the grantee for the bucket.
Instance Attribute Details
#grantee ⇒ Types::Grantee
Container for the person being granted permissions.
21216 21217 21218 21219 21220 21221 |
# File 'lib/aws-sdk-s3/types.rb', line 21216 class TargetGrant < Struct.new( :grantee, :permission) SENSITIVE = [] include Aws::Structure end |
#permission ⇒ String
Logging permissions assigned to the grantee for the bucket.
21216 21217 21218 21219 21220 21221 |
# File 'lib/aws-sdk-s3/types.rb', line 21216 class TargetGrant < Struct.new( :grantee, :permission) SENSITIVE = [] include Aws::Structure end |