Class: Aws::S3::Types::TopicConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Note:

When making an API call, you may pass TopicConfiguration data as a hash:

{
  id: "NotificationId",
  topic_arn: "TopicArn", # required
  events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated, s3:ObjectRestore:Post, s3:ObjectRestore:Completed
  filter: {
    key: {
      filter_rules: [
        {
          name: "prefix", # accepts prefix, suffix
          value: "FilterRuleValue",
        },
      ],
    },
  },
}

A container for specifying the configuration for publication of messages to an Amazon Simple Notification Service (Amazon SNS) topic.when Amazon S3 detects specified events.

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<String>



9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-s3/types.rb', line 9649

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  include Aws::Structure
end

#filterTypes::NotificationConfigurationFilter

A container for object key name filtering rules. For information about key name filtering, see Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.



9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-s3/types.rb', line 9649

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  include Aws::Structure
end

#idString

An optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.



9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-s3/types.rb', line 9649

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  include Aws::Structure
end

#topic_arnString

The Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 will publish a message when it detects events of the specified type.



9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-s3/types.rb', line 9649

class TopicConfiguration < Struct.new(
  :id,
  :topic_arn,
  :events,
  :filter)
  include Aws::Structure
end