Class: Aws::S3::Types::TopicConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::TopicConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
When making an API call, you may pass TopicConfiguration data as a hash:
{
id: "NotificationId",
topic_arn: "TopicArn", # required
events: ["s3:ReducedRedundancyLostObject"], # required, accepts s3:ReducedRedundancyLostObject, s3:ObjectCreated:*, s3:ObjectCreated:Put, s3:ObjectCreated:Post, s3:ObjectCreated:Copy, s3:ObjectCreated:CompleteMultipartUpload, s3:ObjectRemoved:*, s3:ObjectRemoved:Delete, s3:ObjectRemoved:DeleteMarkerCreated
filter: {
key: {
filter_rules: [
{
name: "prefix", # accepts prefix, suffix
value: "FilterRuleValue",
},
],
},
},
}
Container for specifying the configuration when you want Amazon S3 to publish events to an Amazon Simple Notification Service (Amazon SNS) topic.
Instance Attribute Summary collapse
- #events ⇒ Array<String>
-
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules.
-
#id ⇒ String
Optional unique identifier for configurations in a notification configuration.
-
#topic_arn ⇒ String
Amazon SNS topic ARN to which Amazon S3 will publish a message when it detects events of specified type.
Instance Attribute Details
#events ⇒ Array<String>
8362 8363 8364 8365 8366 8367 8368 |
# File 'lib/aws-sdk-s3/types.rb', line 8362 class TopicConfiguration < Struct.new( :id, :topic_arn, :events, :filter) include Aws::Structure end |
#filter ⇒ Types::NotificationConfigurationFilter
Container for object key name filtering rules. For information about key name filtering, go to Configuring Event Notifications in the Amazon Simple Storage Service Developer Guide.
8362 8363 8364 8365 8366 8367 8368 |
# File 'lib/aws-sdk-s3/types.rb', line 8362 class TopicConfiguration < Struct.new( :id, :topic_arn, :events, :filter) include Aws::Structure end |
#id ⇒ String
Optional unique identifier for configurations in a notification configuration. If you don't provide one, Amazon S3 will assign an ID.
8362 8363 8364 8365 8366 8367 8368 |
# File 'lib/aws-sdk-s3/types.rb', line 8362 class TopicConfiguration < Struct.new( :id, :topic_arn, :events, :filter) include Aws::Structure end |
#topic_arn ⇒ String
Amazon SNS topic ARN to which Amazon S3 will publish a message when it detects events of specified type.
8362 8363 8364 8365 8366 8367 8368 |
# File 'lib/aws-sdk-s3/types.rb', line 8362 class TopicConfiguration < Struct.new( :id, :topic_arn, :events, :filter) include Aws::Structure end |