Class: Aws::S3::Types::Transition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3/types.rb

Overview

Specifies when an object transitions to a specified storage class. For more information about Amazon S3 lifecycle configuration rules, see Transitioning Objects Using Amazon S3 Lifecycle in the Amazon S3 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateTime

Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.

Returns:

  • (Time)


21210
21211
21212
21213
21214
21215
21216
# File 'lib/aws-sdk-s3/types.rb', line 21210

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#daysInteger

Indicates the number of days after creation when objects are transitioned to the specified storage class. The value can be 0 or any positive integer. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see Constraints and considerations for transitions in the Amazon S3 User Guide.

Returns:

  • (Integer)


21210
21211
21212
21213
21214
21215
21216
# File 'lib/aws-sdk-s3/types.rb', line 21210

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The storage class to which you want the object to transition.

Returns:

  • (String)


21210
21211
21212
21213
21214
21215
21216
# File 'lib/aws-sdk-s3/types.rb', line 21210

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end