Class: Aws::S3::Types::UpdateBucketMetadataInventoryTableConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UpdateBucketMetadataInventoryTableConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable an inventory table for.
-
#checksum_algorithm ⇒ String
The checksum algorithm to use with your inventory table configuration.
-
#content_md5 ⇒ String
The ‘Content-MD5` header for the inventory table configuration.
-
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable an inventory table for.
-
#inventory_table_configuration ⇒ Types::InventoryTableConfigurationUpdates
The contents of your inventory table configuration.
Instance Attribute Details
#bucket ⇒ String
The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable an inventory table for.
20364 20365 20366 20367 20368 20369 20370 20371 20372 |
# File 'lib/aws-sdk-s3/types.rb', line 20364 class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :inventory_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
The checksum algorithm to use with your inventory table configuration.
20364 20365 20366 20367 20368 20369 20370 20371 20372 |
# File 'lib/aws-sdk-s3/types.rb', line 20364 class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :inventory_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The ‘Content-MD5` header for the inventory table configuration.
20364 20365 20366 20367 20368 20369 20370 20371 20372 |
# File 'lib/aws-sdk-s3/types.rb', line 20364 class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :inventory_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable an inventory table for.
20364 20365 20366 20367 20368 20369 20370 20371 20372 |
# File 'lib/aws-sdk-s3/types.rb', line 20364 class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :inventory_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#inventory_table_configuration ⇒ Types::InventoryTableConfigurationUpdates
The contents of your inventory table configuration.
20364 20365 20366 20367 20368 20369 20370 20371 20372 |
# File 'lib/aws-sdk-s3/types.rb', line 20364 class UpdateBucketMetadataInventoryTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :inventory_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |