Class: Aws::S3::Types::UpdateBucketMetadataJournalTableConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UpdateBucketMetadataJournalTableConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable journal table record expiration for.
-
#checksum_algorithm ⇒ String
The checksum algorithm to use with your journal table configuration.
-
#content_md5 ⇒ String
The ‘Content-MD5` header for the journal table configuration.
-
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable journal table record expiration for.
-
#journal_table_configuration ⇒ Types::JournalTableConfigurationUpdates
The contents of your journal table configuration.
Instance Attribute Details
#bucket ⇒ String
The general purpose bucket that corresponds to the metadata configuration that you want to enable or disable journal table record expiration for.
20400 20401 20402 20403 20404 20405 20406 20407 20408 |
# File 'lib/aws-sdk-s3/types.rb', line 20400 class UpdateBucketMetadataJournalTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :journal_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
The checksum algorithm to use with your journal table configuration.
20400 20401 20402 20403 20404 20405 20406 20407 20408 |
# File 'lib/aws-sdk-s3/types.rb', line 20400 class UpdateBucketMetadataJournalTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :journal_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#content_md5 ⇒ String
The ‘Content-MD5` header for the journal table configuration.
20400 20401 20402 20403 20404 20405 20406 20407 20408 |
# File 'lib/aws-sdk-s3/types.rb', line 20400 class UpdateBucketMetadataJournalTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :journal_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The expected owner of the general purpose bucket that corresponds to the metadata table configuration that you want to enable or disable journal table record expiration for.
20400 20401 20402 20403 20404 20405 20406 20407 20408 |
# File 'lib/aws-sdk-s3/types.rb', line 20400 class UpdateBucketMetadataJournalTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :journal_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#journal_table_configuration ⇒ Types::JournalTableConfigurationUpdates
The contents of your journal table configuration.
20400 20401 20402 20403 20404 20405 20406 20407 20408 |
# File 'lib/aws-sdk-s3/types.rb', line 20400 class UpdateBucketMetadataJournalTableConfigurationRequest < Struct.new( :bucket, :content_md5, :checksum_algorithm, :journal_table_configuration, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |