Class: Aws::S3::Types::UploadPartOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::UploadPartOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:ssekms_key_id]
Instance Attribute Summary collapse
-
#bucket_key_enabled ⇒ Boolean
Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
-
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part.
-
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part.
-
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part.
-
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` checksum of the part.
-
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part.
-
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part.
-
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` checksum of the part.
-
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part.
-
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part.
-
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part.
-
#etag ⇒ String
Entity tag for the uploaded object.
-
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request.
-
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
-
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that’s used.
-
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
-
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
Instance Attribute Details
#bucket_key_enabled ⇒ Boolean
Indicates whether the multipart upload uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_crc32 ⇒ String
The Base64 encoded, 32-bit ‘CRC32` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_crc32c ⇒ String
The Base64 encoded, 32-bit ‘CRC32C` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_crc64nvme ⇒ String
The Base64 encoded, 64-bit ‘CRC64NVME` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_md5 ⇒ String
The Base64 encoded, 128-bit ‘MD5` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_sha1 ⇒ String
The Base64 encoded, 160-bit ‘SHA1` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_sha256 ⇒ String
The Base64 encoded, 256-bit ‘SHA256` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_sha512 ⇒ String
The Base64 encoded, 512-bit ‘SHA512` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_xxhash128 ⇒ String
The Base64 encoded, 128-bit ‘XXHASH128` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_xxhash3 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH3` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#checksum_xxhash64 ⇒ String
The Base64 encoded, 64-bit ‘XXHASH64` checksum of the part. This will only be present if the checksum was provided in the request. For more information, see [Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#etag ⇒ String
Entity tag for the uploaded object.
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#request_charged ⇒ String
If present, indicates that the requester was successfully charged for the request. For more information, see [Using Requester Pays buckets for storage transfers and usage] in the *Amazon Simple Storage Service user guide*.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/RequesterPaysBuckets.html
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#server_side_encryption ⇒ String
The server-side encryption algorithm used when you store this object in Amazon S3 or Amazon FSx.
<note markdown=“1”> When accessing data stored in Amazon FSx file systems using S3 access points, the only valid server side encryption option is ‘aws:fsx`.
</note>
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#sse_customer_algorithm ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that’s used.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#sse_customer_key_md5 ⇒ String
If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
<note markdown=“1”> This functionality is not supported for directory buckets.
</note>
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |
#ssekms_key_id ⇒ String
If present, indicates the ID of the KMS key that was used for object encryption.
21128 21129 21130 21131 21132 21133 21134 21135 21136 21137 21138 21139 21140 21141 21142 21143 21144 21145 21146 21147 21148 |
# File 'lib/aws-sdk-s3/types.rb', line 21128 class UploadPartOutput < Struct.new( :server_side_encryption, :etag, :checksum_crc32, :checksum_crc32c, :checksum_crc64nvme, :checksum_sha1, :checksum_sha256, :checksum_sha512, :checksum_md5, :checksum_xxhash64, :checksum_xxhash3, :checksum_xxhash128, :sse_customer_algorithm, :sse_customer_key_md5, :ssekms_key_id, :bucket_key_enabled, :request_charged) SENSITIVE = [:ssekms_key_id] include Aws::Structure end |