Class: Aws::S3::Types::WebsiteConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3::Types::WebsiteConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3/types.rb
Overview
Specifies website configuration parameters for an Amazon S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_document ⇒ Types::ErrorDocument
The name of the error document for the website.
-
#index_document ⇒ Types::IndexDocument
The name of the index document for the website.
-
#redirect_all_requests_to ⇒ Types::RedirectAllRequestsTo
The redirect behavior for every request to this bucket’s website endpoint.
-
#routing_rules ⇒ Array<Types::RoutingRule>
Rules that define when a redirect is applied and the redirect behavior.
Instance Attribute Details
#error_document ⇒ Types::ErrorDocument
The name of the error document for the website.
20475 20476 20477 20478 20479 20480 20481 20482 |
# File 'lib/aws-sdk-s3/types.rb', line 20475 class WebsiteConfiguration < Struct.new( :error_document, :index_document, :redirect_all_requests_to, :routing_rules) SENSITIVE = [] include Aws::Structure end |
#index_document ⇒ Types::IndexDocument
The name of the index document for the website.
20475 20476 20477 20478 20479 20480 20481 20482 |
# File 'lib/aws-sdk-s3/types.rb', line 20475 class WebsiteConfiguration < Struct.new( :error_document, :index_document, :redirect_all_requests_to, :routing_rules) SENSITIVE = [] include Aws::Structure end |
#redirect_all_requests_to ⇒ Types::RedirectAllRequestsTo
The redirect behavior for every request to this bucket’s website endpoint.
If you specify this property, you can’t specify any other property.
20475 20476 20477 20478 20479 20480 20481 20482 |
# File 'lib/aws-sdk-s3/types.rb', line 20475 class WebsiteConfiguration < Struct.new( :error_document, :index_document, :redirect_all_requests_to, :routing_rules) SENSITIVE = [] include Aws::Structure end |
#routing_rules ⇒ Array<Types::RoutingRule>
Rules that define when a redirect is applied and the redirect behavior.
20475 20476 20477 20478 20479 20480 20481 20482 |
# File 'lib/aws-sdk-s3/types.rb', line 20475 class WebsiteConfiguration < Struct.new( :error_document, :index_document, :redirect_all_requests_to, :routing_rules) SENSITIVE = [] include Aws::Structure end |