Class: Aws::S3::Waiters::BucketNotExists
- Inherits:
-
Object
- Object
- Aws::S3::Waiters::BucketNotExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-s3/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ BucketNotExists
constructor
A new instance of BucketNotExists.
-
#wait(params = {}) ⇒ Types::HeadBucketOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ BucketNotExists
Returns a new instance of BucketNotExists.
139 140 |
# File 'lib/aws-sdk-s3/waiters.rb', line 139
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
162 163 164 |
# File 'lib/aws-sdk-s3/waiters.rb', line 162 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::HeadBucketOutput
Returns a response object which responds to the following methods:
- #bucket_arn => String
- #bucket_location_type => String
- #bucket_location_name => String
- #bucket_region => String
- #access_point_alias => Boolean
157 |
# File 'lib/aws-sdk-s3/waiters.rb', line 157
def wait: (
|